airport_to_timezone = {
    'AAA': 'Pacific/Tahiti',
    'AAC': 'Africa/Cairo',
    'AAE': 'Africa/Algiers',
    'AAF': 'America/New_York',
    'AAH': 'Europe/Berlin',
    'AAL': 'Europe/Copenhagen',
    'AAM': 'Africa/Johannesburg',
    'AAN': 'Asia/Dubai',
    'AAO': 'America/Caracas',
    'AAP': 'America/Chicago',
    'AAQ': 'Europe/Moscow',
    'AAR': 'Europe/Copenhagen',
    'AAT': 'Asia/Shanghai',
    'AAX': 'America/Sao_Paulo',
    'AAY': 'Asia/Aden',
    'AAZ': 'America/Guatemala',
    'ABA': 'Asia/Krasnoyarsk',
    'ABB': 'Africa/Lagos',
    'ABC': 'Europe/Madrid',
    'ABD': 'Asia/Tehran',
    'ABE': 'America/New_York',
    'ABF': 'Pacific/Tarawa',
    'ABI': 'America/Chicago',
    'ABJ': 'Africa/Abidjan',
    'ABK': 'Africa/Addis_Ababa',
    'ABL': 'America/Anchorage',
    'ABM': 'Australia/Brisbane',
    'ABN': 'America/Paramaribo',
    'ABQ': 'America/Denver',
    'ABR': 'America/Chicago',
    'ABS': 'Africa/Cairo',
    'ABT': 'Asia/Riyadh',
    'ABV': 'Africa/Lagos',
    'ABX': 'Australia/Sydney',
    'ABY': 'America/New_York',
    'ABZ': 'Europe/London',
    'ACA': 'America/Mexico_City',
    'ACC': 'Africa/Accra',
    'ACD': 'America/Bogota',
    'ACE': 'Atlantic/Canary',
    'ACF': 'Australia/Brisbane',
    'ACH': 'Europe/Zurich',
    'ACI': 'Europe/Guernsey',
    'ACJ': 'Asia/Colombo',
    'ACK': 'America/New_York',
    'ACN': 'America/Mexico_City',
    'ACP': 'Asia/Tehran',
    'ACR': 'America/Bogota',
    'ACT': 'America/Chicago',
    'ACV': 'America/Los_Angeles',
    'ACX': 'Asia/Shanghai',
    'ACY': 'America/New_York',
    'ACZ': 'Asia/Tehran',
    'ADA': 'Europe/Istanbul',
    'ADB': 'Europe/Istanbul',
    'ADD': 'Africa/Addis_Ababa',
    'ADE': 'Asia/Aden',
    'ADF': 'Europe/Istanbul',
    'ADH': 'Asia/Yakutsk',
    'ADJ': 'Asia/Amman',
    'ADK': 'America/Adak',
    'ADL': 'Australia/Adelaide',
    'ADM': 'America/Chicago',
    'ADP': 'Asia/Colombo',
    'ADQ': 'America/Anchorage',
    'ADS': 'America/Chicago',
    'ADT': 'America/Chicago',
    'ADU': 'Asia/Tehran',
    'ADW': 'America/New_York',
    'ADX': 'Europe/London',
    'ADY': 'Africa/Johannesburg',
    'ADZ': 'America/Bogota',
    'AEA': 'Pacific/Tarawa',
    'AEB': 'Asia/Shanghai',
    'AEG': 'Asia/Jakarta',
    'AEH': 'Africa/Ndjamena',
    'AEO': 'Africa/Nouakchott',
    'AEP': 'America/Buenos_Aires',
    'AER': 'Europe/Moscow',
    'AES': 'Europe/Oslo',
    'AET': 'America/Anchorage',
    'AEU': 'Asia/Tehran',
    'AEX': 'America/Chicago',
    'AEY': 'Atlantic/Reykjavik',
    'AFA': 'America/Mendoza',
    'AFL': 'America/Campo_Grande',
    'AFS': 'Asia/Samarkand',
    'AFT': 'Pacific/Guadalcanal',
    'AFW': 'America/Chicago',
    'AFY': 'Europe/Istanbul',
    'AFZ': 'Asia/Tehran',
    'AGA': 'Africa/Casablanca',
    'AGB': 'Europe/Berlin',
    'AGC': 'America/New_York',
    'AGE': 'Europe/Berlin',
    'AGF': 'Europe/Paris',
    'AGH': 'Europe/Stockholm',
    'AGI': 'America/Paramaribo',
    'AGJ': 'Asia/Tokyo',
    'AGN': 'America/Anchorage',
    'AGP': 'Europe/Madrid',
    'AGQ': 'Europe/Athens',
    'AGR': 'Asia/Calcutta',
    'AGS': 'America/New_York',
    'AGT': 'America/Asuncion',
    'AGU': 'America/Mexico_City',
    'AGV': 'America/Caracas',
    'AGX': 'Asia/Calcutta',
    'AGZ': 'Africa/Johannesburg',
    'AHB': 'Asia/Riyadh',
    'AHE': 'Pacific/Tahiti',
    'AHN': 'America/New_York',
    'AHO': 'Europe/Rome',
    'AHS': 'America/Tegucigalpa',
    'AHU': 'Africa/Casablanca',
    'AIA': 'America/Denver',
    'AIK': 'America/New_York',
    'AIN': 'America/Anchorage',
    'AIS': 'Pacific/Tarawa',
    'AIT': 'Pacific/Rarotonga',
    'AIU': 'Pacific/Rarotonga',
    'AIZ': 'America/Chicago',
    'AJA': 'Europe/Paris',
    'AJF': 'Asia/Riyadh',
    'AJI': 'Europe/Istanbul',
    'AJK': 'Asia/Tehran',
    'AJL': 'Asia/Calcutta',
    'AJN': 'Indian/Comoro',
    'AJR': 'Europe/Stockholm',
    'AJU': 'America/Fortaleza',
    'AJY': 'Africa/Niamey',
    'AKA': 'Asia/Shanghai',
    'AKB': 'America/Adak',
    'AKC': 'America/New_York',
    'AKD': 'Asia/Calcutta',
    'AKF': 'Africa/Tripoli',
    'AKH': 'Asia/Riyadh',
    'AKI': 'America/Anchorage',
    'AKJ': 'Asia/Tokyo',
    'AKK': 'America/Anchorage',
    'AKL': 'Pacific/Auckland',
    'AKN': 'America/Anchorage',
    'AKO': 'America/Denver',
    'AKP': 'America/Anchorage',
    'AKR': 'Africa/Lagos',
    'AKS': 'Pacific/Guadalcanal',
    'AKT': 'Europe/London',
    'AKU': 'Asia/Shanghai',
    'AKV': 'America/Toronto',
    'AKW': 'Asia/Tehran',
    'AKX': 'Asia/Oral',
    'AKY': 'Asia/Rangoon',
    'ALA': 'Asia/Qyzylorda',
    'ALB': 'America/New_York',
    'ALC': 'Europe/Madrid',
    'ALF': 'Europe/Oslo',
    'ALG': 'Africa/Algiers',
    'ALH': 'Australia/Perth',
    'ALI': 'America/Chicago',
    'ALJ': 'Africa/Johannesburg',
    'ALL': 'Europe/Rome',
    'ALM': 'America/Denver',
    'ALO': 'America/Chicago',
    'ALP': 'Asia/Damascus',
    'ALR': 'Pacific/Auckland',
    'ALS': 'America/Denver',
    'ALU': 'Africa/Mogadishu',
    'ALW': 'America/Los_Angeles',
    'ALY': 'Africa/Cairo',
    'AMA': 'America/Chicago',
    'AMB': 'Indian/Antananarivo',
    'AMC': 'Africa/Ndjamena',
    'AMD': 'Asia/Calcutta',
    'AMH': 'Africa/Addis_Ababa',
    'AMI': 'Asia/Makassar',
    'AMM': 'Asia/Amman',
    'AMQ': 'Asia/Jayapura',
    'AMS': 'Europe/Amsterdam',
    'AMV': 'Europe/Moscow',
    'AMZ': 'Pacific/Auckland',
    'ANB': 'America/Chicago',
    'ANC': 'America/Anchorage',
    'AND': 'America/New_York',
    'ANE': 'Europe/Paris',
    'ANF': 'America/Santiago',
    'ANG': 'Europe/Paris',
    'ANI': 'America/Anchorage',
    'ANK': 'Europe/Istanbul',
    'ANM': 'Indian/Antananarivo',
    'ANN': 'America/Anchorage',
    'ANP': 'America/New_York',
    'ANQ': 'America/New_York',
    'ANR': 'Europe/Brussels',
    'ANS': 'America/Lima',
    'ANU': 'America/Antigua',
    'ANV': 'America/Anchorage',
    'ANX': 'Europe/Oslo',
    'AOC': 'Europe/Berlin',
    'AOE': 'Europe/Istanbul',
    'AOG': 'Asia/Shanghai',
    'AOH': 'America/New_York',
    'AOI': 'Europe/Rome',
    'AOJ': 'Asia/Tokyo',
    'AOK': 'Europe/Athens',
    'AOL': 'America/Cordoba',
    'AOO': 'America/New_York',
    'AOP': 'America/Lima',
    'AOR': 'Asia/Kuala_Lumpur',
    'AOT': 'Europe/Rome',
    'APA': 'America/Denver',
    'APC': 'America/Los_Angeles',
    'APF': 'America/New_York',
    'APG': 'America/New_York',
    'APK': 'Pacific/Tahiti',
    'APL': 'Africa/Maputo',
    'APN': 'America/New_York',
    'APO': 'America/Bogota',
    'APW': 'Pacific/Apia',
    'APZ': 'America/Argentina/Salta',
    'AQA': 'America/Sao_Paulo',
    'AQB': 'America/Guatemala',
    'AQG': 'Asia/Shanghai',
    'AQI': 'Asia/Riyadh',
    'AQJ': 'Asia/Amman',
    'AQP': 'America/Lima',
    'ARA': 'America/Chicago',
    'ARB': 'America/New_York',
    'ARC': 'America/Anchorage',
    'ARD': 'Asia/Makassar',
    'ARE': 'America/Puerto_Rico',
    'ARH': 'Europe/Moscow',
    'ARI': 'America/Santiago',
    'ARK': 'Africa/Dar_es_Salaam',
    'ARM': 'Australia/Sydney',
    'ARN': 'Europe/Stockholm',
    'ARR': 'America/Catamarca',
    'ART': 'America/New_York',
    'ARU': 'America/Sao_Paulo',
    'ARV': 'America/Chicago',
    'ARW': 'Europe/Bucharest',
    'ASA': 'Africa/Asmera',
    'ASB': 'Asia/Ashgabat',
    'ASD': 'America/Nassau',
    'ASE': 'America/Denver',
    'ASF': 'Europe/Samara',
    'ASH': 'America/New_York',
    'ASI': 'Atlantic/St_Helena',
    'ASJ': 'Asia/Tokyo',
    'ASK': 'Africa/Abidjan',
    'ASM': 'Africa/Asmera',
    'ASO': 'Africa/Addis_Ababa',
    'ASP': 'Australia/Darwin',
    'ASR': 'Europe/Istanbul',
    'AST': 'America/Los_Angeles',
    'ASU': 'America/Asuncion',
    'ASV': 'Africa/Nairobi',
    'ASW': 'Africa/Cairo',
    'ATA': 'America/Lima',
    'ATB': 'Africa/Khartoum',
    'ATC': 'America/Nassau',
    'ATD': 'Pacific/Guadalcanal',
    'ATF': 'America/Guayaquil',
    'ATH': 'Europe/Athens',
    'ATJ': 'Indian/Antananarivo',
    'ATK': 'America/Anchorage',
    'ATL': 'America/New_York',
    'ATM': 'America/Belem',
    'ATO': 'America/New_York',
    'ATQ': 'Asia/Calcutta',
    'ATR': 'Africa/Nouakchott',
    'ATW': 'America/Chicago',
    'ATY': 'America/Chicago',
    'ATZ': 'Africa/Cairo',
    'AUA': 'America/Aruba',
    'AUC': 'America/Bogota',
    'AUF': 'Europe/Paris',
    'AUG': 'America/New_York',
    'AUH': 'Asia/Dubai',
    'AUK': 'America/Anchorage',
    'AUO': 'America/Chicago',
    'AUQ': 'Pacific/Marquesas',
    'AUR': 'Europe/Paris',
    'AUS': 'America/Chicago',
    'AUU': 'Australia/Brisbane',
    'AUW': 'America/Chicago',
    'AUX': 'America/Fortaleza',
    'AUY': 'Pacific/Efate',
    'AVA': 'Asia/Shanghai',
    'AVB': 'Europe/Rome',
    'AVI': 'America/Havana',
    'AVK': 'Asia/Ulaanbaatar',
    'AVL': 'America/New_York',
    'AVN': 'Europe/Paris',
    'AVO': 'America/New_York',
    'AVP': 'America/New_York',
    'AVR': 'Europe/Lisbon',
    'AVV': 'Australia/Hobart',
    'AVW': 'America/Phoenix',
    'AVX': 'America/Los_Angeles',
    'AWA': 'Africa/Addis_Ababa',
    'AWD': 'Pacific/Efate',
    'AWK': 'Pacific/Johnston',
    'AWZ': 'Asia/Tehran',
    'AXA': 'America/Anguilla',
    'AXD': 'Europe/Athens',
    'AXJ': 'Asia/Tokyo',
    'AXK': 'Asia/Aden',
    'AXM': 'America/Bogota',
    'AXP': 'America/Nassau',
    'AXR': 'Pacific/Tahiti',
    'AXT': 'Asia/Tokyo',
    'AXU': 'Africa/Addis_Ababa',
    'AYK': 'Asia/Qyzylorda',
    'AYO': 'America/Asuncion',
    'AYP': 'America/Lima',
    'AYQ': 'Australia/Darwin',
    'AYT': 'Europe/Istanbul',
    'AZA': 'America/Phoenix',
    'AZD': 'Asia/Tehran',
    'AZI': 'Asia/Dubai',
    'AZN': 'Asia/Samarkand',
    'AZO': 'America/New_York',
    'AZR': 'Africa/Algiers',
    'AZS': 'America/Santo_Domingo',
    'BAB': 'America/Los_Angeles',
    'BAD': 'America/Chicago',
    'BAF': 'America/New_York',
    'BAG': 'Asia/Manila',
    'BAH': 'Asia/Bahrain',
    'BAI': 'America/Costa_Rica',
    'BAL': 'Europe/Istanbul',
    'BAQ': 'America/Bogota',
    'BAS': 'Pacific/Guadalcanal',
    'BAU': 'America/Sao_Paulo',
    'BAV': 'Asia/Shanghai',
    'BAX': 'Asia/Krasnoyarsk',
    'BAY': 'Europe/Bucharest',
    'BAZ': 'America/Boa_Vista',
    'BBA': 'America/Santiago',
    'BBG': 'Pacific/Tarawa',
    'BBH': 'Europe/Berlin',
    'BBI': 'Asia/Calcutta',
    'BBJ': 'Europe/Berlin',
    'BBK': 'Africa/Gaborone',
    'BBL': 'Australia/Brisbane',
    'BBM': 'Asia/Phnom_Penh',
    'BBN': 'Asia/Kuala_Lumpur',
    'BBO': 'Africa/Mogadishu',
    'BBP': 'Europe/London',
    'BBQ': 'America/Antigua',
    'BBR': 'America/Guadeloupe',
    'BBS': 'Europe/London',
    'BBT': 'Africa/Bangui',
    'BBU': 'Europe/Bucharest',
    'BBX': 'America/New_York',
    'BCA': 'America/Havana',
    'BCD': 'Asia/Manila',
    'BCE': 'America/Denver',
    'BCH': 'Asia/Dili',
    'BCI': 'Australia/Brisbane',
    'BCL': 'America/Costa_Rica',
    'BCM': 'Europe/Bucharest',
    'BCN': 'Europe/Madrid',
    'BCO': 'Africa/Addis_Ababa',
    'BCT': 'America/New_York',
    'BDA': 'Atlantic/Bermuda',
    'BDB': 'Australia/Brisbane',
    'BDD': 'Australia/Brisbane',
    'BDE': 'America/Chicago',
    'BDH': 'Asia/Tehran',
    'BDJ': 'Asia/Makassar',
    'BDL': 'America/New_York',
    'BDM': 'Europe/Istanbul',
    'BDN': 'Asia/Karachi',
    'BDO': 'Asia/Jakarta',
    'BDP': 'Asia/Katmandu',
    'BDQ': 'Asia/Calcutta',
    'BDR': 'America/New_York',
    'BDS': 'Europe/Rome',
    'BDT': 'Africa/Kinshasa',
    'BDU': 'Europe/Oslo',
    'BEB': 'Europe/London',
    'BEC': 'America/Chicago',
    'BED': 'America/New_York',
    'BEF': 'America/Managua',
    'BEG': 'Europe/Belgrade',
    'BEI': 'Africa/Addis_Ababa',
    'BEJ': 'Asia/Makassar',
    'BEK': 'Asia/Calcutta',
    'BEL': 'America/Belem',
    'BEM': 'Africa/Casablanca',
    'BEN': 'Africa/Tripoli',
    'BEO': 'Australia/Sydney',
    'BEP': 'Asia/Calcutta',
    'BEQ': 'Europe/London',
    'BES': 'Europe/Paris',
    'BET': 'America/Anchorage',
    'BEU': 'Australia/Brisbane',
    'BEV': 'Asia/Jerusalem',
    'BEW': 'Africa/Maputo',
    'BEX': 'Europe/London',
    'BEY': 'Asia/Beirut',
    'BEZ': 'Pacific/Tarawa',
    'BFD': 'America/New_York',
    'BFE': 'Europe/Berlin',
    'BFF': 'America/Denver',
    'BFH': 'America/Sao_Paulo',
    'BFI': 'America/Los_Angeles',
    'BFJ': 'Asia/Shanghai',
    'BFK': 'America/Denver',
    'BFL': 'America/Los_Angeles',
    'BFM': 'America/Chicago',
    'BFN': 'Africa/Johannesburg',
    'BFO': 'Africa/Harare',
    'BFP': 'America/New_York',
    'BFS': 'Europe/London',
    'BFT': 'America/New_York',
    'BFV': 'Asia/Bangkok',
    'BFW': 'Africa/Algiers',
    'BFX': 'Africa/Douala',
    'BGA': 'America/Bogota',
    'BGC': 'Europe/Lisbon',
    'BGE': 'America/New_York',
    'BGF': 'Africa/Bangui',
    'BGG': 'Europe/Istanbul',
    'BGI': 'America/Barbados',
    'BGM': 'America/New_York',
    'BGO': 'Europe/Oslo',
    'BGR': 'America/New_York',
    'BGW': 'Asia/Baghdad',
    'BGX': 'America/Sao_Paulo',
    'BGY': 'Europe/Rome',
    'BGZ': 'Europe/Lisbon',
    'BHB': 'America/New_York',
    'BHD': 'Europe/London',
    'BHE': 'Pacific/Auckland',
    'BHG': 'America/Tegucigalpa',
    'BHH': 'Asia/Riyadh',
    'BHI': 'America/Buenos_Aires',
    'BHJ': 'Asia/Calcutta',
    'BHK': 'Asia/Samarkand',
    'BHM': 'America/Chicago',
    'BHN': 'Asia/Aden',
    'BHO': 'Asia/Calcutta',
    'BHP': 'Asia/Katmandu',
    'BHQ': 'Australia/Adelaide',
    'BHR': 'Asia/Katmandu',
    'BHS': 'Australia/Sydney',
    'BHU': 'Asia/Calcutta',
    'BHV': 'Asia/Karachi',
    'BHW': 'Asia/Karachi',
    'BHX': 'Europe/London',
    'BHY': 'Asia/Shanghai',
    'BIA': 'Europe/Paris',
    'BID': 'America/New_York',
    'BIF': 'America/Denver',
    'BIG': 'America/Anchorage',
    'BIK': 'Asia/Jayapura',
    'BIL': 'America/Denver',
    'BIM': 'America/Nassau',
    'BIN': 'Asia/Kabul',
    'BIO': 'Europe/Madrid',
    'BIQ': 'Europe/Paris',
    'BIR': 'Asia/Katmandu',
    'BIS': 'America/Chicago',
    'BIU': 'Atlantic/Reykjavik',
    'BIX': 'America/Chicago',
    'BIY': 'Africa/Johannesburg',
    'BJA': 'Africa/Algiers',
    'BJB': 'Asia/Tehran',
    'BJC': 'America/Denver',
    'BJF': 'Europe/Oslo',
    'BJH': 'Asia/Katmandu',
    'BJI': 'America/Chicago',
    'BJL': 'Africa/Banjul',
    'BJM': 'Africa/Bujumbura',
    'BJO': 'America/La_Paz',
    'BJP': 'America/Sao_Paulo',
    'BJR': 'Africa/Addis_Ababa',
    'BJU': 'Asia/Katmandu',
    'BJV': 'Europe/Istanbul',
    'BJX': 'America/Mexico_City',
    'BJZ': 'Europe/Madrid',
    'BKA': 'Europe/Moscow',
    'BKB': 'Asia/Calcutta',
    'BKC': 'America/Anchorage',
    'BKD': 'America/Chicago',
    'BKG': 'America/Chicago',
    'BKH': 'Pacific/Honolulu',
    'BKI': 'Asia/Kuala_Lumpur',
    'BKK': 'Asia/Bangkok',
    'BKL': 'America/New_York',
    'BKM': 'Asia/Kuala_Lumpur',
    'BKO': 'Africa/Bamako',
    'BKQ': 'Australia/Brisbane',
    'BKS': 'Asia/Jakarta',
    'BKW': 'America/New_York',
    'BKY': 'Africa/Lubumbashi',
    'BKZ': 'Africa/Dar_es_Salaam',
    'BLA': 'America/Caracas',
    'BLB': 'America/Panama',
    'BLE': 'Europe/Stockholm',
    'BLF': 'America/New_York',
    'BLG': 'Asia/Kuala_Lumpur',
    'BLH': 'America/Los_Angeles',
    'BLI': 'America/Los_Angeles',
    'BLJ': 'Africa/Algiers',
    'BLK': 'Europe/London',
    'BLL': 'Europe/Copenhagen',
    'BLQ': 'Europe/Rome',
    'BLR': 'Asia/Calcutta',
    'BLT': 'Australia/Brisbane',
    'BLV': 'America/Chicago',
    'BLZ': 'Africa/Blantyre',
    'BMA': 'Europe/Stockholm',
    'BMC': 'America/Denver',
    'BMD': 'Indian/Antananarivo',
    'BME': 'Australia/Perth',
    'BMG': 'America/New_York',
    'BMI': 'America/Chicago',
    'BMK': 'Europe/Berlin',
    'BMM': 'Africa/Libreville',
    'BMO': 'Asia/Rangoon',
    'BMP': 'Australia/Brisbane',
    'BMT': 'America/Chicago',
    'BMU': 'Asia/Makassar',
    'BMV': 'Asia/Saigon',
    'BMW': 'Africa/Algiers',
    'BMX': 'America/Anchorage',
    'BMY': 'Pacific/Noumea',
    'BNA': 'America/Chicago',
    'BND': 'Asia/Tehran',
    'BNE': 'Australia/Brisbane',
    'BNI': 'Africa/Lagos',
    'BNK': 'Australia/Sydney',
    'BNN': 'Europe/Oslo',
    'BNO': 'America/Los_Angeles',
    'BNP': 'Asia/Karachi',
    'BNS': 'America/Caracas',
    'BNU': 'America/Sao_Paulo',
    'BNX': 'Europe/Sarajevo',
    'BOA': 'Africa/Kinshasa',
    'BOB': 'Pacific/Tahiti',
    'BOC': 'America/Panama',
    'BOD': 'Europe/Paris',
    'BOG': 'America/Bogota',
    'BOH': 'Europe/London',
    'BOI': 'America/Denver',
    'BOJ': 'Europe/Sofia',
    'BOM': 'Asia/Calcutta',
    'BON': 'America/Curacao',
    'BOO': 'Europe/Oslo',
    'BOR': 'Europe/Paris',
    'BOS': 'America/New_York',
    'BOU': 'Europe/Paris',
    'BOW': 'America/New_York',
    'BOY': 'Africa/Ouagadougou',
    'BPC': 'Africa/Douala',
    'BPE': 'Asia/Shanghai',
    'BPF': 'Pacific/Guadalcanal',
    'BPG': 'America/Campo_Grande',
    'BPM': 'Asia/Calcutta',
    'BPN': 'Asia/Makassar',
    'BPS': 'America/Fortaleza',
    'BPT': 'America/Chicago',
    'BPX': 'Asia/Shanghai',
    'BPY': 'Indian/Antananarivo',
    'BQA': 'Asia/Manila',
    'BQB': 'Australia/Perth',
    'BQH': 'Europe/London',
    'BQJ': 'Asia/Vladivostok',
    'BQK': 'America/New_York',
    'BQL': 'Australia/Brisbane',
    'BQN': 'America/Puerto_Rico',
    'BQS': 'Asia/Yakutsk',
    'BQT': 'Europe/Minsk',
    'BQU': 'America/St_Vincent',
    'BRA': 'America/Fortaleza',
    'BRC': 'America/Argentina/Salta',
    'BRD': 'America/Chicago',
    'BRE': 'Europe/Berlin',
    'BRI': 'Europe/Rome',
    'BRK': 'Australia/Sydney',
    'BRL': 'America/Chicago',
    'BRM': 'America/Caracas',
    'BRN': 'Europe/Zurich',
    'BRO': 'America/Chicago',
    'BRQ': 'Europe/Prague',
    'BRR': 'Europe/London',
    'BRS': 'Europe/London',
    'BRT': 'Australia/Darwin',
    'BRU': 'Europe/Brussels',
    'BRV': 'Europe/Berlin',
    'BRW': 'America/Anchorage',
    'BRX': 'America/Santo_Domingo',
    'BSA': 'Africa/Mogadishu',
    'BSB': 'America/Sao_Paulo',
    'BSC': 'America/Bogota',
    'BSD': 'Asia/Shanghai',
    'BSF': 'Pacific/Honolulu',
    'BSG': 'Africa/Malabo',
    'BSJ': 'Australia/Hobart',
    'BSK': 'Africa/Algiers',
    'BSL': 'Europe/Paris',
    'BSR': 'Asia/Baghdad',
    'BST': 'Asia/Kabul',
    'BSU': 'Africa/Kinshasa',
    'BSX': 'Asia/Rangoon',
    'BTC': 'Asia/Colombo',
    'BTE': 'Africa/Freetown',
    'BTH': 'Asia/Jakarta',
    'BTI': 'America/Anchorage',
    'BTJ': 'Asia/Jakarta',
    'BTK': 'Asia/Irkutsk',
    'BTM': 'America/Denver',
    'BTR': 'America/Chicago',
    'BTS': 'Europe/Bratislava',
    'BTT': 'America/Anchorage',
    'BTU': 'Asia/Kuala_Lumpur',
    'BTV': 'America/New_York',
    'BTW': 'Asia/Makassar',
    'BTZ': 'Europe/Istanbul',
    'BUA': 'Pacific/Port_Moresby',
    'BUC': 'Australia/Brisbane',
    'BUD': 'Europe/Budapest',
    'BUF': 'America/New_York',
    'BUG': 'Africa/Luanda',
    'BUI': 'Asia/Jayapura',
    'BUJ': 'Africa/Algiers',
    'BUN': 'America/Bogota',
    'BUO': 'Africa/Mogadishu',
    'BUP': 'Asia/Calcutta',
    'BUQ': 'Africa/Harare',
    'BUR': 'America/Los_Angeles',
    'BUS': 'Asia/Tbilisi',
    'BUX': 'Africa/Lubumbashi',
    'BUZ': 'Asia/Tehran',
    'BVA': 'Europe/Paris',
    'BVB': 'America/Boa_Vista',
    'BVC': 'Atlantic/Cape_Verde',
    'BVE': 'Europe/Paris',
    'BVG': 'Europe/Oslo',
    'BVH': 'America/Boa_Vista',
    'BVI': 'Australia/Brisbane',
    'BVS': 'America/Belem',
    'BVY': 'America/New_York',
    'BWA': 'Asia/Katmandu',
    'BWB': 'Australia/Perth',
    'BWE': 'Europe/Berlin',
    'BWF': 'Europe/London',
    'BWG': 'America/Chicago',
    'BWH': 'Asia/Kuala_Lumpur',
    'BWI': 'America/New_York',
    'BWK': 'Europe/Zagreb',
    'BWN': 'Asia/Brunei',
    'BWO': 'Europe/Moscow',
    'BWT': 'Australia/Melbourne',
    'BWU': 'Australia/Sydney',
    'BXB': 'Asia/Jayapura',
    'BXE': 'Africa/Dakar',
    'BXG': 'Australia/Hobart',
    'BXH': 'Asia/Qyzylorda',
    'BXK': 'America/Phoenix',
    'BXN': 'Europe/Istanbul',
    'BXO': 'Europe/Zurich',
    'BXR': 'Asia/Tehran',
    'BXU': 'Asia/Manila',
    'BXY': 'Asia/Qyzylorda',
    'BYC': 'America/La_Paz',
    'BYF': 'Europe/Paris',
    'BYH': 'America/Chicago',
    'BYJ': 'Europe/Lisbon',
    'BYK': 'Africa/Abidjan',
    'BYM': 'America/Havana',
    'BYN': 'Asia/Ulaanbaatar',
    'BYO': 'America/Campo_Grande',
    'BYR': 'Europe/Copenhagen',
    'BYS': 'America/Los_Angeles',
    'BYT': 'Europe/Dublin',
    'BYU': 'Europe/Berlin',
    'BZA': 'America/Managua',
    'BZE': 'America/Belize',
    'BZG': 'Europe/Warsaw',
    'BZH': 'Africa/Harare',
    'BZI': 'Europe/Istanbul',
    'BZK': 'Europe/Moscow',
    'BZL': 'Asia/Dhaka',
    'BZN': 'America/Denver',
    'BZO': 'Europe/Rome',
    'BZR': 'Europe/Paris',
    'BZU': 'Africa/Lubumbashi',
    'BZV': 'Africa/Brazzaville',
    'BZY': 'Europe/Chisinau',
    'BZZ': 'Europe/London',
    'CAB': 'Africa/Luanda',
    'CAC': 'America/Sao_Paulo',
    'CAE': 'America/New_York',
    'CAF': 'America/Boa_Vista',
    'CAG': 'Europe/Rome',
    'CAH': 'Asia/Saigon',
    'CAI': 'Africa/Cairo',
    'CAJ': 'America/Caracas',
    'CAK': 'America/New_York',
    'CAL': 'Europe/London',
    'CAN': 'Asia/Shanghai',
    'CAP': 'America/Port-au-Prince',
    'CAQ': 'America/Bogota',
    'CAR': 'America/New_York',
    'CAT': 'Europe/Lisbon',
    'CAU': 'America/Fortaleza',
    'CAW': 'America/Sao_Paulo',
    'CAX': 'Europe/London',
    'CAY': 'America/Cayenne',
    'CAZ': 'Australia/Sydney',
    'CBB': 'America/La_Paz',
    'CBD': 'Asia/Calcutta',
    'CBE': 'America/New_York',
    'CBG': 'Europe/London',
    'CBH': 'Africa/Algiers',
    'CBJ': 'America/Santo_Domingo',
    'CBL': 'America/Caracas',
    'CBM': 'America/Chicago',
    'CBN': 'Asia/Jakarta',
    'CBO': 'Asia/Manila',
    'CBQ': 'Africa/Lagos',
    'CBR': 'Australia/Sydney',
    'CBT': 'Africa/Luanda',
    'CBU': 'Europe/Berlin',
    'CBV': 'America/Guatemala',
    'CCA': 'America/La_Paz',
    'CCC': 'America/Havana',
    'CCF': 'Europe/Paris',
    'CCH': 'America/Santiago',
    'CCI': 'America/Sao_Paulo',
    'CCJ': 'Asia/Calcutta',
    'CCK': 'Indian/Cocos',
    'CCL': 'Australia/Brisbane',
    'CCM': 'America/Sao_Paulo',
    'CCN': 'Asia/Kabul',
    'CCP': 'America/Santiago',
    'CCR': 'America/Los_Angeles',
    'CCS': 'America/Caracas',
    'CCU': 'Asia/Calcutta',
    'CCV': 'Pacific/Efate',
    'CCZ': 'America/Nassau',
    'CDA': 'Australia/Darwin',
    'CDB': 'America/Anchorage',
    'CDC': 'America/Denver',
    'CDG': 'Europe/Paris',
    'CDJ': 'America/Belem',
    'CDN': 'America/New_York',
    'CDP': 'Asia/Calcutta',
    'CDR': 'America/Denver',
    'CDS': 'America/Chicago',
    'CDU': 'Australia/Sydney',
    'CDV': 'America/Anchorage',
    'CDW': 'America/New_York',
    'CEB': 'Asia/Manila',
    'CEC': 'America/Los_Angeles',
    'CED': 'Australia/Adelaide',
    'CEE': 'Europe/Moscow',
    'CEF': 'America/New_York',
    'CEG': 'Europe/London',
    'CEI': 'Asia/Bangkok',
    'CEJ': 'Europe/Kiev',
    'CEK': 'Asia/Yekaterinburg',
    'CEM': 'America/Anchorage',
    'CEN': 'America/Hermosillo',
    'CEQ': 'Europe/Paris',
    'CER': 'Europe/Paris',
    'CES': 'Australia/Sydney',
    'CET': 'Europe/Paris',
    'CEU': 'America/New_York',
    'CEW': 'America/Chicago',
    'CEZ': 'America/Denver',
    'CFB': 'America/Sao_Paulo',
    'CFC': 'America/Sao_Paulo',
    'CFD': 'America/Chicago',
    'CFE': 'Europe/Paris',
    'CFG': 'America/Havana',
    'CFK': 'Africa/Algiers',
    'CFN': 'Europe/Dublin',
    'CFO': 'America/Campo_Grande',
    'CFR': 'Europe/Paris',
    'CFS': 'Australia/Sydney',
    'CFU': 'Europe/Athens',
    'CGB': 'America/Campo_Grande',
    'CGD': 'Asia/Shanghai',
    'CGF': 'America/New_York',
    'CGH': 'America/Sao_Paulo',
    'CGI': 'America/Chicago',
    'CGJ': 'Africa/Lusaka',
    'CGK': 'Asia/Jakarta',
    'CGM': 'Asia/Manila',
    'CGN': 'Europe/Berlin',
    'CGO': 'Asia/Shanghai',
    'CGP': 'Asia/Dhaka',
    'CGQ': 'Asia/Shanghai',
    'CGR': 'America/Campo_Grande',
    'CGX': 'America/Chicago',
    'CGZ': 'America/Phoenix',
    'CHA': 'America/New_York',
    'CHC': 'Pacific/Auckland',
    'CHF': 'Asia/Seoul',
    'CHG': 'Asia/Shanghai',
    'CHH': 'America/Lima',
    'CHM': 'America/Lima',
    'CHN': 'Asia/Seoul',
    'CHO': 'America/New_York',
    'CHQ': 'Europe/Athens',
    'CHR': 'Europe/Paris',
    'CHS': 'America/New_York',
    'CHT': 'Pacific/Chatham',
    'CHU': 'America/Anchorage',
    'CHX': 'America/Panama',
    'CHY': 'Pacific/Guadalcanal',
    'CIA': 'Europe/Rome',
    'CIC': 'America/Los_Angeles',
    'CID': 'America/Chicago',
    'CIF': 'Asia/Shanghai',
    'CIH': 'Asia/Shanghai',
    'CIJ': 'America/La_Paz',
    'CIK': 'America/Anchorage',
    'CIO': 'America/Asuncion',
    'CIP': 'Africa/Lusaka',
    'CIS': 'Pacific/Enderbury',
    'CIT': 'Asia/Qyzylorda',
    'CIU': 'America/New_York',
    'CIW': 'America/St_Vincent',
    'CIX': 'America/Lima',
    'CIY': 'Europe/Rome',
    'CIZ': 'America/Boa_Vista',
    'CJA': 'America/Lima',
    'CJB': 'Asia/Calcutta',
    'CJC': 'America/Santiago',
    'CJJ': 'Asia/Seoul',
    'CJL': 'Asia/Karachi',
    'CJM': 'Asia/Bangkok',
    'CJN': 'Asia/Jakarta',
    'CJS': 'America/Mazatlan',
    'CJU': 'Asia/Seoul',
    'CKB': 'America/New_York',
    'CKC': 'Europe/Kiev',
    'CKG': 'Asia/Shanghai',
    'CKH': 'Asia/Srednekolymsk',
    'CKL': 'Europe/Moscow',
    'CKS': 'America/Belem',
    'CKT': 'Asia/Tehran',
    'CKV': 'America/Chicago',
    'CKY': 'Africa/Conakry',
    'CKZ': 'Europe/Istanbul',
    'CLD': 'America/Los_Angeles',
    'CLE': 'America/New_York',
    'CLJ': 'Europe/Bucharest',
    'CLL': 'America/Chicago',
    'CLM': 'America/Los_Angeles',
    'CLN': 'America/Fortaleza',
    'CLO': 'America/Bogota',
    'CLQ': 'America/Mexico_City',
    'CLS': 'America/Los_Angeles',
    'CLT': 'America/New_York',
    'CLV': 'America/Sao_Paulo',
    'CLW': 'America/New_York',
    'CLY': 'Europe/Paris',
    'CLZ': 'America/Caracas',
    'CMA': 'Australia/Brisbane',
    'CMB': 'Asia/Colombo',
    'CME': 'America/Mexico_City',
    'CMF': 'Europe/Paris',
    'CMG': 'America/Campo_Grande',
    'CMH': 'America/New_York',
    'CMI': 'America/Chicago',
    'CMJ': 'Asia/Taipei',
    'CMK': 'Africa/Blantyre',
    'CMN': 'Africa/Casablanca',
    'CMP': 'America/Belem',
    'CMR': 'Europe/Paris',
    'CMU': 'Pacific/Port_Moresby',
    'CMW': 'America/Havana',
    'CMX': 'America/New_York',
    'CNB': 'Australia/Sydney',
    'CNC': 'Australia/Brisbane',
    'CND': 'Europe/Bucharest',
    'CNF': 'America/Sao_Paulo',
    'CNG': 'Europe/Paris',
    'CNI': 'Asia/Shanghai',
    'CNJ': 'Australia/Brisbane',
    'CNL': 'Europe/Copenhagen',
    'CNM': 'America/Denver',
    'CNP': 'America/Scoresbysund',
    'CNQ': 'America/Cordoba',
    'CNS': 'Australia/Brisbane',
    'CNW': 'America/Chicago',
    'CNX': 'Asia/Bangkok',
    'CNY': 'America/Denver',
    'COC': 'America/Cordoba',
    'COD': 'America/Denver',
    'COE': 'America/Los_Angeles',
    'COF': 'America/New_York',
    'COG': 'America/Bogota',
    'COH': 'Asia/Calcutta',
    'COJ': 'Australia/Sydney',
    'COK': 'Asia/Calcutta',
    'CON': 'America/New_York',
    'COO': 'Africa/Porto-Novo',
    'COQ': 'Asia/Ulaanbaatar',
    'COR': 'America/Cordoba',
    'COS': 'America/Denver',
    'COT': 'America/Chicago',
    'COU': 'America/Chicago',
    'COX': 'America/Nassau',
    'COZ': 'America/Santo_Domingo',
    'CPA': 'Africa/Monrovia',
    'CPB': 'America/Bogota',
    'CPC': 'America/Argentina/Salta',
    'CPD': 'Australia/Adelaide',
    'CPE': 'America/Mexico_City',
    'CPH': 'Europe/Copenhagen',
    'CPQ': 'America/Sao_Paulo',
    'CPR': 'America/Denver',
    'CPT': 'Africa/Johannesburg',
    'CPV': 'America/Fortaleza',
    'CPX': 'America/Puerto_Rico',
    'CQD': 'Asia/Tehran',
    'CQF': 'Europe/Paris',
    'CQM': 'Europe/Madrid',
    'CRA': 'Europe/Bucharest',
    'CRC': 'America/Bogota',
    'CRD': 'America/Catamarca',
    'CRE': 'America/New_York',
    'CRI': 'America/Nassau',
    'CRK': 'Asia/Manila',
    'CRL': 'Europe/Brussels',
    'CRM': 'Asia/Manila',
    'CRP': 'America/Chicago',
    'CRQ': 'America/Fortaleza',
    'CRV': 'Europe/Rome',
    'CRW': 'America/New_York',
    'CRZ': 'Asia/Ashgabat',
    'CSA': 'Europe/London',
    'CSB': 'Europe/Bucharest',
    'CSF': 'Europe/Paris',
    'CSG': 'America/New_York',
    'CSH': 'Europe/Moscow',
    'CSK': 'Africa/Dakar',
    'CSM': 'America/Chicago',
    'CSO': 'Europe/Berlin',
    'CSX': 'Asia/Shanghai',
    'CSY': 'Europe/Moscow',
    'CSZ': 'America/Buenos_Aires',
    'CTA': 'Europe/Rome',
    'CTB': 'America/Denver',
    'CTC': 'America/Catamarca',
    'CTD': 'America/Panama',
    'CTG': 'America/Bogota',
    'CTH': 'America/New_York',
    'CTL': 'Australia/Brisbane',
    'CTM': 'America/Cancun',
    'CTN': 'Australia/Brisbane',
    'CTS': 'Asia/Tokyo',
    'CTT': 'Europe/Paris',
    'CTU': 'Asia/Shanghai',
    'CTY': 'America/New_York',
    'CUA': 'America/Mazatlan',
    'CUC': 'America/Bogota',
    'CUE': 'America/Guayaquil',
    'CUF': 'Europe/Rome',
    'CUH': 'America/Chicago',
    'CUL': 'America/Mazatlan',
    'CUM': 'America/Caracas',
    'CUN': 'America/Cancun',
    'CUP': 'America/Caracas',
    'CUQ': 'Australia/Brisbane',
    'CUR': 'America/Curacao',
    'CUT': 'America/Argentina/Salta',
    'CUU': 'America/Mazatlan',
    'CUZ': 'America/Lima',
    'CVF': 'Europe/Paris',
    'CVG': 'America/New_York',
    'CVJ': 'America/Mexico_City',
    'CVM': 'America/Mexico_City',
    'CVN': 'America/Denver',
    'CVO': 'America/Los_Angeles',
    'CVQ': 'Australia/Perth',
    'CVS': 'America/Denver',
    'CVT': 'Europe/London',
    'CVU': 'Atlantic/Azores',
    'CWA': 'America/Chicago',
    'CWB': 'America/Sao_Paulo',
    'CWC': 'Europe/Kiev',
    'CWE': 'Africa/Cairo',
    'CWI': 'America/Chicago',
    'CWL': 'Europe/London',
    'CWT': 'Australia/Sydney',
    'CXA': 'America/Caracas',
    'CXB': 'Asia/Dhaka',
    'CXH': 'America/Vancouver',
    'CXJ': 'America/Sao_Paulo',
    'CXL': 'America/Los_Angeles',
    'CXO': 'America/Chicago',
    'CXP': 'Asia/Jakarta',
    'CXR': 'Asia/Saigon',
    'CYA': 'America/Port-au-Prince',
    'CYB': 'America/Cayman',
    'CYF': 'America/Anchorage',
    'CYI': 'Asia/Taipei',
    'CYO': 'America/Havana',
    'CYP': 'Asia/Manila',
    'CYR': 'America/Montevideo',
    'CYS': 'America/Denver',
    'CYT': 'America/Anchorage',
    'CYU': 'Asia/Manila',
    'CYW': 'America/Mexico_City',
    'CYX': 'Asia/Srednekolymsk',
    'CYZ': 'Asia/Manila',
    'CZA': 'America/Mexico_City',
    'CZE': 'America/Caracas',
    'CZF': 'America/Anchorage',
    'CZL': 'Africa/Algiers',
    'CZM': 'America/Cancun',
    'CZS': 'America/Rio_Branco',
    'CZU': 'America/Bogota',
    'CZX': 'Asia/Shanghai',
    'DAB': 'America/New_York',
    'DAC': 'Asia/Dhaka',
    'DAD': 'Asia/Saigon',
    'DAL': 'America/Chicago',
    'DAM': 'Asia/Damascus',
    'DAN': 'America/New_York',
    'DAR': 'Africa/Dar_es_Salaam',
    'DAT': 'Asia/Shanghai',
    'DAU': 'Pacific/Port_Moresby',
    'DAV': 'America/Panama',
    'DAX': 'Asia/Shanghai',
    'DAY': 'America/New_York',
    'DBA': 'Asia/Karachi',
    'DBB': 'Africa/Cairo',
    'DBD': 'Asia/Calcutta',
    'DBM': 'Africa/Addis_Ababa',
    'DBN': 'America/New_York',
    'DBO': 'Australia/Sydney',
    'DBQ': 'America/Chicago',
    'DBT': 'Africa/Addis_Ababa',
    'DBV': 'Europe/Zagreb',
    'DCA': 'America/New_York',
    'DCF': 'America/Dominica',
    'DCI': 'Europe/Rome',
    'DCM': 'Europe/Paris',
    'DCT': 'America/Nassau',
    'DCY': 'Asia/Shanghai',
    'DDC': 'America/Chicago',
    'DDG': 'Asia/Shanghai',
    'DEA': 'Asia/Karachi',
    'DEB': 'Europe/Budapest',
    'DEC': 'America/Chicago',
    'DED': 'Asia/Calcutta',
    'DEF': 'Asia/Tehran',
    'DEL': 'Asia/Calcutta',
    'DEM': 'Africa/Addis_Ababa',
    'DEN': 'America/Denver',
    'DES': 'Indian/Mahe',
    'DET': 'America/New_York',
    'DEZ': 'Asia/Damascus',
    'DFW': 'America/Chicago',
    'DGE': 'Australia/Sydney',
    'DGL': 'America/Phoenix',
    'DGO': 'America/Mexico_City',
    'DGT': 'Asia/Manila',
    'DHA': 'Asia/Riyadh',
    'DHF': 'Asia/Dubai',
    'DHI': 'Asia/Katmandu',
    'DHM': 'Asia/Calcutta',
    'DHN': 'America/Chicago',
    'DHR': 'Europe/Amsterdam',
    'DHT': 'America/Chicago',
    'DIA': 'Asia/Qatar',
    'DIB': 'Asia/Calcutta',
    'DIE': 'Indian/Antananarivo',
    'DIG': 'Asia/Shanghai',
    'DIJ': 'Europe/Paris',
    'DIK': 'America/Denver',
    'DIL': 'Asia/Dili',
    'DIN': 'Asia/Saigon',
    'DIR': 'Africa/Addis_Ababa',
    'DIS': 'Africa/Brazzaville',
    'DIU': 'Asia/Calcutta',
    'DIY': 'Europe/Istanbul',
    'DJB': 'Asia/Jakarta',
    'DJE': 'Africa/Tunis',
    'DJG': 'Africa/Algiers',
    'DJJ': 'Asia/Jayapura',
    'DJO': 'Africa/Abidjan',
    'DKI': 'Australia/Brisbane',
    'DKK': 'America/New_York',
    'DKR': 'Africa/Dakar',
    'DKS': 'Asia/Krasnoyarsk',
    'DLA': 'Africa/Douala',
    'DLC': 'Asia/Shanghai',
    'DLD': 'Europe/Oslo',
    'DLE': 'Europe/Paris',
    'DLF': 'America/Chicago',
    'DLG': 'America/Anchorage',
    'DLH': 'America/Chicago',
    'DLI': 'Asia/Saigon',
    'DLM': 'Europe/Istanbul',
    'DLS': 'America/Los_Angeles',
    'DLU': 'Asia/Shanghai',
    'DLY': 'Pacific/Efate',
    'DLZ': 'Asia/Ulaanbaatar',
    'DMA': 'America/Phoenix',
    'DMB': 'Asia/Qyzylorda',
    'DMD': 'Australia/Brisbane',
    'DME': 'Europe/Moscow',
    'DMK': 'Asia/Bangkok',
    'DMM': 'Asia/Riyadh',
    'DMT': 'America/Campo_Grande',
    'DMU': 'Asia/Calcutta',
    'DNA': 'Asia/Tokyo',
    'DND': 'Europe/London',
    'DNH': 'Asia/Shanghai',
    'DNK': 'Europe/Kiev',
    'DNL': 'America/New_York',
    'DNN': 'America/New_York',
    'DNP': 'Asia/Katmandu',
    'DNR': 'Europe/Paris',
    'DNV': 'America/Chicago',
    'DNZ': 'Europe/Istanbul',
    'DOD': 'Africa/Dar_es_Salaam',
    'DOG': 'Africa/Khartoum',
    'DOK': 'Europe/Kiev',
    'DOL': 'Europe/Paris',
    'DOM': 'America/Dominica',
    'DOP': 'Asia/Katmandu',
    'DOU': 'America/Campo_Grande',
    'DOV': 'America/New_York',
    'DOY': 'Asia/Shanghai',
    'DPA': 'America/Chicago',
    'DPL': 'Asia/Manila',
    'DPO': 'Australia/Melbourne',
    'DPS': 'Asia/Makassar',
    'DQA': 'Asia/Shanghai',
    'DRB': 'Australia/Perth',
    'DRE': 'America/New_York',
    'DRG': 'America/Anchorage',
    'DRI': 'America/Chicago',
    'DRJ': 'America/Paramaribo',
    'DRK': 'America/Costa_Rica',
    'DRO': 'America/Denver',
    'DRS': 'Europe/Berlin',
    'DRT': 'America/Chicago',
    'DRW': 'Australia/Darwin',
    'DSA': 'Europe/London',
    'DSD': 'America/Guadeloupe',
    'DSE': 'Africa/Addis_Ababa',
    'DSI': 'America/Chicago',
    'DSK': 'Asia/Karachi',
    'DSM': 'America/Chicago',
    'DSN': 'Asia/Shanghai',
    'DSO': 'Asia/Pyongyang',
    'DTA': 'America/Denver',
    'DTB': 'Asia/Jakarta',
    'DTD': 'Asia/Makassar',
    'DTE': 'Asia/Manila',
    'DTI': 'America/Sao_Paulo',
    'DTM': 'Europe/Berlin',
    'DTN': 'America/Chicago',
    'DTW': 'America/New_York',
    'DUB': 'Europe/Dublin',
    'DUC': 'America/Chicago',
    'DUD': 'Pacific/Auckland',
    'DUE': 'Africa/Luanda',
    'DUG': 'America/Phoenix',
    'DUJ': 'America/New_York',
    'DUM': 'Asia/Jakarta',
    'DUR': 'Africa/Johannesburg',
    'DUS': 'Europe/Berlin',
    'DUT': 'America/Anchorage',
    'DVL': 'America/Chicago',
    'DVO': 'Asia/Manila',
    'DVT': 'America/Phoenix',
    'DWB': 'Indian/Antananarivo',
    'DWC': 'Asia/Dubai',
    'DWH': 'America/Chicago',
    'DXB': 'Asia/Dubai',
    'DXR': 'America/New_York',
    'DYG': 'Asia/Shanghai',
    'DYL': 'America/New_York',
    'DYR': 'Asia/Anadyr',
    'DYS': 'America/Chicago',
    'DYU': 'Asia/Dushanbe',
    'DZA': 'Indian/Mayotte',
    'DZN': 'Asia/Qyzylorda',
    'DZO': 'America/Montevideo',
    'EAA': 'America/Anchorage',
    'EAE': 'Pacific/Efate',
    'EAM': 'Asia/Riyadh',
    'EAS': 'Europe/Madrid',
    'EAT': 'America/Los_Angeles',
    'EAU': 'America/Chicago',
    'EBA': 'Europe/Rome',
    'EBB': 'Africa/Kampala',
    'EBD': 'Africa/Khartoum',
    'EBG': 'America/Bogota',
    'EBJ': 'Europe/Copenhagen',
    'EBL': 'Asia/Baghdad',
    'EBM': 'Africa/Tunis',
    'EBU': 'Europe/Paris',
    'ECA': 'America/New_York',
    'ECG': 'America/New_York',
    'ECN': 'Asia/Nicosia',
    'ECP': 'America/Chicago',
    'EDF': 'America/Anchorage',
    'EDI': 'Europe/London',
    'EDL': 'Africa/Nairobi',
    'EDM': 'Europe/Paris',
    'EDO': 'Europe/Istanbul',
    'EDR': 'Australia/Brisbane',
    'EDW': 'America/Los_Angeles',
    'EEK': 'America/Anchorage',
    'EEN': 'America/New_York',
    'EFD': 'America/Chicago',
    'EFL': 'Europe/Athens',
    'EGC': 'Europe/Paris',
    'EGE': 'America/Denver',
    'EGH': 'Africa/Cairo',
    'EGM': 'Pacific/Guadalcanal',
    'EGN': 'Africa/Khartoum',
    'EGO': 'Europe/Moscow',
    'EGS': 'Atlantic/Reykjavik',
    'EGV': 'America/Chicago',
    'EGX': 'America/Anchorage',
    'EHL': 'America/Argentina/Salta',
    'EHM': 'America/Anchorage',
    'EIB': 'Europe/Berlin',
    'EIE': 'Asia/Krasnoyarsk',
    'EIK': 'Europe/Moscow',
    'EIL': 'America/Anchorage',
    'EIN': 'Europe/Amsterdam',
    'EIS': 'America/Tortola',
    'EIY': 'Asia/Jerusalem',
    'EJA': 'America/Bogota',
    'EJH': 'Asia/Riyadh',
    'EKB': 'Asia/Qyzylorda',
    'EKN': 'America/New_York',
    'EKO': 'America/Los_Angeles',
    'EKT': 'Europe/Stockholm',
    'ELB': 'America/Bogota',
    'ELC': 'Australia/Darwin',
    'ELD': 'America/Chicago',
    'ELF': 'Africa/Khartoum',
    'ELG': 'Africa/Algiers',
    'ELH': 'America/Nassau',
    'ELI': 'America/Anchorage',
    'ELM': 'America/New_York',
    'ELO': 'America/Cordoba',
    'ELP': 'America/Denver',
    'ELQ': 'Asia/Riyadh',
    'ELS': 'Africa/Johannesburg',
    'ELT': 'Africa/Cairo',
    'ELU': 'Africa/Algiers',
    'ELV': 'America/Anchorage',
    'ELY': 'America/Los_Angeles',
    'EMA': 'Europe/London',
    'EMD': 'Australia/Brisbane',
    'EME': 'Europe/Berlin',
    'EMK': 'America/Anchorage',
    'EML': 'Europe/Zurich',
    'EMN': 'Africa/Nouakchott',
    'EMP': 'America/Chicago',
    'ENA': 'America/Anchorage',
    'ENC': 'Europe/Paris',
    'END': 'America/Chicago',
    'ENE': 'Asia/Makassar',
    'ENF': 'Europe/Helsinki',
    'ENH': 'Asia/Shanghai',
    'ENK': 'Europe/London',
    'ENS': 'Europe/Amsterdam',
    'ENT': 'Pacific/Majuro',
    'ENU': 'Africa/Lagos',
    'ENV': 'America/Denver',
    'ENW': 'America/Chicago',
    'ENY': 'Asia/Shanghai',
    'EOH': 'America/Bogota',
    'EOI': 'Europe/London',
    'EOK': 'America/Chicago',
    'EOR': 'America/Caracas',
    'EOZ': 'America/Caracas',
    'EPA': 'America/Buenos_Aires',
    'EPL': 'Europe/Paris',
    'EPR': 'Australia/Perth',
    'EPU': 'Europe/Tallinn',
    'EQS': 'America/Catamarca',
    'ERC': 'Europe/Istanbul',
    'ERF': 'Europe/Berlin',
    'ERG': 'Asia/Irkutsk',
    'ERH': 'Africa/Casablanca',
    'ERI': 'America/New_York',
    'ERM': 'America/Sao_Paulo',
    'ERN': 'America/Boa_Vista',
    'ERS': 'Africa/Windhoek',
    'ERV': 'America/Chicago',
    'ERZ': 'Europe/Istanbul',
    'ESB': 'Europe/Istanbul',
    'ESC': 'America/New_York',
    'ESD': 'America/Los_Angeles',
    'ESE': 'America/Tijuana',
    'ESF': 'America/Chicago',
    'ESG': 'America/Asuncion',
    'ESH': 'Europe/London',
    'ESK': 'Europe/Istanbul',
    'ESL': 'Europe/Moscow',
    'ESM': 'America/Guayaquil',
    'ESN': 'America/New_York',
    'ESR': 'America/Santiago',
    'ESS': 'Europe/Berlin',
    'ESU': 'Africa/Casablanca',
    'ETH': 'Asia/Jerusalem',
    'ETR': 'America/Guayaquil',
    'ETZ': 'Europe/Paris',
    'EUA': 'Pacific/Tongatapu',
    'EUF': 'America/Chicago',
    'EUG': 'America/Los_Angeles',
    'EUM': 'Europe/Berlin',
    'EUN': 'Africa/El_Aaiun',
    'EUQ': 'Asia/Manila',
    'EUX': 'America/Curacao',
    'EVE': 'Europe/Oslo',
    'EVG': 'Europe/Stockholm',
    'EVN': 'Asia/Yerevan',
    'EVV': 'America/Chicago',
    'EVW': 'America/Denver',
    'EVX': 'Europe/Paris',
    'EWB': 'America/New_York',
    'EWK': 'America/Chicago',
    'EWN': 'America/New_York',
    'EWR': 'America/New_York',
    'EXT': 'Europe/London',
    'EYK': 'Asia/Yekaterinburg',
    'EYP': 'America/Bogota',
    'EYW': 'America/New_York',
    'EZE': 'America/Buenos_Aires',
    'EZS': 'Europe/Istanbul',
    'EZV': 'Asia/Yekaterinburg',
    'FAA': 'Africa/Conakry',
    'FAB': 'Europe/London',
    'FAE': 'Atlantic/Faeroe',
    'FAF': 'America/New_York',
    'FAI': 'America/Anchorage',
    'FAJ': 'America/Puerto_Rico',
    'FAN': 'Europe/Oslo',
    'FAO': 'Europe/Lisbon',
    'FAR': 'America/Chicago',
    'FAT': 'America/Los_Angeles',
    'FAV': 'Pacific/Tahiti',
    'FAY': 'America/New_York',
    'FAZ': 'Asia/Tehran',
    'FBA': 'America/Boa_Vista',
    'FBD': 'Asia/Kabul',
    'FBE': 'America/Sao_Paulo',
    'FBG': 'America/New_York',
    'FBK': 'America/Anchorage',
    'FBM': 'Africa/Lubumbashi',
    'FBR': 'America/Denver',
    'FBU': 'Europe/Oslo',
    'FCA': 'America/Denver',
    'FCB': 'Africa/Johannesburg',
    'FCM': 'America/Chicago',
    'FCN': 'Europe/Berlin',
    'FCO': 'Europe/Rome',
    'FCS': 'America/Denver',
    'FDF': 'America/Martinique',
    'FDH': 'Europe/Berlin',
    'FDO': 'America/Buenos_Aires',
    'FDU': 'Africa/Kinshasa',
    'FDY': 'America/New_York',
    'FEG': 'Asia/Samarkand',
    'FEL': 'Europe/Berlin',
    'FEN': 'America/Fortaleza',
    'FEZ': 'Africa/Casablanca',
    'FFA': 'America/New_York',
    'FFD': 'Europe/London',
    'FFO': 'America/New_York',
    'FFT': 'America/New_York',
    'FFU': 'America/Santiago',
    'FGI': 'Pacific/Apia',
    'FGU': 'Pacific/Tahiti',
    'FHU': 'America/Phoenix',
    'FIE': 'Europe/London',
    'FIG': 'Africa/Conakry',
    'FIH': 'Africa/Kinshasa',
    'FIZ': 'Australia/Perth',
    'FJR': 'Asia/Dubai',
    'FKB': 'Europe/Berlin',
    'FKI': 'Africa/Lubumbashi',
    'FKJ': 'Asia/Tokyo',
    'FKL': 'America/New_York',
    'FKQ': 'Asia/Jayapura',
    'FKS': 'Asia/Tokyo',
    'FLA': 'America/Bogota',
    'FLD': 'America/Chicago',
    'FLF': 'Europe/Berlin',
    'FLG': 'America/Phoenix',
    'FLL': 'America/New_York',
    'FLN': 'America/Sao_Paulo',
    'FLO': 'America/New_York',
    'FLR': 'Europe/Rome',
    'FLS': 'Australia/Melbourne',
    'FLV': 'America/Chicago',
    'FLW': 'Atlantic/Azores',
    'FLZ': 'Asia/Jakarta',
    'FMA': 'America/Cordoba',
    'FME': 'America/New_York',
    'FMH': 'America/New_York',
    'FMI': 'Africa/Lubumbashi',
    'FMM': 'Europe/Berlin',
    'FMN': 'America/Denver',
    'FMO': 'Europe/Berlin',
    'FMY': 'America/New_York',
    'FNA': 'Africa/Freetown',
    'FNC': 'Europe/Lisbon',
    'FNI': 'Europe/Paris',
    'FNJ': 'Asia/Pyongyang',
    'FNL': 'America/Denver',
    'FNR': 'America/Anchorage',
    'FNT': 'America/New_York',
    'FNU': 'Europe/Rome',
    'FOC': 'Asia/Shanghai',
    'FOD': 'America/Chicago',
    'FOE': 'America/Chicago',
    'FOG': 'Europe/Rome',
    'FOK': 'America/New_York',
    'FOM': 'Africa/Douala',
    'FON': 'America/Costa_Rica',
    'FOR': 'America/Fortaleza',
    'FOS': 'Australia/Perth',
    'FPO': 'America/Nassau',
    'FPR': 'America/New_York',
    'FRA': 'Europe/Berlin',
    'FRC': 'America/Sao_Paulo',
    'FRD': 'America/Los_Angeles',
    'FRE': 'Pacific/Guadalcanal',
    'FRG': 'America/New_York',
    'FRI': 'America/Chicago',
    'FRJ': 'Europe/Paris',
    'FRL': 'Europe/Rome',
    'FRN': 'America/Anchorage',
    'FRO': 'Europe/Oslo',
    'FRS': 'America/Guatemala',
    'FRU': 'Asia/Bishkek',
    'FRW': 'Africa/Gaborone',
    'FRY': 'America/New_York',
    'FRZ': 'Europe/Berlin',
    'FSC': 'Europe/Paris',
    'FSD': 'America/Chicago',
    'FSI': 'America/Chicago',
    'FSM': 'America/Chicago',
    'FSP': 'America/Miquelon',
    'FST': 'America/Chicago',
    'FTA': 'Pacific/Efate',
    'FTE': 'America/Argentina/Rio_Gallegos',
    'FTI': 'Pacific/Pago_Pago',
    'FTK': 'America/New_York',
    'FTU': 'Indian/Antananarivo',
    'FTW': 'America/Chicago',
    'FTX': 'Africa/Brazzaville',
    'FTY': 'America/New_York',
    'FUE': 'Atlantic/Canary',
    'FUG': 'Asia/Shanghai',
    'FUJ': 'Asia/Tokyo',
    'FUK': 'Asia/Tokyo',
    'FUL': 'America/Los_Angeles',
    'FUN': 'Pacific/Funafuti',
    'FUO': 'Asia/Shanghai',
    'FUT': 'Pacific/Wallis',
    'FWA': 'America/New_York',
    'FWH': 'America/Chicago',
    'FXE': 'America/New_York',
    'FXO': 'Africa/Maputo',
    'FYT': 'Africa/Ndjamena',
    'FYU': 'America/Anchorage',
    'FYV': 'America/Chicago',
    'FZO': 'Europe/London',
    'GAD': 'America/Chicago',
    'GAE': 'Africa/Tunis',
    'GAF': 'Africa/Tunis',
    'GAH': 'Australia/Brisbane',
    'GAI': 'America/New_York',
    'GAJ': 'Asia/Tokyo',
    'GAL': 'America/Anchorage',
    'GAM': 'America/Anchorage',
    'GAN': 'Indian/Maldives',
    'GAO': 'America/Havana',
    'GAQ': 'Africa/Bamako',
    'GAS': 'Africa/Nairobi',
    'GAU': 'Asia/Calcutta',
    'GAY': 'Asia/Calcutta',
    'GBA': 'Europe/London',
    'GBB': 'Asia/Baku',
    'GBD': 'America/Chicago',
    'GBE': 'Africa/Gaborone',
    'GBJ': 'America/Guadeloupe',
    'GBK': 'Africa/Freetown',
    'GBT': 'Asia/Tehran',
    'GBZ': 'Pacific/Auckland',
    'GCC': 'America/Denver',
    'GCH': 'Asia/Tehran',
    'GCI': 'Europe/Guernsey',
    'GCJ': 'Africa/Johannesburg',
    'GCK': 'America/Chicago',
    'GCM': 'America/Cayman',
    'GCN': 'America/Phoenix',
    'GDE': 'Africa/Addis_Ababa',
    'GDL': 'America/Mexico_City',
    'GDN': 'Europe/Warsaw',
    'GDO': 'America/Caracas',
    'GDQ': 'Africa/Addis_Ababa',
    'GDT': 'America/Grand_Turk',
    'GDV': 'America/Denver',
    'GDW': 'America/New_York',
    'GDX': 'Asia/Srednekolymsk',
    'GDZ': 'Europe/Moscow',
    'GEA': 'Pacific/Noumea',
    'GED': 'America/New_York',
    'GEG': 'America/Los_Angeles',
    'GEL': 'America/Sao_Paulo',
    'GEO': 'America/Guyana',
    'GER': 'America/Havana',
    'GES': 'Asia/Manila',
    'GET': 'Australia/Perth',
    'GEV': 'Europe/Stockholm',
    'GEX': 'Australia/Hobart',
    'GFF': 'Australia/Sydney',
    'GFK': 'America/Chicago',
    'GFL': 'America/New_York',
    'GFN': 'Australia/Sydney',
    'GFO': 'America/Guyana',
    'GFR': 'Europe/Paris',
    'GFY': 'Africa/Windhoek',
    'GGE': 'America/New_York',
    'GGG': 'America/Chicago',
    'GGM': 'Africa/Nairobi',
    'GGS': 'America/Argentina/Rio_Gallegos',
    'GGT': 'America/Nassau',
    'GGW': 'America/Denver',
    'GHA': 'Africa/Algiers',
    'GHB': 'America/Nassau',
    'GHC': 'America/Nassau',
    'GHF': 'Europe/Berlin',
    'GHT': 'Africa/Tripoli',
    'GHU': 'America/Cordoba',
    'GIB': 'Europe/Gibraltar',
    'GIC': 'Australia/Brisbane',
    'GIF': 'America/New_York',
    'GIG': 'America/Sao_Paulo',
    'GIL': 'Asia/Karachi',
    'GIR': 'America/Bogota',
    'GIS': 'Pacific/Auckland',
    'GIU': 'Asia/Colombo',
    'GIZ': 'Asia/Riyadh',
    'GJA': 'America/Tegucigalpa',
    'GJL': 'Africa/Algiers',
    'GJM': 'America/Boa_Vista',
    'GJR': 'Atlantic/Reykjavik',
    'GJT': 'America/Denver',
    'GKA': 'Pacific/Port_Moresby',
    'GKE': 'Europe/Berlin',
    'GKK': 'Indian/Maldives',
    'GKL': 'Australia/Brisbane',
    'GKN': 'America/Anchorage',
    'GLA': 'Europe/London',
    'GLD': 'America/Denver',
    'GLF': 'America/Costa_Rica',
    'GLH': 'America/Chicago',
    'GLI': 'Australia/Sydney',
    'GLK': 'Africa/Mogadishu',
    'GLO': 'Europe/London',
    'GLS': 'America/Chicago',
    'GLT': 'Australia/Brisbane',
    'GLV': 'America/Anchorage',
    'GLZ': 'Europe/Amsterdam',
    'GMA': 'Africa/Kinshasa',
    'GMB': 'Africa/Addis_Ababa',
    'GMD': 'Africa/Casablanca',
    'GME': 'Europe/Minsk',
    'GML': 'Europe/Kiev',
    'GMP': 'Asia/Seoul',
    'GMR': 'Pacific/Gambier',
    'GMV': 'America/Denver',
    'GMZ': 'Atlantic/Canary',
    'GNA': 'Europe/Minsk',
    'GNB': 'Europe/Paris',
    'GND': 'America/Grenada',
    'GNI': 'Asia/Taipei',
    'GNM': 'America/Fortaleza',
    'GNR': 'America/Argentina/Salta',
    'GNS': 'Asia/Jakarta',
    'GNT': 'America/Denver',
    'GNV': 'America/New_York',
    'GNY': 'Europe/Istanbul',
    'GNZ': 'Africa/Gaborone',
    'GOA': 'Europe/Rome',
    'GOB': 'Africa/Addis_Ababa',
    'GOH': 'America/Godthab',
    'GOI': 'Asia/Calcutta',
    'GOJ': 'Europe/Moscow',
    'GOM': 'Africa/Kigali',
    'GON': 'America/New_York',
    'GOP': 'Asia/Calcutta',
    'GOQ': 'Asia/Shanghai',
    'GOR': 'Africa/Addis_Ababa',
    'GOT': 'Europe/Stockholm',
    'GOU': 'Africa/Douala',
    'GOV': 'Australia/Darwin',
    'GOZ': 'Europe/Sofia',
    'GPA': 'Europe/Athens',
    'GPB': 'America/Sao_Paulo',
    'GPI': 'America/Bogota',
    'GPL': 'America/Costa_Rica',
    'GPO': 'America/Argentina/Salta',
    'GPS': 'Pacific/Galapagos',
    'GPT': 'America/Chicago',
    'GPZ': 'America/Chicago',
    'GQQ': 'America/New_York',
    'GRB': 'America/Chicago',
    'GRF': 'America/Los_Angeles',
    'GRI': 'America/Chicago',
    'GRJ': 'Africa/Johannesburg',
    'GRK': 'America/Chicago',
    'GRM': 'America/Chicago',
    'GRO': 'Europe/Madrid',
    'GRP': 'America/Fortaleza',
    'GRQ': 'Europe/Amsterdam',
    'GRR': 'America/New_York',
    'GRS': 'Europe/Rome',
    'GRU': 'America/Sao_Paulo',
    'GRW': 'Atlantic/Azores',
    'GRX': 'Europe/Madrid',
    'GRY': 'Atlantic/Reykjavik',
    'GRZ': 'Europe/Vienna',
    'GSB': 'America/New_York',
    'GSE': 'Europe/Stockholm',
    'GSI': 'America/Cayenne',
    'GSJ': 'America/Guatemala',
    'GSO': 'America/New_York',
    'GSP': 'America/New_York',
    'GSQ': 'Africa/Cairo',
    'GST': 'America/Anchorage',
    'GTE': 'Australia/Darwin',
    'GTF': 'America/Denver',
    'GTI': 'Europe/Berlin',
    'GTN': 'Pacific/Auckland',
    'GTO': 'Asia/Makassar',
    'GTR': 'America/Chicago',
    'GUA': 'America/Guatemala',
    'GUB': 'America/Tijuana',
    'GUC': 'America/Denver',
    'GUF': 'America/Chicago',
    'GUI': 'America/Caracas',
    'GUJ': 'America/Sao_Paulo',
    'GUL': 'Australia/Sydney',
    'GUM': 'Pacific/Guam',
    'GUP': 'America/Denver',
    'GUQ': 'America/Caracas',
    'GUR': 'Pacific/Port_Moresby',
    'GUS': 'America/New_York',
    'GUT': 'Europe/Berlin',
    'GUW': 'Asia/Oral',
    'GUX': 'Asia/Calcutta',
    'GVA': 'Europe/Paris',
    'GVL': 'America/New_York',
    'GVR': 'America/Sao_Paulo',
    'GVT': 'America/Chicago',
    'GVX': 'Europe/Stockholm',
    'GWD': 'Asia/Karachi',
    'GWE': 'Africa/Harare',
    'GWL': 'Asia/Calcutta',
    'GWO': 'America/Chicago',
    'GWT': 'Europe/Berlin',
    'GWY': 'Europe/Dublin',
    'GXF': 'Asia/Aden',
    'GXG': 'Africa/Luanda',
    'GXH': 'Asia/Shanghai',
    'GXQ': 'America/Santiago',
    'GYA': 'America/La_Paz',
    'GYD': 'Asia/Baku',
    'GYE': 'America/Guayaquil',
    'GYG': 'Asia/Yakutsk',
    'GYI': 'Africa/Kigali',
    'GYL': 'Australia/Perth',
    'GYM': 'America/Hermosillo',
    'GYN': 'America/Sao_Paulo',
    'GYR': 'America/Phoenix',
    'GYS': 'Asia/Shanghai',
    'GYU': 'Asia/Shanghai',
    'GYY': 'America/Chicago',
    'GZA': 'Asia/Gaza',
    'GZM': 'Europe/Malta',
    'GZO': 'Pacific/Guadalcanal',
    'GZP': 'Europe/Istanbul',
    'GZT': 'Europe/Istanbul',
    'GZW': 'Asia/Tehran',
    'HAA': 'Europe/Oslo',
    'HAC': 'Asia/Tokyo',
    'HAD': 'Europe/Stockholm',
    'HAH': 'Indian/Comoro',
    'HAJ': 'Europe/Berlin',
    'HAK': 'Asia/Shanghai',
    'HAM': 'Europe/Berlin',
    'HAN': 'Asia/Saigon',
    'HAO': 'America/New_York',
    'HAQ': 'Indian/Maldives',
    'HAR': 'America/New_York',
    'HAS': 'Asia/Riyadh',
    'HAU': 'Europe/Oslo',
    'HAV': 'America/Havana',
    'HAW': 'Europe/London',
    'HBA': 'Australia/Melbourne',
    'HBE': 'Africa/Cairo',
    'HBG': 'America/Chicago',
    'HBR': 'America/Chicago',
    'HBX': 'Asia/Calcutta',
    'HCN': 'Asia/Taipei',
    'HCQ': 'Australia/Perth',
    'HCR': 'America/Anchorage',
    'HCW': 'America/New_York',
    'HDD': 'Asia/Karachi',
    'HDF': 'Europe/Berlin',
    'HDG': 'Asia/Shanghai',
    'HDH': 'Pacific/Honolulu',
    'HDI': 'America/New_York',
    'HDM': 'Asia/Tehran',
    'HDN': 'America/Denver',
    'HDR': 'Asia/Tehran',
    'HDS': 'Africa/Johannesburg',
    'HDY': 'Asia/Bangkok',
    'HEA': 'Asia/Kabul',
    'HEH': 'Asia/Rangoon',
    'HEI': 'Europe/Berlin',
    'HEK': 'Asia/Shanghai',
    'HEL': 'Europe/Helsinki',
    'HEM': 'Europe/Helsinki',
    'HER': 'Europe/Athens',
    'HET': 'Asia/Shanghai',
    'HEW': 'Europe/Athens',
    'HEX': 'America/Santo_Domingo',
    'HFA': 'Asia/Jerusalem',
    'HFD': 'America/New_York',
    'HFE': 'Asia/Shanghai',
    'HFN': 'Atlantic/Reykjavik',
    'HFS': 'Europe/Stockholm',
    'HFT': 'Europe/Oslo',
    'HGA': 'Africa/Mogadishu',
    'HGD': 'Australia/Brisbane',
    'HGE': 'America/Caracas',
    'HGH': 'Asia/Shanghai',
    'HGL': 'Europe/Berlin',
    'HGN': 'Asia/Bangkok',
    'HGO': 'Africa/Abidjan',
    'HGR': 'America/New_York',
    'HGS': 'Africa/Freetown',
    'HGU': 'Pacific/Port_Moresby',
    'HHE': 'Asia/Tokyo',
    'HHH': 'America/New_York',
    'HHI': 'Pacific/Honolulu',
    'HHN': 'Europe/Berlin',
    'HHP': 'Asia/Hong_Kong',
    'HHQ': 'Asia/Bangkok',
    'HHR': 'America/Los_Angeles',
    'HIA': 'Asia/Shanghai',
    'HIB': 'America/Chicago',
    'HID': 'Australia/Brisbane',
    'HIF': 'America/Denver',
    'HII': 'America/Phoenix',
    'HIJ': 'Asia/Tokyo',
    'HIN': 'Asia/Seoul',
    'HIO': 'America/Los_Angeles',
    'HIR': 'Pacific/Guadalcanal',
    'HIW': 'Asia/Tokyo',
    'HJJ': 'Asia/Shanghai',
    'HJR': 'Asia/Calcutta',
    'HKD': 'Asia/Tokyo',
    'HKG': 'Asia/Hong_Kong',
    'HKK': 'Pacific/Auckland',
    'HKN': 'Pacific/Port_Moresby',
    'HKT': 'Asia/Bangkok',
    'HKY': 'America/New_York',
    'HLA': 'Africa/Johannesburg',
    'HLD': 'Asia/Shanghai',
    'HLF': 'Europe/Stockholm',
    'HLG': 'America/New_York',
    'HLH': 'Asia/Shanghai',
    'HLJ': 'Europe/Vilnius',
    'HLN': 'America/Denver',
    'HLP': 'Asia/Jakarta',
    'HLR': 'America/Chicago',
    'HLT': 'Australia/Hobart',
    'HLZ': 'Pacific/Auckland',
    'HMA': 'Asia/Yekaterinburg',
    'HMB': 'Africa/Cairo',
    'HME': 'Africa/Algiers',
    'HMI': 'Asia/Shanghai',
    'HMJ': 'Europe/Kiev',
    'HMN': 'America/Denver',
    'HMO': 'America/Hermosillo',
    'HMR': 'Europe/Oslo',
    'HMV': 'Europe/Stockholm',
    'HNA': 'Asia/Tokyo',
    'HND': 'Asia/Tokyo',
    'HNH': 'America/Anchorage',
    'HNL': 'Pacific/Honolulu',
    'HNM': 'Pacific/Honolulu',
    'HNS': 'America/Anchorage',
    'HOA': 'Africa/Nairobi',
    'HOB': 'America/Denver',
    'HOD': 'Asia/Aden',
    'HOE': 'Asia/Vientiane',
    'HOF': 'Asia/Riyadh',
    'HOG': 'America/Havana',
    'HOH': 'Europe/Vienna',
    'HOK': 'Australia/Darwin',
    'HOM': 'America/Anchorage',
    'HON': 'America/Chicago',
    'HOP': 'America/Chicago',
    'HOQ': 'Europe/Berlin',
    'HOR': 'Atlantic/Azores',
    'HOS': 'America/Argentina/Salta',
    'HOT': 'America/Chicago',
    'HOU': 'America/Chicago',
    'HOV': 'Europe/Oslo',
    'HOX': 'Asia/Rangoon',
    'HPA': 'Pacific/Tongatapu',
    'HPB': 'America/Anchorage',
    'HPH': 'Asia/Saigon',
    'HPN': 'America/New_York',
    'HQM': 'America/Los_Angeles',
    'HRB': 'Asia/Shanghai',
    'HRE': 'Africa/Harare',
    'HRG': 'Africa/Cairo',
    'HRI': 'Asia/Colombo',
    'HRK': 'Europe/Kiev',
    'HRL': 'America/Chicago',
    'HRM': 'Africa/Algiers',
    'HRO': 'America/Chicago',
    'HRS': 'Africa/Johannesburg',
    'HRT': 'Europe/London',
    'HSG': 'Asia/Tokyo',
    'HSH': 'America/Los_Angeles',
    'HSK': 'Europe/Madrid',
    'HSL': 'America/Anchorage',
    'HSN': 'Asia/Shanghai',
    'HSS': 'Asia/Calcutta',
    'HST': 'America/New_York',
    'HSV': 'America/Chicago',
    'HSZ': 'Asia/Taipei',
    'HTA': 'Asia/Yakutsk',
    'HTG': 'Asia/Krasnoyarsk',
    'HTI': 'Australia/Brisbane',
    'HTL': 'America/New_York',
    'HTN': 'Asia/Shanghai',
    'HTS': 'America/New_York',
    'HTY': 'Europe/Istanbul',
    'HUA': 'America/Chicago',
    'HUE': 'Africa/Addis_Ababa',
    'HUF': 'America/New_York',
    'HUH': 'Pacific/Tahiti',
    'HUI': 'Asia/Saigon',
    'HUL': 'America/New_York',
    'HUN': 'Asia/Taipei',
    'HUQ': 'Africa/Tripoli',
    'HUS': 'America/Anchorage',
    'HUT': 'America/Chicago',
    'HUU': 'America/Lima',
    'HUV': 'Europe/Stockholm',
    'HUW': 'America/Boa_Vista',
    'HUX': 'America/Mexico_City',
    'HUY': 'Europe/London',
    'HUZ': 'Asia/Shanghai',
    'HVA': 'Indian/Antananarivo',
    'HVB': 'Australia/Brisbane',
    'HVD': 'Asia/Hovd',
    'HVG': 'Europe/Oslo',
    'HVN': 'America/New_York',
    'HVR': 'America/Denver',
    'HWD': 'America/Los_Angeles',
    'HWN': 'Africa/Harare',
    'HWO': 'America/New_York',
    'HYA': 'America/New_York',
    'HYC': 'Europe/London',
    'HYG': 'America/Anchorage',
    'HYN': 'Asia/Shanghai',
    'HYS': 'America/Chicago',
    'HYV': 'Europe/Helsinki',
    'HZB': 'Europe/Paris',
    'HZG': 'Asia/Shanghai',
    'HZH': 'Asia/Shanghai',
    'HZK': 'Atlantic/Reykjavik',
    'HZL': 'America/New_York',
    'IAA': 'Asia/Krasnoyarsk',
    'IAB': 'America/Chicago',
    'IAD': 'America/New_York',
    'IAG': 'America/New_York',
    'IAH': 'America/Chicago',
    'IAM': 'Africa/Algiers',
    'IAN': 'America/Anchorage',
    'IAO': 'Asia/Manila',
    'IAR': 'Europe/Moscow',
    'IAS': 'Europe/Bucharest',
    'IBA': 'Africa/Lagos',
    'IBB': 'Pacific/Galapagos',
    'IBE': 'America/Bogota',
    'IBP': 'America/Lima',
    'IBR': 'Asia/Tokyo',
    'IBZ': 'Europe/Madrid',
    'ICC': 'America/Caracas',
    'ICI': 'Pacific/Fiji',
    'ICK': 'America/Paramaribo',
    'ICN': 'Asia/Seoul',
    'ICT': 'America/Chicago',
    'IDA': 'America/Denver',
    'IDR': 'Asia/Calcutta',
    'IDY': 'Europe/Paris',
    'IEG': 'Europe/Warsaw',
    'IES': 'Europe/Berlin',
    'IEV': 'Europe/Kiev',
    'IFH': 'Asia/Tehran',
    'IFJ': 'Atlantic/Reykjavik',
    'IFL': 'Australia/Brisbane',
    'IFN': 'Asia/Tehran',
    'IFO': 'Europe/Kiev',
    'IGA': 'America/Nassau',
    'IGB': 'America/Argentina/Salta',
    'IGD': 'Europe/Istanbul',
    'IGG': 'America/Anchorage',
    'IGL': 'Europe/Istanbul',
    'IGR': 'America/Cordoba',
    'IGS': 'Europe/Berlin',
    'IGT': 'Europe/Moscow',
    'IGU': 'America/Sao_Paulo',
    'IHC': 'Africa/Maputo',
    'IHR': 'Asia/Tehran',
    'IIA': 'Europe/Dublin',
    'IIL': 'Asia/Tehran',
    'IJK': 'Europe/Samara',
    'IKA': 'Asia/Tehran',
    'IKB': 'America/New_York',
    'IKI': 'Asia/Tokyo',
    'IKK': 'America/Chicago',
    'IKO': 'America/Anchorage',
    'IKS': 'Asia/Yakutsk',
    'IKT': 'Asia/Irkutsk',
    'ILD': 'Europe/Madrid',
    'ILF': 'America/Winnipeg',
    'ILG': 'America/New_York',
    'ILI': 'America/Anchorage',
    'ILM': 'America/New_York',
    'ILN': 'America/New_York',
    'ILO': 'Asia/Manila',
    'ILP': 'Pacific/Noumea',
    'ILQ': 'America/Lima',
    'ILR': 'Africa/Lagos',
    'ILU': 'Africa/Nairobi',
    'ILY': 'Europe/London',
    'ILZ': 'Europe/Bratislava',
    'IMB': 'America/Guyana',
    'IMF': 'Asia/Calcutta',
    'IMK': 'Asia/Katmandu',
    'IMM': 'America/New_York',
    'IMP': 'America/Fortaleza',
    'IMT': 'America/Chicago',
    'IND': 'America/New_York',
    'ING': 'America/Argentina/Rio_Gallegos',
    'INH': 'Africa/Maputo',
    'INI': 'Europe/Belgrade',
    'INK': 'America/Chicago',
    'INL': 'America/Chicago',
    'INN': 'Europe/Vienna',
    'INO': 'Africa/Kinshasa',
    'INQ': 'Europe/Dublin',
    'INS': 'America/Los_Angeles',
    'INT': 'America/New_York',
    'INU': 'Pacific/Nauru',
    'INV': 'Europe/London',
    'INW': 'America/Phoenix',
    'INZ': 'Africa/Algiers',
    'IOA': 'Europe/Athens',
    'IOM': 'Europe/Isle_of_Man',
    'IOR': 'Europe/Dublin',
    'IOS': 'America/Fortaleza',
    'IOW': 'America/Chicago',
    'IPA': 'Pacific/Efate',
    'IPC': 'Pacific/Easter',
    'IPH': 'Asia/Kuala_Lumpur',
    'IPI': 'America/Bogota',
    'IPL': 'America/Los_Angeles',
    'IPN': 'America/Sao_Paulo',
    'IPT': 'America/New_York',
    'IQA': 'Asia/Baghdad',
    'IQM': 'Asia/Shanghai',
    'IQN': 'Asia/Shanghai',
    'IQQ': 'America/Santiago',
    'IQT': 'America/Lima',
    'IRA': 'Pacific/Guadalcanal',
    'IRB': 'America/Chicago',
    'IRC': 'America/Anchorage',
    'IRD': 'Asia/Dhaka',
    'IRG': 'Australia/Brisbane',
    'IRI': 'Africa/Dar_es_Salaam',
    'IRJ': 'America/Argentina/La_Rioja',
    'IRK': 'America/Chicago',
    'IRP': 'Africa/Lubumbashi',
    'IRZ': 'America/Boa_Vista',
    'ISA': 'Australia/Brisbane',
    'ISC': 'Europe/London',
    'ISE': 'Europe/Istanbul',
    'ISG': 'Asia/Tokyo',
    'ISJ': 'America/Cancun',
    'ISK': 'Asia/Calcutta',
    'ISL': 'Europe/Istanbul',
    'ISM': 'America/New_York',
    'ISN': 'America/Chicago',
    'ISO': 'America/New_York',
    'ISP': 'America/New_York',
    'ISU': 'Asia/Baghdad',
    'ISW': 'America/Chicago',
    'ITA': 'America/Boa_Vista',
    'ITB': 'America/Belem',
    'ITH': 'America/New_York',
    'ITM': 'Asia/Tokyo',
    'ITO': 'Pacific/Honolulu',
    'ITR': 'America/Sao_Paulo',
    'IUE': 'Pacific/Niue',
    'IVA': 'Indian/Antananarivo',
    'IVC': 'Pacific/Auckland',
    'IVL': 'Europe/Helsinki',
    'IVR': 'Australia/Sydney',
    'IWA': 'Europe/Moscow',
    'IWJ': 'Asia/Tokyo',
    'IWO': 'Asia/Tokyo',
    'IWS': 'America/Chicago',
    'IXA': 'Asia/Calcutta',
    'IXB': 'Asia/Calcutta',
    'IXC': 'Asia/Calcutta',
    'IXD': 'Asia/Calcutta',
    'IXE': 'Asia/Calcutta',
    'IXG': 'Asia/Calcutta',
    'IXH': 'Asia/Calcutta',
    'IXI': 'Asia/Calcutta',
    'IXJ': 'Asia/Calcutta',
    'IXK': 'Asia/Calcutta',
    'IXL': 'Asia/Calcutta',
    'IXM': 'Asia/Calcutta',
    'IXP': 'Asia/Calcutta',
    'IXR': 'Asia/Calcutta',
    'IXS': 'Asia/Calcutta',
    'IXU': 'Asia/Calcutta',
    'IXV': 'Asia/Calcutta',
    'IXW': 'Asia/Calcutta',
    'IXY': 'Asia/Calcutta',
    'IXZ': 'Asia/Calcutta',
    'IYK': 'America/Los_Angeles',
    'IZA': 'America/Sao_Paulo',
    'IZO': 'Asia/Tokyo',
    'IZT': 'America/Mexico_City',
    'JAA': 'Asia/Kabul',
    'JAB': 'Australia/Darwin',
    'JAC': 'America/Denver',
    'JAD': 'Australia/Perth',
    'JAF': 'Asia/Colombo',
    'JAG': 'Asia/Karachi',
    'JAI': 'Asia/Calcutta',
    'JAK': 'America/Port-au-Prince',
    'JAL': 'America/Mexico_City',
    'JAN': 'America/Chicago',
    'JAP': 'America/Costa_Rica',
    'JAR': 'Asia/Tehran',
    'JAU': 'America/Lima',
    'JAV': 'America/Godthab',
    'JAX': 'America/New_York',
    'JBQ': 'America/Santo_Domingo',
    'JBR': 'America/Chicago',
    'JCB': 'America/Sao_Paulo',
    'JCH': 'America/Godthab',
    'JCI': 'America/Chicago',
    'JCK': 'Australia/Brisbane',
    'JCR': 'America/Belem',
    'JDF': 'America/Sao_Paulo',
    'JDG': 'Asia/Seoul',
    'JDH': 'Asia/Calcutta',
    'JDO': 'America/Fortaleza',
    'JDZ': 'Asia/Shanghai',
    'JED': 'Asia/Riyadh',
    'JEE': 'America/Port-au-Prince',
    'JEF': 'America/Chicago',
    'JEG': 'America/Godthab',
    'JER': 'Europe/Jersey',
    'JFK': 'America/New_York',
    'JFR': 'America/Godthab',
    'JGA': 'Asia/Calcutta',
    'JGD': 'Asia/Shanghai',
    'JGN': 'Asia/Shanghai',
    'JGO': 'America/Godthab',
    'JGS': 'Asia/Shanghai',
    'JHB': 'Asia/Kuala_Lumpur',
    'JHG': 'Asia/Shanghai',
    'JHM': 'Pacific/Honolulu',
    'JHQ': 'Australia/Brisbane',
    'JHS': 'America/Godthab',
    'JHW': 'America/New_York',
    'JIB': 'Africa/Djibouti',
    'JIJ': 'Africa/Addis_Ababa',
    'JIK': 'Europe/Athens',
    'JIM': 'Africa/Addis_Ababa',
    'JIQ': 'Asia/Shanghai',
    'JIU': 'Asia/Shanghai',
    'JIW': 'Asia/Karachi',
    'JJI': 'America/Lima',
    'JJM': 'Africa/Nairobi',
    'JJN': 'Asia/Shanghai',
    'JJU': 'America/Godthab',
    'JKG': 'Europe/Stockholm',
    'JKH': 'Europe/Athens',
    'JKL': 'Europe/Athens',
    'JKR': 'Asia/Katmandu',
    'JLN': 'America/Chicago',
    'JLR': 'Asia/Calcutta',
    'JMK': 'Europe/Athens',
    'JMO': 'Asia/Katmandu',
    'JMS': 'America/Chicago',
    'JMU': 'Asia/Shanghai',
    'JNB': 'Africa/Johannesburg',
    'JNG': 'Asia/Shanghai',
    'JNI': 'America/Buenos_Aires',
    'JNN': 'America/Godthab',
    'JNS': 'America/Godthab',
    'JNU': 'America/Anchorage',
    'JNX': 'Europe/Athens',
    'JNZ': 'Asia/Shanghai',
    'JOE': 'Europe/Helsinki',
    'JOG': 'Asia/Jakarta',
    'JOH': 'Africa/Johannesburg',
    'JOI': 'America/Sao_Paulo',
    'JOK': 'Europe/Moscow',
    'JOL': 'Asia/Manila',
    'JON': 'Pacific/Johnston',
    'JOS': 'Africa/Lagos',
    'JOT': 'America/Chicago',
    'JPA': 'America/Fortaleza',
    'JPR': 'America/Boa_Vista',
    'JQA': 'America/Godthab',
    'JQE': 'America/Panama',
    'JRA': 'America/New_York',
    'JRB': 'America/New_York',
    'JRF': 'Pacific/Honolulu',
    'JRH': 'Asia/Calcutta',
    'JRO': 'Africa/Dar_es_Salaam',
    'JSA': 'Asia/Calcutta',
    'JSH': 'Europe/Athens',
    'JSI': 'Europe/Athens',
    'JSM': 'America/Catamarca',
    'JSR': 'Asia/Dhaka',
    'JST': 'America/New_York',
    'JSU': 'America/Godthab',
    'JSY': 'Europe/Athens',
    'JTC': 'America/Sao_Paulo',
    'JTR': 'Europe/Athens',
    'JTY': 'Europe/Athens',
    'JUB': 'Africa/Juba',
    'JUH': 'Asia/Shanghai',
    'JUI': 'Europe/Berlin',
    'JUJ': 'America/Jujuy',
    'JUL': 'America/Lima',
    'JUM': 'Asia/Katmandu',
    'JUV': 'America/Godthab',
    'JUZ': 'Asia/Shanghai',
    'JVA': 'Indian/Antananarivo',
    'JVL': 'America/Chicago',
    'JWA': 'Africa/Gaborone',
    'JWN': 'Asia/Tehran',
    'JXA': 'Asia/Shanghai',
    'JXN': 'America/New_York',
    'JYR': 'Asia/Tehran',
    'JYV': 'Europe/Helsinki',
    'JZH': 'Asia/Shanghai',
    'KAA': 'Africa/Lusaka',
    'KAB': 'Africa/Harare',
    'KAC': 'Asia/Damascus',
    'KAD': 'Africa/Lagos',
    'KAG': 'Asia/Seoul',
    'KAI': 'America/Guyana',
    'KAJ': 'Europe/Helsinki',
    'KAL': 'America/Anchorage',
    'KAN': 'Africa/Lagos',
    'KAO': 'Europe/Helsinki',
    'KAR': 'America/Guyana',
    'KAT': 'Pacific/Auckland',
    'KAU': 'Europe/Helsinki',
    'KAW': 'Asia/Rangoon',
    'KAX': 'Australia/Perth',
    'KBL': 'Asia/Kabul',
    'KBP': 'Europe/Kiev',
    'KBQ': 'Africa/Blantyre',
    'KBR': 'Asia/Kuala_Lumpur',
    'KBS': 'Africa/Freetown',
    'KBV': 'Asia/Bangkok',
    'KBZ': 'Pacific/Auckland',
    'KCA': 'Asia/Shanghai',
    'KCH': 'Asia/Kuala_Lumpur',
    'KCK': 'Asia/Irkutsk',
    'KCM': 'Europe/Istanbul',
    'KCO': 'Europe/Istanbul',
    'KCT': 'Asia/Colombo',
    'KCZ': 'Asia/Tokyo',
    'KDD': 'Asia/Karachi',
    'KDH': 'Asia/Kabul',
    'KDI': 'Asia/Makassar',
    'KDL': 'Europe/Tallinn',
    'KDM': 'Indian/Maldives',
    'KDO': 'Indian/Maldives',
    'KDT': 'Asia/Bangkok',
    'KDU': 'Asia/Karachi',
    'KDV': 'Pacific/Fiji',
    'KDX': 'Africa/Khartoum',
    'KDY': 'Asia/Yakutsk',
    'KED': 'Africa/Nouakchott',
    'KEF': 'Atlantic/Reykjavik',
    'KEJ': 'Asia/Krasnoyarsk',
    'KEL': 'Europe/Berlin',
    'KEM': 'Europe/Helsinki',
    'KEN': 'Africa/Freetown',
    'KEP': 'Asia/Katmandu',
    'KER': 'Asia/Tehran',
    'KET': 'Asia/Rangoon',
    'KEV': 'Europe/Helsinki',
    'KEW': 'America/Winnipeg',
    'KEY': 'Africa/Nairobi',
    'KFA': 'Africa/Nouakchott',
    'KFE': 'Australia/Perth',
    'KFG': 'Australia/Darwin',
    'KFP': 'America/Anchorage',
    'KFS': 'Europe/Istanbul',
    'KGA': 'Africa/Lubumbashi',
    'KGC': 'Australia/Adelaide',
    'KGD': 'Europe/Kaliningrad',
    'KGE': 'Pacific/Guadalcanal',
    'KGF': 'Asia/Qyzylorda',
    'KGG': 'Africa/Dakar',
    'KGI': 'Australia/Perth',
    'KGJ': 'Africa/Blantyre',
    'KGK': 'America/Anchorage',
    'KGL': 'Africa/Kigali',
    'KGO': 'Europe/Kiev',
    'KGP': 'Asia/Yekaterinburg',
    'KGS': 'Europe/Athens',
    'KGT': 'Asia/Shanghai',
    'KHC': 'Europe/Simferopol',
    'KHD': 'Asia/Tehran',
    'KHE': 'Europe/Kiev',
    'KHG': 'Asia/Shanghai',
    'KHH': 'Asia/Taipei',
    'KHI': 'Asia/Karachi',
    'KHJ': 'Europe/Helsinki',
    'KHK': 'Asia/Tehran',
    'KHM': 'Asia/Rangoon',
    'KHN': 'Asia/Shanghai',
    'KHS': 'Asia/Muscat',
    'KHT': 'Asia/Kabul',
    'KHV': 'Asia/Vladivostok',
    'KHW': 'Africa/Gaborone',
    'KHY': 'Asia/Tehran',
    'KID': 'Europe/Stockholm',
    'KIF': 'America/Toronto',
    'KIH': 'Asia/Tehran',
    'KIJ': 'Asia/Tokyo',
    'KIK': 'Asia/Baghdad',
    'KIM': 'Africa/Johannesburg',
    'KIN': 'America/Jamaica',
    'KIO': 'Pacific/Majuro',
    'KIR': 'Europe/Dublin',
    'KIS': 'Africa/Nairobi',
    'KIT': 'Europe/Athens',
    'KIV': 'Europe/Chisinau',
    'KIW': 'Africa/Lusaka',
    'KIX': 'Asia/Tokyo',
    'KJA': 'Asia/Krasnoyarsk',
    'KJI': 'Asia/Shanghai',
    'KJK': 'Europe/Brussels',
    'KJP': 'Asia/Tokyo',
    'KKA': 'America/Anchorage',
    'KKC': 'Asia/Bangkok',
    'KKE': 'Pacific/Auckland',
    'KKH': 'America/Anchorage',
    'KKJ': 'Asia/Tokyo',
    'KKN': 'Europe/Oslo',
    'KKR': 'Pacific/Tahiti',
    'KKS': 'Asia/Tehran',
    'KKW': 'Africa/Kinshasa',
    'KKX': 'Asia/Tokyo',
    'KLC': 'Africa/Dakar',
    'KLD': 'Europe/Moscow',
    'KLF': 'Europe/Moscow',
    'KLG': 'America/Anchorage',
    'KLH': 'Asia/Calcutta',
    'KLI': 'Africa/Kinshasa',
    'KLM': 'Asia/Tehran',
    'KLN': 'America/Anchorage',
    'KLO': 'Asia/Manila',
    'KLR': 'Europe/Stockholm',
    'KLS': 'America/Los_Angeles',
    'KLU': 'Europe/Vienna',
    'KLV': 'Europe/Prague',
    'KLW': 'America/Anchorage',
    'KLX': 'Europe/Athens',
    'KLZ': 'Africa/Johannesburg',
    'KMA': 'Pacific/Port_Moresby',
    'KMC': 'Asia/Riyadh',
    'KME': 'Africa/Kigali',
    'KMG': 'Asia/Shanghai',
    'KMH': 'Africa/Johannesburg',
    'KMI': 'Asia/Tokyo',
    'KMJ': 'Asia/Tokyo',
    'KMN': 'Africa/Lubumbashi',
    'KMO': 'America/Anchorage',
    'KMP': 'Africa/Windhoek',
    'KMQ': 'Asia/Tokyo',
    'KMS': 'Africa/Accra',
    'KMU': 'Africa/Mogadishu',
    'KMV': 'Asia/Rangoon',
    'KMW': 'Europe/Moscow',
    'KNA': 'America/Santiago',
    'KND': 'Africa/Lubumbashi',
    'KNF': 'Europe/London',
    'KNG': 'Asia/Jayapura',
    'KNH': 'Asia/Taipei',
    'KNO': 'Asia/Jakarta',
    'KNP': 'Africa/Luanda',
    'KNQ': 'Pacific/Noumea',
    'KNS': 'Australia/Melbourne',
    'KNU': 'Asia/Calcutta',
    'KNW': 'America/Anchorage',
    'KNX': 'Australia/Perth',
    'KOA': 'Pacific/Honolulu',
    'KOC': 'Pacific/Noumea',
    'KOE': 'Asia/Makassar',
    'KOI': 'Europe/London',
    'KOJ': 'Asia/Tokyo',
    'KOK': 'Europe/Helsinki',
    'KOP': 'Asia/Bangkok',
    'KOQ': 'Europe/Berlin',
    'KOS': 'Asia/Phnom_Penh',
    'KOT': 'America/Anchorage',
    'KOU': 'Africa/Libreville',
    'KOV': 'Asia/Qyzylorda',
    'KOW': 'Asia/Shanghai',
    'KPC': 'America/Anchorage',
    'KPN': 'America/Anchorage',
    'KPO': 'Asia/Seoul',
    'KPV': 'America/Anchorage',
    'KQA': 'America/Anchorage',
    'KQT': 'Asia/Dushanbe',
    'KRB': 'Australia/Brisbane',
    'KRF': 'Europe/Stockholm',
    'KRH': 'Europe/London',
    'KRI': 'Pacific/Port_Moresby',
    'KRK': 'Europe/Warsaw',
    'KRL': 'Asia/Shanghai',
    'KRN': 'Europe/Stockholm',
    'KRO': 'Asia/Yekaterinburg',
    'KRP': 'Europe/Copenhagen',
    'KRR': 'Europe/Moscow',
    'KRS': 'Europe/Oslo',
    'KRT': 'Africa/Khartoum',
    'KRW': 'Asia/Ashgabat',
    'KRY': 'Asia/Shanghai',
    'KRZ': 'Africa/Kinshasa',
    'KSA': 'Pacific/Kosrae',
    'KSC': 'Europe/Bratislava',
    'KSD': 'Europe/Stockholm',
    'KSF': 'Europe/Berlin',
    'KSH': 'Asia/Tehran',
    'KSI': 'Africa/Conakry',
    'KSJ': 'Europe/Athens',
    'KSK': 'Europe/Stockholm',
    'KSL': 'Africa/Khartoum',
    'KSM': 'America/Anchorage',
    'KSN': 'Asia/Qyzylorda',
    'KSO': 'Europe/Athens',
    'KSQ': 'Asia/Samarkand',
    'KSS': 'Africa/Bamako',
    'KSU': 'Europe/Oslo',
    'KSY': 'Europe/Istanbul',
    'KSZ': 'Europe/Moscow',
    'KTA': 'Australia/Perth',
    'KTD': 'Asia/Tokyo',
    'KTE': 'Asia/Kuala_Lumpur',
    'KTF': 'Pacific/Auckland',
    'KTG': 'Asia/Jakarta',
    'KTI': 'Asia/Phnom_Penh',
    'KTL': 'Africa/Nairobi',
    'KTM': 'Asia/Katmandu',
    'KTN': 'America/Anchorage',
    'KTP': 'America/Jamaica',
    'KTQ': 'Europe/Helsinki',
    'KTR': 'Australia/Darwin',
    'KTS': 'America/Anchorage',
    'KTT': 'Europe/Helsinki',
    'KTU': 'Asia/Calcutta',
    'KTW': 'Europe/Warsaw',
    'KUA': 'Asia/Kuala_Lumpur',
    'KUC': 'Pacific/Tarawa',
    'KUD': 'Asia/Kuala_Lumpur',
    'KUF': 'Europe/Samara',
    'KUG': 'Australia/Brisbane',
    'KUH': 'Asia/Tokyo',
    'KUK': 'America/Anchorage',
    'KUL': 'Asia/Kuala_Lumpur',
    'KUM': 'Asia/Tokyo',
    'KUN': 'Europe/Vilnius',
    'KUO': 'Europe/Helsinki',
    'KUT': 'Asia/Tbilisi',
    'KUU': 'Asia/Calcutta',
    'KUV': 'Asia/Seoul',
    'KVA': 'Europe/Athens',
    'KVB': 'Europe/Stockholm',
    'KVC': 'America/Anchorage',
    'KVD': 'Asia/Baku',
    'KVG': 'Pacific/Port_Moresby',
    'KVK': 'Europe/Moscow',
    'KVL': 'America/Anchorage',
    'KVM': 'Asia/Anadyr',
    'KVR': 'Asia/Vladivostok',
    'KVX': 'Europe/Moscow',
    'KWA': 'Pacific/Majuro',
    'KWE': 'Asia/Shanghai',
    'KWG': 'Europe/Kiev',
    'KWI': 'Asia/Kuwait',
    'KWJ': 'Asia/Seoul',
    'KWK': 'America/Anchorage',
    'KWL': 'Asia/Shanghai',
    'KWM': 'Australia/Brisbane',
    'KWN': 'America/Anchorage',
    'KWT': 'America/Anchorage',
    'KWZ': 'Africa/Lubumbashi',
    'KXE': 'Africa/Johannesburg',
    'KXF': 'Pacific/Fiji',
    'KXK': 'Asia/Vladivostok',
    'KYA': 'Europe/Istanbul',
    'KYD': 'Asia/Taipei',
    'KYE': 'Asia/Beirut',
    'KYI': 'Australia/Adelaide',
    'KYK': 'America/Anchorage',
    'KYP': 'Asia/Rangoon',
    'KYS': 'Africa/Bamako',
    'KYU': 'America/Anchorage',
    'KYZ': 'Asia/Krasnoyarsk',
    'KZC': 'Asia/Phnom_Penh',
    'KZG': 'Europe/Berlin',
    'KZI': 'Europe/Athens',
    'KZN': 'Europe/Moscow',
    'KZO': 'Asia/Qyzylorda',
    'KZR': 'Europe/Istanbul',
    'KZS': 'Europe/Athens',
    'LAA': 'America/Denver',
    'LAD': 'Africa/Luanda',
    'LAE': 'Pacific/Port_Moresby',
    'LAF': 'America/New_York',
    'LAI': 'Europe/Paris',
    'LAJ': 'America/Sao_Paulo',
    'LAK': 'America/Edmonton',
    'LAL': 'America/New_York',
    'LAM': 'America/Denver',
    'LAN': 'America/New_York',
    'LAO': 'Asia/Manila',
    'LAP': 'America/Mazatlan',
    'LAQ': 'Africa/Tripoli',
    'LAR': 'America/Denver',
    'LAS': 'America/Los_Angeles',
    'LAU': 'Africa/Nairobi',
    'LAW': 'America/Chicago',
    'LAX': 'America/Los_Angeles',
    'LAY': 'Africa/Johannesburg',
    'LAZ': 'America/Fortaleza',
    'LBA': 'Europe/London',
    'LBB': 'America/Chicago',
    'LBC': 'Europe/Berlin',
    'LBD': 'Asia/Dushanbe',
    'LBE': 'America/New_York',
    'LBF': 'America/Chicago',
    'LBG': 'Europe/Paris',
    'LBI': 'Europe/Paris',
    'LBJ': 'Asia/Makassar',
    'LBL': 'America/Chicago',
    'LBQ': 'Africa/Libreville',
    'LBR': 'America/Boa_Vista',
    'LBS': 'Pacific/Fiji',
    'LBT': 'America/New_York',
    'LBU': 'Asia/Kuala_Lumpur',
    'LBV': 'Africa/Libreville',
    'LBW': 'Asia/Makassar',
    'LBX': 'Asia/Manila',
    'LBY': 'Europe/Paris',
    'LBZ': 'Africa/Luanda',
    'LCA': 'Asia/Nicosia',
    'LCC': 'Europe/Rome',
    'LCE': 'America/Tegucigalpa',
    'LCG': 'Europe/Madrid',
    'LCH': 'America/Chicago',
    'LCJ': 'Europe/Warsaw',
    'LCK': 'America/New_York',
    'LCL': 'America/Havana',
    'LCQ': 'America/New_York',
    'LCX': 'Asia/Shanghai',
    'LCY': 'Europe/London',
    'LDB': 'America/Sao_Paulo',
    'LDE': 'Europe/Paris',
    'LDG': 'Europe/Moscow',
    'LDH': 'Australia/Lord_Howe',
    'LDI': 'Africa/Dar_es_Salaam',
    'LDJ': 'America/New_York',
    'LDK': 'Europe/Stockholm',
    'LDN': 'Asia/Katmandu',
    'LDS': 'Asia/Shanghai',
    'LDU': 'Asia/Kuala_Lumpur',
    'LDV': 'Europe/Paris',
    'LDX': 'America/Cayenne',
    'LDY': 'Europe/London',
    'LEA': 'Australia/Perth',
    'LEB': 'America/New_York',
    'LEC': 'America/Fortaleza',
    'LED': 'Europe/Moscow',
    'LEH': 'Europe/Paris',
    'LEI': 'Europe/Madrid',
    'LEJ': 'Europe/Berlin',
    'LEK': 'Africa/Conakry',
    'LEL': 'Australia/Darwin',
    'LEN': 'Europe/Madrid',
    'LEQ': 'Europe/London',
    'LER': 'Australia/Perth',
    'LET': 'America/Bogota',
    'LEU': 'Europe/Madrid',
    'LEV': 'Pacific/Fiji',
    'LEW': 'America/New_York',
    'LEX': 'America/New_York',
    'LEY': 'Europe/Amsterdam',
    'LFB': 'Africa/Maputo',
    'LFI': 'America/New_York',
    'LFK': 'America/Chicago',
    'LFM': 'Asia/Tehran',
    'LFR': 'America/Caracas',
    'LFT': 'America/Chicago',
    'LFW': 'Africa/Lome',
    'LGA': 'America/New_York',
    'LGB': 'America/Los_Angeles',
    'LGC': 'America/New_York',
    'LGG': 'Europe/Brussels',
    'LGH': 'Australia/Adelaide',
    'LGI': 'America/Nassau',
    'LGK': 'Asia/Kuala_Lumpur',
    'LGL': 'Asia/Kuala_Lumpur',
    'LGO': 'Europe/Berlin',
    'LGP': 'Asia/Manila',
    'LGS': 'America/Mendoza',
    'LGU': 'America/Denver',
    'LGW': 'Europe/London',
    'LHA': 'Europe/Berlin',
    'LHE': 'Asia/Karachi',
    'LHG': 'Australia/Sydney',
    'LHR': 'Europe/London',
    'LHS': 'America/Argentina/Rio_Gallegos',
    'LHV': 'America/New_York',
    'LHW': 'Asia/Shanghai',
    'LID': 'Europe/Amsterdam',
    'LIF': 'Pacific/Noumea',
    'LIG': 'Europe/Paris',
    'LIH': 'Pacific/Honolulu',
    'LII': 'Asia/Jayapura',
    'LIL': 'Europe/Paris',
    'LIM': 'America/Lima',
    'LIN': 'Europe/Rome',
    'LIO': 'America/Costa_Rica',
    'LIP': 'America/Sao_Paulo',
    'LIQ': 'Africa/Kinshasa',
    'LIR': 'America/Costa_Rica',
    'LIS': 'Europe/Lisbon',
    'LIT': 'America/Chicago',
    'LIW': 'Asia/Rangoon',
    'LIX': 'Africa/Blantyre',
    'LIY': 'America/New_York',
    'LJA': 'Africa/Lubumbashi',
    'LJG': 'Asia/Shanghai',
    'LJN': 'America/Chicago',
    'LJU': 'Europe/Ljubljana',
    'LKB': 'Pacific/Fiji',
    'LKG': 'Africa/Nairobi',
    'LKH': 'Asia/Kuala_Lumpur',
    'LKL': 'Europe/Oslo',
    'LKN': 'Europe/Oslo',
    'LKO': 'Asia/Calcutta',
    'LKP': 'America/New_York',
    'LKV': 'America/Los_Angeles',
    'LKY': 'Africa/Dar_es_Salaam',
    'LKZ': 'Europe/London',
    'LLA': 'Europe/Stockholm',
    'LLE': 'Africa/Johannesburg',
    'LLF': 'Asia/Shanghai',
    'LLI': 'Africa/Addis_Ababa',
    'LLK': 'Asia/Baku',
    'LLU': 'America/Godthab',
    'LLV': 'Asia/Shanghai',
    'LLW': 'Africa/Blantyre',
    'LLY': 'America/New_York',
    'LMA': 'America/Anchorage',
    'LME': 'Europe/Paris',
    'LMM': 'America/Mazatlan',
    'LMN': 'Asia/Kuala_Lumpur',
    'LMO': 'Europe/London',
    'LMP': 'Europe/Rome',
    'LMQ': 'Africa/Tripoli',
    'LMT': 'America/Los_Angeles',
    'LNA': 'America/New_York',
    'LNB': 'Pacific/Efate',
    'LND': 'America/Denver',
    'LNE': 'Pacific/Efate',
    'LNJ': 'Asia/Shanghai',
    'LNK': 'America/Chicago',
    'LNN': 'America/New_York',
    'LNO': 'Australia/Perth',
    'LNR': 'America/Chicago',
    'LNS': 'America/New_York',
    'LNY': 'Pacific/Honolulu',
    'LNZ': 'Europe/Vienna',
    'LOD': 'Pacific/Efate',
    'LOE': 'Asia/Bangkok',
    'LOH': 'America/Guayaquil',
    'LOK': 'Africa/Nairobi',
    'LOO': 'Africa/Algiers',
    'LOP': 'Asia/Makassar',
    'LOS': 'Africa/Lagos',
    'LOT': 'America/Chicago',
    'LOU': 'America/New_York',
    'LOV': 'America/Mexico_City',
    'LOZ': 'America/New_York',
    'LPA': 'Atlantic/Canary',
    'LPB': 'America/La_Paz',
    'LPC': 'America/Los_Angeles',
    'LPD': 'America/Bogota',
    'LPG': 'America/Buenos_Aires',
    'LPI': 'Europe/Stockholm',
    'LPK': 'Europe/Moscow',
    'LPL': 'Europe/London',
    'LPM': 'Pacific/Efate',
    'LPP': 'Europe/Helsinki',
    'LPQ': 'Asia/Vientiane',
    'LPS': 'America/Los_Angeles',
    'LPT': 'Asia/Bangkok',
    'LPU': 'Asia/Makassar',
    'LPX': 'Europe/Riga',
    'LPY': 'Europe/Paris',
    'LQM': 'America/Bogota',
    'LRA': 'Europe/Athens',
    'LRD': 'America/Chicago',
    'LRE': 'Australia/Brisbane',
    'LRF': 'America/Chicago',
    'LRH': 'Europe/Paris',
    'LRL': 'Africa/Lome',
    'LRM': 'America/Santo_Domingo',
    'LRR': 'Asia/Tehran',
    'LRS': 'Europe/Athens',
    'LRT': 'Europe/Paris',
    'LRU': 'America/Denver',
    'LRV': 'America/Caracas',
    'LSC': 'America/Santiago',
    'LSE': 'America/Chicago',
    'LSF': 'America/New_York',
    'LSH': 'Asia/Rangoon',
    'LSI': 'Europe/London',
    'LSL': 'America/Costa_Rica',
    'LSP': 'America/Caracas',
    'LSQ': 'America/Santiago',
    'LSS': 'America/Guadeloupe',
    'LST': 'Australia/Melbourne',
    'LSV': 'America/Los_Angeles',
    'LSW': 'Asia/Jakarta',
    'LSX': 'Asia/Jakarta',
    'LSY': 'Australia/Sydney',
    'LSZ': 'Europe/Zagreb',
    'LTA': 'Africa/Johannesburg',
    'LTD': 'Africa/Tripoli',
    'LTI': 'Asia/Ulaanbaatar',
    'LTK': 'Asia/Damascus',
    'LTM': 'America/Guyana',
    'LTN': 'Europe/London',
    'LTO': 'America/Mazatlan',
    'LTQ': 'Europe/Paris',
    'LTS': 'America/Chicago',
    'LTT': 'Europe/Paris',
    'LTX': 'America/Guayaquil',
    'LUA': 'Asia/Katmandu',
    'LUD': 'Africa/Windhoek',
    'LUF': 'America/Phoenix',
    'LUG': 'Europe/Zurich',
    'LUH': 'Asia/Calcutta',
    'LUK': 'America/New_York',
    'LUM': 'Asia/Shanghai',
    'LUN': 'Africa/Lusaka',
    'LUO': 'Africa/Luanda',
    'LUP': 'Pacific/Honolulu',
    'LUQ': 'America/Argentina/San_Luis',
    'LUR': 'America/Anchorage',
    'LUV': 'Asia/Jayapura',
    'LUW': 'Asia/Makassar',
    'LUX': 'Europe/Luxembourg',
    'LUZ': 'Europe/Warsaw',
    'LVA': 'Europe/Paris',
    'LVI': 'Africa/Lusaka',
    'LVK': 'America/Los_Angeles',
    'LVM': 'America/Denver',
    'LVO': 'Australia/Perth',
    'LVP': 'Asia/Tehran',
    'LVS': 'America/Denver',
    'LWB': 'America/New_York',
    'LWC': 'America/Chicago',
    'LWK': 'Europe/London',
    'LWM': 'America/New_York',
    'LWN': 'Asia/Yerevan',
    'LWO': 'Europe/Kiev',
    'LWR': 'Europe/Amsterdam',
    'LWS': 'America/Los_Angeles',
    'LWT': 'America/Denver',
    'LWY': 'Asia/Kuala_Lumpur',
    'LXA': 'Asia/Shanghai',
    'LXG': 'Asia/Vientiane',
    'LXR': 'Africa/Cairo',
    'LXS': 'Europe/Athens',
    'LYA': 'Asia/Shanghai',
    'LYB': 'America/Cayman',
    'LYC': 'Europe/Stockholm',
    'LYE': 'Europe/London',
    'LYG': 'Asia/Shanghai',
    'LYH': 'America/New_York',
    'LYI': 'Asia/Shanghai',
    'LYM': 'Europe/London',
    'LYN': 'Europe/Paris',
    'LYP': 'Asia/Karachi',
    'LYR': 'Arctic/Longyearbyen',
    'LYS': 'Europe/Paris',
    'LYU': 'America/Chicago',
    'LYX': 'Europe/London',
    'LZC': 'America/Mexico_City',
    'LZH': 'Asia/Shanghai',
    'LZN': 'Asia/Taipei',
    'LZO': 'Asia/Shanghai',
    'LZR': 'Australia/Brisbane',
    'LZU': 'America/New_York',
    'LZY': 'Asia/Shanghai',
    'MAA': 'Asia/Calcutta',
    'MAB': 'America/Belem',
    'MAD': 'Europe/Madrid',
    'MAE': 'America/Los_Angeles',
    'MAF': 'America/Chicago',
    'MAG': 'Pacific/Port_Moresby',
    'MAH': 'Europe/Madrid',
    'MAJ': 'Pacific/Majuro',
    'MAK': 'Africa/Juba',
    'MAM': 'America/Mexico_City',
    'MAN': 'Europe/London',
    'MAO': 'America/Boa_Vista',
    'MAQ': 'Asia/Bangkok',
    'MAR': 'America/Caracas',
    'MAS': 'Pacific/Port_Moresby',
    'MAT': 'Africa/Kinshasa',
    'MAU': 'Pacific/Tahiti',
    'MAX': 'Africa/Dakar',
    'MAY': 'America/Nassau',
    'MAZ': 'America/Puerto_Rico',
    'MBA': 'Africa/Nairobi',
    'MBD': 'Africa/Johannesburg',
    'MBE': 'Asia/Tokyo',
    'MBH': 'Australia/Brisbane',
    'MBJ': 'America/Jamaica',
    'MBL': 'America/New_York',
    'MBO': 'Asia/Manila',
    'MBS': 'America/New_York',
    'MBT': 'Asia/Manila',
    'MBU': 'Pacific/Guadalcanal',
    'MBW': 'Australia/Hobart',
    'MBX': 'Europe/Ljubljana',
    'MBZ': 'America/Boa_Vista',
    'MCC': 'America/Los_Angeles',
    'MCE': 'America/Los_Angeles',
    'MCF': 'America/New_York',
    'MCG': 'America/Anchorage',
    'MCH': 'America/Guayaquil',
    'MCI': 'America/Chicago',
    'MCJ': 'America/Bogota',
    'MCK': 'America/Chicago',
    'MCL': 'America/Anchorage',
    'MCN': 'America/New_York',
    'MCO': 'America/New_York',
    'MCP': 'America/Fortaleza',
    'MCS': 'America/Cordoba',
    'MCT': 'Asia/Muscat',
    'MCU': 'Europe/Paris',
    'MCV': 'Australia/Darwin',
    'MCW': 'America/Chicago',
    'MCX': 'Europe/Moscow',
    'MCY': 'Australia/Brisbane',
    'MCZ': 'America/Fortaleza',
    'MDC': 'Asia/Makassar',
    'MDE': 'America/Bogota',
    'MDG': 'Asia/Shanghai',
    'MDI': 'Africa/Lagos',
    'MDK': 'Africa/Kinshasa',
    'MDL': 'Asia/Rangoon',
    'MDQ': 'America/Buenos_Aires',
    'MDS': 'America/Grand_Turk',
    'MDT': 'America/New_York',
    'MDU': 'Pacific/Port_Moresby',
    'MDW': 'America/Chicago',
    'MDY': 'Pacific/Midway',
    'MDZ': 'America/Mendoza',
    'MEA': 'America/Sao_Paulo',
    'MEB': 'Australia/Hobart',
    'MEC': 'America/Guayaquil',
    'MED': 'Asia/Riyadh',
    'MEE': 'Pacific/Noumea',
    'MEG': 'Africa/Luanda',
    'MEH': 'Europe/Oslo',
    'MEI': 'America/Chicago',
    'MEK': 'Africa/Casablanca',
    'MEL': 'Australia/Hobart',
    'MEM': 'America/Chicago',
    'MEN': 'Europe/Paris',
    'MEO': 'America/New_York',
    'MER': 'America/Los_Angeles',
    'MES': 'Asia/Jakarta',
    'MEU': 'America/Belem',
    'MEX': 'America/Mexico_City',
    'MEY': 'Asia/Katmandu',
    'MFA': 'Africa/Dar_es_Salaam',
    'MFD': 'America/New_York',
    'MFE': 'America/Chicago',
    'MFG': 'Asia/Karachi',
    'MFI': 'America/Chicago',
    'MFJ': 'Pacific/Fiji',
    'MFK': 'Asia/Taipei',
    'MFM': 'Asia/Macau',
    'MFN': 'Pacific/Auckland',
    'MFQ': 'Africa/Niamey',
    'MFR': 'America/Los_Angeles',
    'MFU': 'Africa/Lusaka',
    'MFX': 'Europe/Paris',
    'MGA': 'America/Managua',
    'MGB': 'Australia/Adelaide',
    'MGC': 'America/Chicago',
    'MGE': 'America/New_York',
    'MGF': 'America/Sao_Paulo',
    'MGH': 'Africa/Johannesburg',
    'MGJ': 'America/New_York',
    'MGL': 'Europe/Berlin',
    'MGM': 'America/Chicago',
    'MGN': 'America/Bogota',
    'MGQ': 'Africa/Mogadishu',
    'MGS': 'Pacific/Rarotonga',
    'MGT': 'Australia/Darwin',
    'MGW': 'America/New_York',
    'MGY': 'America/New_York',
    'MGZ': 'Asia/Rangoon',
    'MHA': 'America/Guyana',
    'MHC': 'America/Santiago',
    'MHD': 'Asia/Tehran',
    'MHG': 'Europe/Berlin',
    'MHH': 'America/Nassau',
    'MHK': 'America/Chicago',
    'MHP': 'Europe/Minsk',
    'MHQ': 'Europe/Mariehamn',
    'MHR': 'America/Los_Angeles',
    'MHT': 'America/New_York',
    'MHU': 'Australia/Hobart',
    'MHV': 'America/Los_Angeles',
    'MHX': 'Pacific/Rarotonga',
    'MHZ': 'Europe/London',
    'MIA': 'America/New_York',
    'MIB': 'America/Chicago',
    'MID': 'America/Mexico_City',
    'MIE': 'America/New_York',
    'MIG': 'Asia/Shanghai',
    'MII': 'America/Sao_Paulo',
    'MIJ': 'Pacific/Majuro',
    'MIK': 'Europe/Helsinki',
    'MIM': 'Australia/Sydney',
    'MIP': 'Asia/Jerusalem',
    'MIR': 'Africa/Tunis',
    'MIS': 'Pacific/Port_Moresby',
    'MIU': 'Africa/Lagos',
    'MIV': 'America/New_York',
    'MJA': 'Indian/Antananarivo',
    'MJC': 'Africa/Abidjan',
    'MJD': 'Asia/Karachi',
    'MJF': 'Europe/Oslo',
    'MJI': 'Africa/Tripoli',
    'MJK': 'Australia/Perth',
    'MJL': 'Africa/Libreville',
    'MJM': 'Africa/Lubumbashi',
    'MJN': 'Indian/Antananarivo',
    'MJT': 'Europe/Athens',
    'MJV': 'Europe/Madrid',
    'MJZ': 'Asia/Yakutsk',
    'MKC': 'America/Chicago',
    'MKE': 'America/Chicago',
    'MKG': 'America/New_York',
    'MKK': 'Pacific/Honolulu',
    'MKL': 'America/Chicago',
    'MKM': 'Asia/Kuala_Lumpur',
    'MKP': 'Pacific/Tahiti',
    'MKQ': 'Asia/Jayapura',
    'MKR': 'Australia/Perth',
    'MKS': 'Africa/Addis_Ababa',
    'MKU': 'Africa/Libreville',
    'MKW': 'Asia/Jayapura',
    'MKY': 'Australia/Brisbane',
    'MKZ': 'Asia/Kuala_Lumpur',
    'MLA': 'Europe/Malta',
    'MLB': 'America/New_York',
    'MLC': 'America/Chicago',
    'MLE': 'Indian/Maldives',
    'MLG': 'Asia/Jakarta',
    'MLI': 'America/Chicago',
    'MLL': 'America/Anchorage',
    'MLM': 'America/Mexico_City',
    'MLN': 'Europe/Madrid',
    'MLO': 'Europe/Athens',
    'MLS': 'America/Denver',
    'MLU': 'America/Chicago',
    'MLW': 'Africa/Monrovia',
    'MLX': 'Europe/Istanbul',
    'MLY': 'America/Anchorage',
    'MMB': 'Asia/Tokyo',
    'MMD': 'Asia/Tokyo',
    'MME': 'Europe/London',
    'MMG': 'Australia/Perth',
    'MMH': 'America/Los_Angeles',
    'MMI': 'America/New_York',
    'MMJ': 'Asia/Tokyo',
    'MMK': 'Europe/Moscow',
    'MMO': 'Atlantic/Cape_Verde',
    'MMU': 'America/New_York',
    'MMX': 'Europe/Stockholm',
    'MMY': 'Asia/Tokyo',
    'MMZ': 'Asia/Kabul',
    'MNB': 'Africa/Kinshasa',
    'MNC': 'Africa/Maputo',
    'MNF': 'Pacific/Fiji',
    'MNG': 'Australia/Darwin',
    'MNI': 'America/Montserrat',
    'MNJ': 'Indian/Antananarivo',
    'MNK': 'Pacific/Tarawa',
    'MNL': 'Asia/Manila',
    'MNM': 'America/Chicago',
    'MNR': 'Africa/Lusaka',
    'MNU': 'Asia/Rangoon',
    'MNX': 'America/Boa_Vista',
    'MNY': 'Pacific/Guadalcanal',
    'MNZ': 'America/New_York',
    'MOA': 'America/Havana',
    'MOB': 'America/Chicago',
    'MOC': 'America/Sao_Paulo',
    'MOD': 'America/Los_Angeles',
    'MOE': 'Asia/Rangoon',
    'MOF': 'Asia/Makassar',
    'MOG': 'Asia/Rangoon',
    'MOI': 'Pacific/Rarotonga',
    'MOJ': 'America/Paramaribo',
    'MOL': 'Europe/Oslo',
    'MON': 'Pacific/Auckland',
    'MOO': 'Australia/Adelaide',
    'MOQ': 'Indian/Antananarivo',
    'MOT': 'America/Chicago',
    'MOU': 'America/Anchorage',
    'MOV': 'Australia/Brisbane',
    'MOZ': 'Pacific/Tahiti',
    'MPA': 'Africa/Windhoek',
    'MPH': 'Asia/Manila',
    'MPK': 'Asia/Seoul',
    'MPL': 'Europe/Paris',
    'MPM': 'Africa/Maputo',
    'MPN': 'Atlantic/Stanley',
    'MPV': 'America/New_York',
    'MPW': 'Europe/Kiev',
    'MPY': 'America/Cayenne',
    'MQC': 'America/Miquelon',
    'MQF': 'Asia/Yekaterinburg',
    'MQH': 'America/Sao_Paulo',
    'MQJ': 'Asia/Srednekolymsk',
    'MQL': 'Australia/Hobart',
    'MQM': 'Europe/Istanbul',
    'MQN': 'Europe/Oslo',
    'MQP': 'Africa/Johannesburg',
    'MQQ': 'Africa/Ndjamena',
    'MQS': 'America/St_Vincent',
    'MQT': 'America/New_York',
    'MQU': 'America/Bogota',
    'MQX': 'Africa/Addis_Ababa',
    'MQY': 'America/Chicago',
    'MRB': 'America/New_York',
    'MRD': 'America/Caracas',
    'MRE': 'Africa/Nairobi',
    'MRI': 'America/Anchorage',
    'MRK': 'America/New_York',
    'MRN': 'America/New_York',
    'MRO': 'Pacific/Auckland',
    'MRQ': 'Asia/Manila',
    'MRR': 'America/Guayaquil',
    'MRS': 'Europe/Paris',
    'MRU': 'Indian/Mauritius',
    'MRV': 'Europe/Moscow',
    'MRW': 'Europe/Copenhagen',
    'MRX': 'Asia/Tehran',
    'MRY': 'America/Los_Angeles',
    'MRZ': 'Australia/Sydney',
    'MSA': 'America/Winnipeg',
    'MSC': 'America/Phoenix',
    'MSE': 'Europe/London',
    'MSH': 'Asia/Muscat',
    'MSJ': 'Asia/Tokyo',
    'MSL': 'America/Chicago',
    'MSN': 'America/Chicago',
    'MSO': 'America/Denver',
    'MSP': 'America/Chicago',
    'MSQ': 'Europe/Minsk',
    'MSR': 'Europe/Istanbul',
    'MSS': 'America/New_York',
    'MST': 'Europe/Amsterdam',
    'MSU': 'Africa/Maseru',
    'MSW': 'Africa/Asmera',
    'MSY': 'America/Chicago',
    'MSZ': 'Africa/Luanda',
    'MTC': 'America/New_York',
    'MTF': 'Africa/Addis_Ababa',
    'MTH': 'America/New_York',
    'MTJ': 'America/Denver',
    'MTK': 'Pacific/Tarawa',
    'MTL': 'Australia/Sydney',
    'MTM': 'America/Anchorage',
    'MTN': 'America/New_York',
    'MTR': 'America/Bogota',
    'MTS': 'Africa/Mbabane',
    'MTT': 'America/Mexico_City',
    'MTV': 'Pacific/Efate',
    'MTY': 'America/Mexico_City',
    'MTZ': 'Asia/Jerusalem',
    'MUA': 'Pacific/Guadalcanal',
    'MUB': 'Africa/Gaborone',
    'MUC': 'Europe/Berlin',
    'MUD': 'Africa/Maputo',
    'MUE': 'Pacific/Honolulu',
    'MUH': 'Africa/Cairo',
    'MUI': 'America/New_York',
    'MUK': 'Pacific/Rarotonga',
    'MUN': 'America/Caracas',
    'MUO': 'America/Denver',
    'MUR': 'Asia/Kuala_Lumpur',
    'MUS': 'Asia/Tokyo',
    'MUW': 'Africa/Algiers',
    'MUX': 'Asia/Karachi',
    'MUZ': 'Africa/Dar_es_Salaam',
    'MVA': 'Atlantic/Reykjavik',
    'MVB': 'Africa/Libreville',
    'MVD': 'America/Montevideo',
    'MVF': 'America/Fortaleza',
    'MVL': 'America/New_York',
    'MVP': 'America/Bogota',
    'MVQ': 'Europe/Minsk',
    'MVR': 'Africa/Douala',
    'MVS': 'America/Fortaleza',
    'MVT': 'Pacific/Tahiti',
    'MVV': 'Europe/Paris',
    'MVY': 'America/New_York',
    'MVZ': 'Africa/Harare',
    'MWA': 'America/Chicago',
    'MWC': 'America/Chicago',
    'MWD': 'Asia/Karachi',
    'MWF': 'Pacific/Efate',
    'MWH': 'America/Los_Angeles',
    'MWK': 'Asia/Jakarta',
    'MWL': 'America/Chicago',
    'MWQ': 'Asia/Rangoon',
    'MWX': 'Asia/Seoul',
    'MWZ': 'Africa/Dar_es_Salaam',
    'MXB': 'Asia/Makassar',
    'MXF': 'America/Chicago',
    'MXH': 'Pacific/Port_Moresby',
    'MXJ': 'Africa/Lagos',
    'MXL': 'America/Tijuana',
    'MXM': 'Indian/Antananarivo',
    'MXN': 'Europe/Paris',
    'MXP': 'Europe/Rome',
    'MXS': 'Pacific/Apia',
    'MXT': 'Indian/Antananarivo',
    'MXV': 'Asia/Ulaanbaatar',
    'MXX': 'Europe/Stockholm',
    'MXZ': 'Asia/Shanghai',
    'MYA': 'Australia/Sydney',
    'MYB': 'Africa/Libreville',
    'MYC': 'America/Caracas',
    'MYD': 'Africa/Nairobi',
    'MYE': 'Asia/Tokyo',
    'MYG': 'America/Nassau',
    'MYI': 'Australia/Brisbane',
    'MYJ': 'Asia/Tokyo',
    'MYL': 'America/Denver',
    'MYP': 'Asia/Ashgabat',
    'MYQ': 'Asia/Calcutta',
    'MYR': 'America/New_York',
    'MYT': 'Asia/Rangoon',
    'MYU': 'America/Anchorage',
    'MYV': 'America/Los_Angeles',
    'MYW': 'Africa/Dar_es_Salaam',
    'MYY': 'Asia/Kuala_Lumpur',
    'MZB': 'Africa/Maputo',
    'MZG': 'Asia/Taipei',
    'MZH': 'Europe/Istanbul',
    'MZI': 'Africa/Bamako',
    'MZJ': 'America/Phoenix',
    'MZK': 'Pacific/Tarawa',
    'MZL': 'America/Bogota',
    'MZM': 'Europe/Paris',
    'MZO': 'America/Havana',
    'MZP': 'Pacific/Auckland',
    'MZQ': 'Africa/Johannesburg',
    'MZR': 'Asia/Kabul',
    'MZT': 'America/Mazatlan',
    'MZU': 'Asia/Calcutta',
    'MZV': 'Asia/Kuala_Lumpur',
    'MZW': 'Africa/Algiers',
    'NAA': 'Australia/Sydney',
    'NAG': 'Asia/Calcutta',
    'NAH': 'Asia/Makassar',
    'NAI': 'America/Guyana',
    'NAJ': 'Asia/Baku',
    'NAK': 'Asia/Bangkok',
    'NAL': 'Europe/Moscow',
    'NAN': 'Pacific/Fiji',
    'NAO': 'Asia/Shanghai',
    'NAP': 'Europe/Rome',
    'NAQ': 'America/Thule',
    'NAS': 'America/Nassau',
    'NAT': 'America/Fortaleza',
    'NAV': 'Europe/Istanbul',
    'NAW': 'Asia/Bangkok',
    'NAY': 'Asia/Shanghai',
    'NBC': 'Europe/Moscow',
    'NBE': 'Africa/Tunis',
    'NBG': 'America/Chicago',
    'NBO': 'Africa/Nairobi',
    'NBS': 'Asia/Shanghai',
    'NBX': 'Asia/Jayapura',
    'NCA': 'America/Grand_Turk',
    'NCE': 'Europe/Paris',
    'NCG': 'America/Mazatlan',
    'NCL': 'Europe/London',
    'NCN': 'America/Anchorage',
    'NCO': 'America/New_York',
    'NCR': 'America/Managua',
    'NCS': 'Africa/Johannesburg',
    'NCU': 'Asia/Samarkand',
    'NCY': 'Europe/Paris',
    'NDB': 'Africa/Nouakchott',
    'NDC': 'Asia/Calcutta',
    'NDG': 'Asia/Shanghai',
    'NDJ': 'Africa/Ndjamena',
    'NDR': 'Africa/Casablanca',
    'NDU': 'Africa/Windhoek',
    'NDY': 'Europe/London',
    'NEC': 'America/Buenos_Aires',
    'NEG': 'America/Jamaica',
    'NEL': 'America/New_York',
    'NER': 'Asia/Yakutsk',
    'NEU': 'Asia/Vientiane',
    'NEV': 'America/St_Kitts',
    'NEW': 'America/Chicago',
    'NFG': 'Asia/Yekaterinburg',
    'NFL': 'America/Los_Angeles',
    'NFO': 'Pacific/Tongatapu',
    'NGB': 'Asia/Shanghai',
    'NGE': 'Africa/Douala',
    'NGF': 'Pacific/Honolulu',
    'NGI': 'Pacific/Fiji',
    'NGO': 'Asia/Tokyo',
    'NGQ': 'Asia/Shanghai',
    'NGS': 'Asia/Tokyo',
    'NGU': 'America/New_York',
    'NGX': 'Asia/Katmandu',
    'NGZ': 'America/Los_Angeles',
    'NHA': 'Asia/Saigon',
    'NHD': 'Asia/Dubai',
    'NHK': 'America/New_York',
    'NHT': 'Europe/London',
    'NHV': 'Pacific/Marquesas',
    'NIB': 'America/Anchorage',
    'NIG': 'Pacific/Tarawa',
    'NIM': 'Africa/Niamey',
    'NIO': 'Africa/Kinshasa',
    'NIP': 'America/New_York',
    'NIT': 'Europe/Paris',
    'NIU': 'Pacific/Tahiti',
    'NJA': 'Asia/Tokyo',
    'NJC': 'Asia/Yekaterinburg',
    'NJF': 'Asia/Baghdad',
    'NJK': 'America/Los_Angeles',
    'NKC': 'Africa/Nouakchott',
    'NKG': 'Asia/Shanghai',
    'NKM': 'Asia/Tokyo',
    'NKT': 'Europe/Istanbul',
    'NKW': 'Indian/Chagos',
    'NKX': 'America/Los_Angeles',
    'NLA': 'Africa/Lusaka',
    'NLC': 'America/Los_Angeles',
    'NLD': 'America/Mexico_City',
    'NLF': 'Australia/Brisbane',
    'NLG': 'America/Anchorage',
    'NLK': 'Pacific/Norfolk',
    'NLO': 'Africa/Kinshasa',
    'NLP': 'Africa/Johannesburg',
    'NLT': 'Asia/Shanghai',
    'NLV': 'Europe/Kiev',
    'NMA': 'Asia/Samarkand',
    'NMB': 'Asia/Calcutta',
    'NMC': 'America/Nassau',
    'NME': 'America/Anchorage',
    'NMS': 'Asia/Rangoon',
    'NMT': 'Asia/Rangoon',
    'NNA': 'Africa/Casablanca',
    'NNB': 'Pacific/Guadalcanal',
    'NNG': 'Asia/Shanghai',
    'NNL': 'America/Anchorage',
    'NNM': 'Europe/Moscow',
    'NNR': 'Europe/Dublin',
    'NNT': 'Asia/Bangkok',
    'NNX': 'Asia/Makassar',
    'NNY': 'Asia/Shanghai',
    'NOA': 'Australia/Sydney',
    'NOB': 'America/Costa_Rica',
    'NOC': 'Europe/Dublin',
    'NOD': 'Europe/Berlin',
    'NOG': 'America/Hermosillo',
    'NOJ': 'Asia/Yekaterinburg',
    'NON': 'Pacific/Tarawa',
    'NOP': 'Europe/Istanbul',
    'NOR': 'Atlantic/Reykjavik',
    'NOS': 'Indian/Antananarivo',
    'NOT': 'America/Los_Angeles',
    'NOU': 'Pacific/Noumea',
    'NOV': 'Africa/Luanda',
    'NOZ': 'Asia/Krasnoyarsk',
    'NPA': 'America/Chicago',
    'NPE': 'Pacific/Auckland',
    'NPL': 'Pacific/Auckland',
    'NPO': 'Asia/Jakarta',
    'NQA': 'America/Chicago',
    'NQI': 'America/Chicago',
    'NQN': 'America/Argentina/Salta',
    'NQT': 'Europe/London',
    'NQU': 'America/Bogota',
    'NQX': 'America/New_York',
    'NQY': 'Europe/London',
    'NRA': 'Australia/Sydney',
    'NRD': 'Europe/Berlin',
    'NRK': 'Europe/Stockholm',
    'NRL': 'Europe/London',
    'NRN': 'Europe/Berlin',
    'NRR': 'America/Puerto_Rico',
    'NRT': 'Asia/Tokyo',
    'NSE': 'America/Chicago',
    'NSH': 'Asia/Tehran',
    'NSI': 'Africa/Douala',
    'NSK': 'Asia/Krasnoyarsk',
    'NSN': 'Pacific/Auckland',
    'NSO': 'Australia/Sydney',
    'NST': 'Asia/Bangkok',
    'NSY': 'Europe/Rome',
    'NTB': 'Europe/Oslo',
    'NTD': 'America/Los_Angeles',
    'NTE': 'Europe/Paris',
    'NTI': 'Asia/Jayapura',
    'NTL': 'Australia/Sydney',
    'NTN': 'Australia/Brisbane',
    'NTQ': 'Asia/Tokyo',
    'NTR': 'America/Mexico_City',
    'NTT': 'Pacific/Tongatapu',
    'NTU': 'America/New_York',
    'NTX': 'Asia/Jakarta',
    'NTY': 'Africa/Johannesburg',
    'NUE': 'Europe/Berlin',
    'NUI': 'America/Anchorage',
    'NUL': 'America/Anchorage',
    'NUQ': 'America/Los_Angeles',
    'NUS': 'Pacific/Efate',
    'NUW': 'America/Los_Angeles',
    'NUX': 'Asia/Yekaterinburg',
    'NVA': 'America/Bogota',
    'NVI': 'Asia/Samarkand',
    'NVK': 'Europe/Oslo',
    'NVP': 'America/Boa_Vista',
    'NVS': 'Europe/Paris',
    'NVT': 'America/Sao_Paulo',
    'NWA': 'Indian/Comoro',
    'NWI': 'Europe/London',
    'NXX': 'America/New_York',
    'NYA': 'Asia/Yekaterinburg',
    'NYE': 'Africa/Nairobi',
    'NYI': 'Africa/Accra',
    'NYK': 'Africa/Nairobi',
    'NYM': 'Asia/Yekaterinburg',
    'NYO': 'Europe/Stockholm',
    'NYT': 'Asia/Rangoon',
    'NYU': 'Asia/Rangoon',
    'NYW': 'Asia/Rangoon',
    'NZA': 'Africa/Luanda',
    'NZC': 'America/Lima',
    'NZH': 'Asia/Shanghai',
    'NZJ': 'America/Los_Angeles',
    'NZY': 'America/Los_Angeles',
    'OAA': 'Asia/Kabul',
    'OAG': 'Australia/Sydney',
    'OAH': 'Asia/Kabul',
    'OAI': 'Asia/Kabul',
    'OAJ': 'America/New_York',
    'OAK': 'America/Los_Angeles',
    'OAL': 'America/Boa_Vista',
    'OAM': 'Pacific/Auckland',
    'OAR': 'America/Los_Angeles',
    'OAS': 'Asia/Kabul',
    'OAX': 'America/Mexico_City',
    'OAZ': 'Asia/Kabul',
    'OBC': 'Africa/Djibouti',
    'OBE': 'America/New_York',
    'OBF': 'Europe/Berlin',
    'OBL': 'Europe/Brussels',
    'OBN': 'Europe/London',
    'OBO': 'Asia/Tokyo',
    'OBS': 'Europe/Paris',
    'OBU': 'America/Anchorage',
    'OBY': 'America/Scoresbysund',
    'OCA': 'America/New_York',
    'OCC': 'America/Guayaquil',
    'OCF': 'America/New_York',
    'OCJ': 'America/Jamaica',
    'OCN': 'America/Los_Angeles',
    'OCV': 'America/Bogota',
    'OCW': 'America/New_York',
    'ODB': 'Europe/Madrid',
    'ODE': 'Europe/Copenhagen',
    'ODH': 'Europe/London',
    'ODN': 'Asia/Kuala_Lumpur',
    'ODO': 'Asia/Irkutsk',
    'ODS': 'Europe/Kiev',
    'ODY': 'Asia/Vientiane',
    'OEM': 'America/Paramaribo',
    'OER': 'Europe/Stockholm',
    'OES': 'America/Argentina/Salta',
    'OFF': 'America/Chicago',
    'OGD': 'America/Denver',
    'OGG': 'Pacific/Honolulu',
    'OGL': 'America/Guyana',
    'OGN': 'Asia/Tokyo',
    'OGS': 'America/New_York',
    'OGX': 'Africa/Algiers',
    'OGZ': 'Europe/Moscow',
    'OHA': 'Pacific/Auckland',
    'OHD': 'Europe/Skopje',
    'OHE': 'Asia/Shanghai',
    'OHO': 'Asia/Vladivostok',
    'OIA': 'America/Belem',
    'OIM': 'Asia/Tokyo',
    'OIR': 'Asia/Tokyo',
    'OIT': 'Asia/Tokyo',
    'OJC': 'America/Chicago',
    'OKA': 'Asia/Tokyo',
    'OKC': 'America/Chicago',
    'OKD': 'Asia/Tokyo',
    'OKE': 'Asia/Tokyo',
    'OKF': 'Africa/Windhoek',
    'OKI': 'Asia/Tokyo',
    'OKJ': 'Asia/Tokyo',
    'OKM': 'America/Chicago',
    'OKN': 'Africa/Libreville',
    'OKO': 'Asia/Tokyo',
    'OKR': 'Australia/Brisbane',
    'OKU': 'Africa/Windhoek',
    'OKY': 'Australia/Brisbane',
    'OLA': 'Europe/Oslo',
    'OLB': 'Europe/Rome',
    'OLC': 'America/Boa_Vista',
    'OLF': 'America/Denver',
    'OLJ': 'Pacific/Efate',
    'OLM': 'America/Los_Angeles',
    'OLP': 'Australia/Adelaide',
    'OLS': 'America/Phoenix',
    'OLV': 'America/Chicago',
    'OLZ': 'Asia/Yakutsk',
    'OMA': 'America/Chicago',
    'OMB': 'Africa/Libreville',
    'OMC': 'Asia/Manila',
    'OMD': 'Africa/Windhoek',
    'OME': 'America/Anchorage',
    'OMF': 'Asia/Amman',
    'OMH': 'Asia/Tehran',
    'OMI': 'Asia/Tehran',
    'OMO': 'Europe/Sarajevo',
    'OMR': 'Europe/Bucharest',
    'OMS': 'Asia/Omsk',
    'OND': 'Africa/Windhoek',
    'ONG': 'Australia/Brisbane',
    'ONJ': 'Asia/Tokyo',
    'ONK': 'Asia/Yakutsk',
    'ONO': 'America/Denver',
    'ONP': 'America/Los_Angeles',
    'ONQ': 'Europe/Istanbul',
    'ONS': 'Australia/Perth',
    'ONT': 'America/Los_Angeles',
    'ONX': 'America/Panama',
    'OOK': 'America/Anchorage',
    'OOL': 'Australia/Brisbane',
    'OOM': 'Australia/Sydney',
    'OPF': 'America/New_York',
    'OPO': 'Europe/Lisbon',
    'OPS': 'America/Campo_Grande',
    'OPU': 'Pacific/Port_Moresby',
    'ORA': 'America/Argentina/Salta',
    'ORB': 'Europe/Stockholm',
    'ORD': 'America/Chicago',
    'ORE': 'Europe/Paris',
    'ORF': 'America/New_York',
    'ORG': 'America/Paramaribo',
    'ORH': 'America/New_York',
    'ORJ': 'America/Guyana',
    'ORK': 'Europe/Dublin',
    'ORL': 'America/New_York',
    'ORN': 'Africa/Algiers',
    'ORP': 'Africa/Gaborone',
    'ORT': 'America/Anchorage',
    'ORU': 'America/La_Paz',
    'ORV': 'America/Anchorage',
    'ORW': 'Asia/Karachi',
    'ORX': 'America/Belem',
    'ORY': 'Europe/Paris',
    'OSC': 'America/New_York',
    'OSD': 'Europe/Stockholm',
    'OSF': 'Europe/Moscow',
    'OSH': 'America/Chicago',
    'OSI': 'Europe/Zagreb',
    'OSK': 'Europe/Stockholm',
    'OSL': 'Europe/Oslo',
    'OSM': 'Asia/Baghdad',
    'OSN': 'Asia/Seoul',
    'OSP': 'Europe/Warsaw',
    'OSR': 'Europe/Prague',
    'OSS': 'Asia/Bishkek',
    'OST': 'Europe/Brussels',
    'OSU': 'America/New_York',
    'OSW': 'Asia/Yekaterinburg',
    'OSY': 'Europe/Oslo',
    'OTH': 'America/Los_Angeles',
    'OTI': 'Asia/Jayapura',
    'OTK': 'America/Los_Angeles',
    'OTP': 'Europe/Bucharest',
    'OTR': 'America/Costa_Rica',
    'OTU': 'America/Bogota',
    'OTZ': 'America/Anchorage',
    'OUA': 'Africa/Ouagadougou',
    'OUD': 'Africa/Casablanca',
    'OUE': 'Africa/Brazzaville',
    'OUH': 'Africa/Johannesburg',
    'OUK': 'Europe/London',
    'OUL': 'Europe/Helsinki',
    'OUZ': 'Africa/Nouakchott',
    'OVA': 'Indian/Antananarivo',
    'OVB': 'Asia/Krasnoyarsk',
    'OVD': 'Europe/Madrid',
    'OVG': 'Africa/Johannesburg',
    'OVR': 'America/Buenos_Aires',
    'OVS': 'Asia/Yekaterinburg',
    'OWB': 'America/Chicago',
    'OWD': 'America/New_York',
    'OXB': 'Africa/Bissau',
    'OXC': 'America/New_York',
    'OXF': 'Europe/London',
    'OXR': 'America/Los_Angeles',
    'OYA': 'America/Cordoba',
    'OYE': 'Africa/Libreville',
    'OYK': 'America/Fortaleza',
    'OYL': 'Africa/Nairobi',
    'OYO': 'America/Buenos_Aires',
    'OYP': 'America/Cayenne',
    'OZA': 'America/Chicago',
    'OZC': 'Asia/Manila',
    'OZG': 'Africa/Casablanca',
    'OZH': 'Europe/Kiev',
    'OZP': 'Europe/Madrid',
    'OZZ': 'Africa/Casablanca',
    'PAA': 'Asia/Rangoon',
    'PAB': 'Asia/Calcutta',
    'PAC': 'America/Panama',
    'PAD': 'Europe/Berlin',
    'PAE': 'America/Los_Angeles',
    'PAG': 'Asia/Manila',
    'PAH': 'America/Chicago',
    'PAJ': 'Asia/Karachi',
    'PAM': 'America/Chicago',
    'PAN': 'Asia/Bangkok',
    'PAO': 'America/Los_Angeles',
    'PAP': 'America/Port-au-Prince',
    'PAQ': 'America/Anchorage',
    'PAS': 'Europe/Athens',
    'PAT': 'Asia/Calcutta',
    'PAV': 'America/Fortaleza',
    'PAX': 'America/Port-au-Prince',
    'PAZ': 'America/Mexico_City',
    'PBC': 'America/Mexico_City',
    'PBD': 'Asia/Calcutta',
    'PBF': 'America/Chicago',
    'PBG': 'America/New_York',
    'PBH': 'Asia/Thimphu',
    'PBI': 'America/New_York',
    'PBJ': 'Pacific/Efate',
    'PBL': 'America/Caracas',
    'PBM': 'America/Paramaribo',
    'PBN': 'Africa/Luanda',
    'PBO': 'Australia/Perth',
    'PBP': 'America/Costa_Rica',
    'PBR': 'America/Guatemala',
    'PBU': 'Asia/Rangoon',
    'PBZ': 'Africa/Johannesburg',
    'PCB': 'Asia/Jakarta',
    'PCF': 'Africa/Johannesburg',
    'PCL': 'America/Lima',
    'PCN': 'Pacific/Auckland',
    'PCP': 'Africa/Sao_Tome',
    'PCR': 'America/Bogota',
    'PDA': 'America/Bogota',
    'PDG': 'Asia/Jakarta',
    'PDK': 'America/New_York',
    'PDL': 'Atlantic/Azores',
    'PDO': 'Asia/Jakarta',
    'PDP': 'America/Montevideo',
    'PDS': 'America/Mexico_City',
    'PDT': 'America/Los_Angeles',
    'PDV': 'Europe/Sofia',
    'PDX': 'America/Los_Angeles',
    'PEA': 'Australia/Adelaide',
    'PED': 'Europe/Prague',
    'PEE': 'Asia/Yekaterinburg',
    'PEF': 'Europe/Berlin',
    'PEG': 'Europe/Rome',
    'PEH': 'America/Buenos_Aires',
    'PEI': 'America/Bogota',
    'PEK': 'Asia/Shanghai',
    'PEM': 'America/Lima',
    'PEN': 'Asia/Kuala_Lumpur',
    'PEQ': 'America/Chicago',
    'PER': 'Australia/Perth',
    'PES': 'Europe/Moscow',
    'PET': 'America/Sao_Paulo',
    'PEU': 'America/Tegucigalpa',
    'PEV': 'Europe/Budapest',
    'PEW': 'Asia/Karachi',
    'PEX': 'Europe/Moscow',
    'PEZ': 'Europe/Moscow',
    'PFB': 'America/Sao_Paulo',
    'PFJ': 'Atlantic/Reykjavik',
    'PFN': 'America/Chicago',
    'PFO': 'Asia/Nicosia',
    'PFQ': 'Asia/Tehran',
    'PFR': 'Africa/Lubumbashi',
    'PGA': 'America/Phoenix',
    'PGD': 'America/New_York',
    'PGF': 'Europe/Paris',
    'PGH': 'Asia/Calcutta',
    'PGK': 'Asia/Jakarta',
    'PGU': 'Asia/Tehran',
    'PGV': 'America/New_York',
    'PGX': 'Europe/Paris',
    'PHA': 'Asia/Saigon',
    'PHB': 'America/Fortaleza',
    'PHC': 'Africa/Lagos',
    'PHD': 'America/New_York',
    'PHE': 'Australia/Perth',
    'PHF': 'America/New_York',
    'PHK': 'America/New_York',
    'PHL': 'America/New_York',
    'PHN': 'America/New_York',
    'PHS': 'Asia/Bangkok',
    'PHW': 'Africa/Johannesburg',
    'PHX': 'America/Phoenix',
    'PHY': 'Asia/Bangkok',
    'PIA': 'America/Chicago',
    'PIB': 'America/Chicago',
    'PID': 'America/Nassau',
    'PIE': 'America/New_York',
    'PIF': 'Asia/Taipei',
    'PIH': 'America/Denver',
    'PIK': 'Europe/London',
    'PIL': 'America/Asuncion',
    'PIM': 'America/New_York',
    'PIN': 'America/Boa_Vista',
    'PIO': 'America/Lima',
    'PIP': 'America/Anchorage',
    'PIR': 'America/Chicago',
    'PIS': 'Europe/Paris',
    'PIT': 'America/New_York',
    'PIU': 'America/Lima',
    'PIX': 'Atlantic/Azores',
    'PIZ': 'America/Anchorage',
    'PJA': 'Europe/Stockholm',
    'PJC': 'America/Asuncion',
    'PJG': 'Asia/Karachi',
    'PJM': 'America/Costa_Rica',
    'PKA': 'America/Anchorage',
    'PKB': 'America/New_York',
    'PKC': 'Asia/Anadyr',
    'PKE': 'Australia/Sydney',
    'PKG': 'Asia/Kuala_Lumpur',
    'PKH': 'Europe/Athens',
    'PKK': 'Asia/Rangoon',
    'PKN': 'Asia/Jakarta',
    'PKP': 'Pacific/Tahiti',
    'PKR': 'Asia/Katmandu',
    'PKU': 'Asia/Jakarta',
    'PKV': 'Europe/Moscow',
    'PKW': 'Africa/Gaborone',
    'PKY': 'Asia/Jakarta',
    'PKZ': 'Asia/Vientiane',
    'PLD': 'America/Costa_Rica',
    'PLH': 'Europe/London',
    'PLL': 'America/Boa_Vista',
    'PLM': 'Asia/Jakarta',
    'PLN': 'America/New_York',
    'PLO': 'Australia/Adelaide',
    'PLP': 'America/Panama',
    'PLQ': 'Europe/Vilnius',
    'PLS': 'America/Grand_Turk',
    'PLU': 'America/Sao_Paulo',
    'PLV': 'Europe/Kiev',
    'PLW': 'Asia/Makassar',
    'PLX': 'Asia/Qyzylorda',
    'PLZ': 'Africa/Johannesburg',
    'PMA': 'Africa/Dar_es_Salaam',
    'PMB': 'America/Chicago',
    'PMC': 'America/Santiago',
    'PMD': 'America/Los_Angeles',
    'PMF': 'Europe/Rome',
    'PMG': 'America/Campo_Grande',
    'PMI': 'Europe/Madrid',
    'PMK': 'Australia/Brisbane',
    'PML': 'America/Anchorage',
    'PMO': 'Europe/Rome',
    'PMQ': 'America/Argentina/Rio_Gallegos',
    'PMR': 'Pacific/Auckland',
    'PMS': 'Asia/Damascus',
    'PMV': 'America/Caracas',
    'PMW': 'America/Fortaleza',
    'PMY': 'America/Catamarca',
    'PMZ': 'America/Costa_Rica',
    'PNA': 'Europe/Madrid',
    'PNB': 'America/Fortaleza',
    'PNC': 'America/Chicago',
    'PNE': 'America/New_York',
    'PNH': 'Asia/Phnom_Penh',
    'PNI': 'Pacific/Ponape',
    'PNK': 'Asia/Jakarta',
    'PNL': 'Europe/Rome',
    'PNP': 'Pacific/Port_Moresby',
    'PNQ': 'Asia/Calcutta',
    'PNR': 'Africa/Brazzaville',
    'PNS': 'America/Chicago',
    'PNT': 'America/Santiago',
    'PNV': 'Europe/Vilnius',
    'PNY': 'Asia/Calcutta',
    'PNZ': 'America/Fortaleza',
    'POA': 'America/Sao_Paulo',
    'POB': 'America/New_York',
    'POC': 'America/Los_Angeles',
    'POE': 'America/Chicago',
    'POF': 'America/Chicago',
    'POG': 'Africa/Libreville',
    'POI': 'America/La_Paz',
    'POJ': 'America/Sao_Paulo',
    'POL': 'Africa/Maputo',
    'POM': 'Pacific/Port_Moresby',
    'POO': 'America/Sao_Paulo',
    'POP': 'America/Santo_Domingo',
    'POR': 'Europe/Helsinki',
    'POS': 'America/Port_of_Spain',
    'POT': 'America/Jamaica',
    'POW': 'Europe/Ljubljana',
    'POX': 'Europe/Paris',
    'POZ': 'Europe/Warsaw',
    'PPB': 'America/Sao_Paulo',
    'PPC': 'America/Anchorage',
    'PPE': 'America/Hermosillo',
    'PPG': 'Pacific/Pago_Pago',
    'PPK': 'Asia/Qyzylorda',
    'PPL': 'Asia/Katmandu',
    'PPM': 'America/New_York',
    'PPN': 'America/Bogota',
    'PPP': 'Australia/Brisbane',
    'PPQ': 'Pacific/Auckland',
    'PPS': 'Asia/Manila',
    'PPT': 'Pacific/Tahiti',
    'PPW': 'Europe/London',
    'PQC': 'Asia/Saigon',
    'PQI': 'America/New_York',
    'PQQ': 'Australia/Sydney',
    'PRA': 'America/Cordoba',
    'PRC': 'America/Phoenix',
    'PRG': 'Europe/Prague',
    'PRH': 'Asia/Bangkok',
    'PRI': 'Indian/Mahe',
    'PRM': 'Europe/Lisbon',
    'PRN': 'Europe/Belgrade',
    'PRP': 'Europe/Paris',
    'PRQ': 'America/Cordoba',
    'PRU': 'Asia/Rangoon',
    'PRV': 'Europe/Prague',
    'PRY': 'Africa/Johannesburg',
    'PRZ': 'America/Los_Angeles',
    'PSA': 'Europe/Rome',
    'PSC': 'America/Los_Angeles',
    'PSD': 'Africa/Cairo',
    'PSE': 'America/Puerto_Rico',
    'PSG': 'America/Anchorage',
    'PSH': 'Europe/Berlin',
    'PSI': 'Asia/Karachi',
    'PSJ': 'Asia/Makassar',
    'PSL': 'Europe/London',
    'PSM': 'America/New_York',
    'PSO': 'America/Bogota',
    'PSP': 'America/Los_Angeles',
    'PSR': 'Europe/Rome',
    'PSS': 'America/Cordoba',
    'PSU': 'Asia/Jakarta',
    'PSX': 'America/Chicago',
    'PSY': 'Atlantic/Stanley',
    'PSZ': 'America/La_Paz',
    'PTA': 'America/Anchorage',
    'PTB': 'America/New_York',
    'PTF': 'Pacific/Fiji',
    'PTG': 'Africa/Johannesburg',
    'PTH': 'America/Anchorage',
    'PTJ': 'Australia/Hobart',
    'PTK': 'America/New_York',
    'PTM': 'America/Caracas',
    'PTP': 'America/Guadeloupe',
    'PTU': 'America/Anchorage',
    'PTX': 'America/Bogota',
    'PTY': 'America/Panama',
    'PTZ': 'America/Guayaquil',
    'PUB': 'America/Denver',
    'PUC': 'America/Denver',
    'PUD': 'America/Argentina/Rio_Gallegos',
    'PUE': 'America/Panama',
    'PUF': 'Europe/Paris',
    'PUG': 'Australia/Adelaide',
    'PUJ': 'America/Santo_Domingo',
    'PUQ': 'America/Santiago',
    'PUR': 'America/La_Paz',
    'PUS': 'Asia/Seoul',
    'PUU': 'America/Bogota',
    'PUW': 'America/Los_Angeles',
    'PUY': 'Europe/Zagreb',
    'PUZ': 'America/Managua',
    'PVA': 'America/Bogota',
    'PVC': 'America/New_York',
    'PVD': 'America/New_York',
    'PVG': 'Asia/Shanghai',
    'PVH': 'America/Boa_Vista',
    'PVK': 'Europe/Athens',
    'PVL': 'America/New_York',
    'PVO': 'America/Guayaquil',
    'PVR': 'America/Mexico_City',
    'PVS': 'Asia/Anadyr',
    'PVU': 'America/Denver',
    'PWA': 'America/Chicago',
    'PWK': 'America/Chicago',
    'PWM': 'America/New_York',
    'PWQ': 'Asia/Qyzylorda',
    'PWT': 'America/Los_Angeles',
    'PXH': 'Australia/Adelaide',
    'PXM': 'America/Mexico_City',
    'PXO': 'Europe/Lisbon',
    'PXR': 'Asia/Bangkok',
    'PXU': 'Asia/Saigon',
    'PYE': 'Pacific/Rarotonga',
    'PYH': 'America/Caracas',
    'PYJ': 'Asia/Yakutsk',
    'PYM': 'America/New_York',
    'PYR': 'Europe/Athens',
    'PYY': 'Asia/Bangkok',
    'PZB': 'Africa/Johannesburg',
    'PZE': 'Europe/London',
    'PZH': 'Asia/Karachi',
    'PZI': 'Asia/Shanghai',
    'PZO': 'America/Caracas',
    'PZS': 'America/Santiago',
    'PZU': 'Africa/Khartoum',
    'PZY': 'Europe/Bratislava',
    'QBC': 'America/Vancouver',
    'QCJ': 'America/Sao_Paulo',
    'QCY': 'Europe/London',
    'QDJ': 'Africa/Algiers',
    'QEF': 'Europe/Berlin',
    'QFO': 'Europe/London',
    'QGU': 'Asia/Tokyo',
    'QHR': 'Africa/Addis_Ababa',
    'QIG': 'America/Fortaleza',
    'QJB': 'Asia/Riyadh',
    'QLA': 'Europe/London',
    'QLD': 'Africa/Algiers',
    'QLF': 'Europe/Helsinki',
    'QLR': 'Europe/Lisbon',
    'QLS': 'Europe/Zurich',
    'QLT': 'Europe/Rome',
    'QNC': 'Europe/Zurich',
    'QNJ': 'Europe/Paris',
    'QNV': 'America/Sao_Paulo',
    'QOW': 'Africa/Lagos',
    'QPA': 'Europe/Rome',
    'QPD': 'America/Havana',
    'QPG': 'Asia/Singapore',
    'QPS': 'America/Sao_Paulo',
    'QRA': 'Africa/Johannesburg',
    'QRC': 'America/Santiago',
    'QRO': 'America/Mexico_City',
    'QRW': 'Africa/Lagos',
    'QSA': 'Europe/Madrid',
    'QSC': 'America/Sao_Paulo',
    'QSF': 'Africa/Algiers',
    'QSR': 'Europe/Rome',
    'QUO': 'Africa/Lagos',
    'QUY': 'Europe/London',
    'QXH': 'Europe/Berlin',
    'QYD': 'Europe/Warsaw',
    'RAB': 'Pacific/Port_Moresby',
    'RAC': 'America/Chicago',
    'RAE': 'Asia/Riyadh',
    'RAH': 'Asia/Riyadh',
    'RAI': 'Atlantic/Cape_Verde',
    'RAJ': 'Asia/Calcutta',
    'RAK': 'Africa/Casablanca',
    'RAL': 'America/Los_Angeles',
    'RAM': 'Australia/Darwin',
    'RAO': 'America/Sao_Paulo',
    'RAP': 'America/Denver',
    'RAR': 'Pacific/Rarotonga',
    'RAS': 'Asia/Tehran',
    'RAT': 'Asia/Yekaterinburg',
    'RAZ': 'Asia/Karachi',
    'RBA': 'Africa/Casablanca',
    'RBB': 'America/Boa_Vista',
    'RBD': 'America/Chicago',
    'RBE': 'Asia/Phnom_Penh',
    'RBK': 'America/Los_Angeles',
    'RBL': 'America/Los_Angeles',
    'RBM': 'Europe/Berlin',
    'RBQ': 'America/La_Paz',
    'RBR': 'America/Rio_Branco',
    'RBV': 'Pacific/Guadalcanal',
    'RBX': 'Africa/Juba',
    'RBY': 'America/Anchorage',
    'RCA': 'America/Denver',
    'RCB': 'Africa/Johannesburg',
    'RCH': 'America/Bogota',
    'RCL': 'Pacific/Efate',
    'RCO': 'Europe/Paris',
    'RCQ': 'America/Cordoba',
    'RCS': 'Europe/London',
    'RCU': 'America/Cordoba',
    'RCY': 'America/Nassau',
    'RDC': 'America/Belem',
    'RDD': 'America/Los_Angeles',
    'RDG': 'America/New_York',
    'RDM': 'America/Los_Angeles',
    'RDN': 'Asia/Kuala_Lumpur',
    'RDO': 'Europe/Warsaw',
    'RDR': 'America/Chicago',
    'RDS': 'America/Argentina/Salta',
    'RDU': 'America/New_York',
    'RDZ': 'Europe/Paris',
    'REB': 'Europe/Berlin',
    'REC': 'America/Fortaleza',
    'REG': 'Europe/Rome',
    'REL': 'America/Catamarca',
    'REN': 'Asia/Yekaterinburg',
    'REP': 'Asia/Phnom_Penh',
    'RER': 'America/Guatemala',
    'RES': 'America/Cordoba',
    'RET': 'Europe/Oslo',
    'REU': 'Europe/Madrid',
    'REX': 'America/Mexico_City',
    'REY': 'America/La_Paz',
    'RFD': 'America/Chicago',
    'RFP': 'Pacific/Tahiti',
    'RFS': 'America/Managua',
    'RGA': 'America/Argentina/Ushuaia',
    'RGI': 'Pacific/Tahiti',
    'RGK': 'Asia/Krasnoyarsk',
    'RGL': 'America/Argentina/Rio_Gallegos',
    'RGN': 'Asia/Rangoon',
    'RGO': 'Asia/Pyongyang',
    'RGS': 'Europe/Madrid',
    'RGT': 'Asia/Jakarta',
    'RHD': 'America/Cordoba',
    'RHE': 'Europe/Paris',
    'RHI': 'America/Chicago',
    'RHO': 'Europe/Athens',
    'RHP': 'Asia/Katmandu',
    'RIA': 'America/Sao_Paulo',
    'RIB': 'America/La_Paz',
    'RIC': 'America/New_York',
    'RIL': 'America/Denver',
    'RIN': 'Pacific/Guadalcanal',
    'RIS': 'Asia/Tokyo',
    'RIV': 'America/Los_Angeles',
    'RIW': 'America/Denver',
    'RIX': 'Europe/Riga',
    'RIY': 'Asia/Aden',
    'RJA': 'Asia/Calcutta',
    'RJH': 'Asia/Dhaka',
    'RJK': 'Europe/Zagreb',
    'RJL': 'Europe/Madrid',
    'RJN': 'Asia/Tehran',
    'RKD': 'America/New_York',
    'RKE': 'Europe/Copenhagen',
    'RKH': 'America/New_York',
    'RKP': 'America/Chicago',
    'RKS': 'America/Denver',
    'RKT': 'Asia/Dubai',
    'RKV': 'Atlantic/Reykjavik',
    'RKZ': 'Asia/Shanghai',
    'RLG': 'Europe/Berlin',
    'RLK': 'Asia/Shanghai',
    'RMA': 'Australia/Brisbane',
    'RME': 'America/New_York',
    'RMF': 'Africa/Cairo',
    'RMG': 'America/New_York',
    'RMI': 'Europe/Rome',
    'RMK': 'Australia/Adelaide',
    'RML': 'Asia/Colombo',
    'RMQ': 'Asia/Taipei',
    'RMS': 'Europe/Berlin',
    'RMY': 'America/Los_Angeles',
    'RNA': 'Pacific/Guadalcanal',
    'RNB': 'Europe/Stockholm',
    'RND': 'America/Chicago',
    'RNE': 'Europe/Paris',
    'RNI': 'America/Managua',
    'RNJ': 'Asia/Tokyo',
    'RNL': 'Pacific/Guadalcanal',
    'RNN': 'Europe/Copenhagen',
    'RNO': 'America/Los_Angeles',
    'RNS': 'Europe/Paris',
    'RNT': 'America/Los_Angeles',
    'ROA': 'America/New_York',
    'ROB': 'Africa/Monrovia',
    'ROC': 'America/New_York',
    'ROD': 'Africa/Johannesburg',
    'ROI': 'Asia/Bangkok',
    'ROK': 'Australia/Brisbane',
    'ROO': 'America/Campo_Grande',
    'ROP': 'Pacific/Saipan',
    'ROR': 'Pacific/Palau',
    'ROS': 'America/Cordoba',
    'ROT': 'Pacific/Auckland',
    'ROV': 'Europe/Moscow',
    'ROW': 'America/Denver',
    'ROZ': 'Europe/Madrid',
    'RPB': 'Australia/Darwin',
    'RPN': 'Asia/Jerusalem',
    'RPR': 'Asia/Calcutta',
    'RRG': 'Indian/Mauritius',
    'RRK': 'Asia/Calcutta',
    'RRS': 'Europe/Oslo',
    'RSA': 'America/Argentina/Salta',
    'RSD': 'America/Nassau',
    'RSH': 'America/Anchorage',
    'RSS': 'Africa/Khartoum',
    'RST': 'America/Chicago',
    'RSU': 'Asia/Seoul',
    'RSW': 'America/New_York',
    'RTA': 'Pacific/Fiji',
    'RTB': 'America/Tegucigalpa',
    'RTG': 'Asia/Makassar',
    'RTM': 'Europe/Amsterdam',
    'RTS': 'Australia/Perth',
    'RTW': 'Europe/Moscow',
    'RUA': 'Africa/Kampala',
    'RUD': 'Asia/Tehran',
    'RUH': 'Asia/Riyadh',
    'RUI': 'America/Denver',
    'RUK': 'Asia/Katmandu',
    'RUM': 'Asia/Katmandu',
    'RUN': 'Indian/Reunion',
    'RUS': 'Pacific/Guadalcanal',
    'RUT': 'America/New_York',
    'RVA': 'Indian/Antananarivo',
    'RVD': 'America/Sao_Paulo',
    'RVE': 'America/Bogota',
    'RVK': 'Europe/Oslo',
    'RVN': 'Europe/Helsinki',
    'RVS': 'America/Chicago',
    'RVT': 'Australia/Perth',
    'RVV': 'Pacific/Tahiti',
    'RVY': 'America/Montevideo',
    'RWI': 'America/New_York',
    'RWL': 'America/Denver',
    'RWN': 'Europe/Kiev',
    'RXS': 'Asia/Manila',
    'RYB': 'Europe/Moscow',
    'RYG': 'Europe/Oslo',
    'RYK': 'Asia/Karachi',
    'RYN': 'Europe/Paris',
    'RZA': 'America/Argentina/Rio_Gallegos',
    'RZE': 'Europe/Warsaw',
    'RZP': 'Asia/Manila',
    'RZR': 'Asia/Tehran',
    'SAA': 'America/Denver',
    'SAB': 'America/Curacao',
    'SAC': 'America/Los_Angeles',
    'SAD': 'America/Phoenix',
    'SAF': 'America/Denver',
    'SAH': 'Asia/Aden',
    'SAK': 'Atlantic/Reykjavik',
    'SAL': 'America/El_Salvador',
    'SAN': 'America/Los_Angeles',
    'SAP': 'America/Tegucigalpa',
    'SAQ': 'America/Nassau',
    'SAT': 'America/Chicago',
    'SAV': 'America/New_York',
    'SAW': 'Europe/Istanbul',
    'SAY': 'Europe/Rome',
    'SBA': 'America/Los_Angeles',
    'SBB': 'America/Caracas',
    'SBD': 'America/Los_Angeles',
    'SBG': 'Asia/Jakarta',
    'SBK': 'Europe/Paris',
    'SBL': 'America/La_Paz',
    'SBM': 'America/Chicago',
    'SBN': 'America/New_York',
    'SBP': 'America/Los_Angeles',
    'SBR': 'Australia/Brisbane',
    'SBS': 'America/Denver',
    'SBU': 'Africa/Johannesburg',
    'SBW': 'Asia/Kuala_Lumpur',
    'SBY': 'America/New_York',
    'SBZ': 'Europe/Bucharest',
    'SCC': 'America/Anchorage',
    'SCE': 'America/New_York',
    'SCF': 'America/Phoenix',
    'SCH': 'America/New_York',
    'SCI': 'America/Caracas',
    'SCK': 'America/Los_Angeles',
    'SCL': 'America/Santiago',
    'SCM': 'America/Anchorage',
    'SCN': 'Europe/Berlin',
    'SCO': 'Asia/Oral',
    'SCQ': 'Europe/Madrid',
    'SCS': 'Europe/London',
    'SCT': 'Asia/Aden',
    'SCU': 'America/Havana',
    'SCV': 'Europe/Bucharest',
    'SCW': 'Europe/Moscow',
    'SCY': 'Pacific/Galapagos',
    'SCZ': 'Pacific/Guadalcanal',
    'SDB': 'Africa/Johannesburg',
    'SDD': 'Africa/Luanda',
    'SDE': 'America/Cordoba',
    'SDF': 'America/New_York',
    'SDG': 'Asia/Tehran',
    'SDJ': 'Asia/Tokyo',
    'SDK': 'Asia/Kuala_Lumpur',
    'SDL': 'Europe/Stockholm',
    'SDM': 'America/Los_Angeles',
    'SDN': 'Europe/Oslo',
    'SDP': 'America/Anchorage',
    'SDQ': 'America/Santo_Domingo',
    'SDR': 'Europe/Madrid',
    'SDS': 'Asia/Tokyo',
    'SDT': 'Asia/Karachi',
    'SDU': 'America/Sao_Paulo',
    'SDV': 'Asia/Jerusalem',
    'SDX': 'America/Phoenix',
    'SDY': 'America/Denver',
    'SEA': 'America/Los_Angeles',
    'SEB': 'Africa/Tripoli',
    'SEE': 'America/Los_Angeles',
    'SEF': 'America/New_York',
    'SEH': 'Asia/Jayapura',
    'SEK': 'Asia/Srednekolymsk',
    'SEM': 'America/Chicago',
    'SEN': 'Europe/London',
    'SEP': 'America/Chicago',
    'SEU': 'Africa/Dar_es_Salaam',
    'SEY': 'Africa/Nouakchott',
    'SEZ': 'Indian/Mahe',
    'SFA': 'Africa/Tunis',
    'SFB': 'America/New_York',
    'SFC': 'America/Guadeloupe',
    'SFD': 'America/Caracas',
    'SFE': 'Asia/Manila',
    'SFF': 'America/Los_Angeles',
    'SFH': 'America/Tijuana',
    'SFJ': 'America/Godthab',
    'SFK': 'America/Belem',
    'SFL': 'Atlantic/Cape_Verde',
    'SFN': 'America/Cordoba',
    'SFO': 'America/Los_Angeles',
    'SFQ': 'Europe/Istanbul',
    'SFS': 'Asia/Manila',
    'SFT': 'Europe/Stockholm',
    'SFZ': 'America/New_York',
    'SGC': 'Asia/Yekaterinburg',
    'SGD': 'Europe/Copenhagen',
    'SGE': 'Europe/Berlin',
    'SGF': 'America/Chicago',
    'SGH': 'America/New_York',
    'SGN': 'Asia/Saigon',
    'SGO': 'Australia/Brisbane',
    'SGR': 'America/Chicago',
    'SGU': 'America/Denver',
    'SGV': 'America/Argentina/Salta',
    'SGX': 'Africa/Dar_es_Salaam',
    'SGY': 'America/Anchorage',
    'SGZ': 'Asia/Bangkok',
    'SHA': 'Asia/Shanghai',
    'SHB': 'Asia/Tokyo',
    'SHD': 'America/New_York',
    'SHE': 'Asia/Shanghai',
    'SHG': 'America/Anchorage',
    'SHH': 'America/Anchorage',
    'SHI': 'Asia/Tokyo',
    'SHJ': 'Asia/Dubai',
    'SHL': 'Asia/Calcutta',
    'SHM': 'Asia/Tokyo',
    'SHN': 'America/Los_Angeles',
    'SHP': 'Asia/Shanghai',
    'SHR': 'America/Denver',
    'SHT': 'Australia/Hobart',
    'SHV': 'America/Chicago',
    'SHW': 'Asia/Riyadh',
    'SHX': 'America/Anchorage',
    'SHY': 'Africa/Dar_es_Salaam',
    'SIA': 'Asia/Shanghai',
    'SID': 'Atlantic/Cape_Verde',
    'SIF': 'Asia/Katmandu',
    'SIG': 'America/Puerto_Rico',
    'SIJ': 'Atlantic/Reykjavik',
    'SIK': 'America/Chicago',
    'SIN': 'Asia/Singapore',
    'SIP': 'Europe/Simferopol',
    'SIQ': 'Asia/Jakarta',
    'SIR': 'Europe/Zurich',
    'SIS': 'Africa/Johannesburg',
    'SIT': 'America/Anchorage',
    'SIU': 'America/Managua',
    'SJC': 'America/Los_Angeles',
    'SJD': 'America/Mazatlan',
    'SJE': 'America/Bogota',
    'SJI': 'Asia/Manila',
    'SJJ': 'Europe/Sarajevo',
    'SJK': 'America/Sao_Paulo',
    'SJL': 'America/Boa_Vista',
    'SJO': 'America/Costa_Rica',
    'SJP': 'America/Sao_Paulo',
    'SJT': 'America/Chicago',
    'SJU': 'America/Puerto_Rico',
    'SJW': 'Asia/Shanghai',
    'SJY': 'Europe/Helsinki',
    'SJZ': 'Atlantic/Azores',
    'SKA': 'America/Los_Angeles',
    'SKB': 'America/St_Kitts',
    'SKD': 'Asia/Samarkand',
    'SKE': 'Europe/Oslo',
    'SKF': 'America/Chicago',
    'SKG': 'Europe/Athens',
    'SKH': 'Asia/Katmandu',
    'SKK': 'America/Anchorage',
    'SKN': 'Europe/Oslo',
    'SKO': 'Africa/Lagos',
    'SKP': 'Europe/Skopje',
    'SKS': 'Europe/Copenhagen',
    'SKT': 'Asia/Karachi',
    'SKU': 'Europe/Athens',
    'SKV': 'Africa/Cairo',
    'SKX': 'Europe/Moscow',
    'SKY': 'America/New_York',
    'SKZ': 'Asia/Karachi',
    'SLA': 'America/Argentina/Salta',
    'SLC': 'America/Denver',
    'SLD': 'Europe/Bratislava',
    'SLE': 'America/Los_Angeles',
    'SLF': 'Asia/Riyadh',
    'SLH': 'Pacific/Efate',
    'SLJ': 'Australia/Perth',
    'SLK': 'America/New_York',
    'SLL': 'Asia/Muscat',
    'SLM': 'Europe/Madrid',
    'SLN': 'America/Chicago',
    'SLP': 'America/Mexico_City',
    'SLQ': 'America/Anchorage',
    'SLU': 'America/St_Lucia',
    'SLV': 'Asia/Calcutta',
    'SLW': 'America/Mexico_City',
    'SLX': 'America/Grand_Turk',
    'SLY': 'Asia/Yekaterinburg',
    'SLZ': 'America/Fortaleza',
    'SMA': 'Atlantic/Azores',
    'SMD': 'America/New_York',
    'SME': 'America/New_York',
    'SMF': 'America/Los_Angeles',
    'SMI': 'Europe/Athens',
    'SMK': 'America/Anchorage',
    'SML': 'America/Nassau',
    'SMN': 'America/Denver',
    'SMO': 'America/Los_Angeles',
    'SMQ': 'Asia/Jakarta',
    'SMR': 'America/Bogota',
    'SMS': 'Indian/Antananarivo',
    'SMV': 'Europe/Zurich',
    'SMW': 'Africa/El_Aaiun',
    'SMX': 'America/Los_Angeles',
    'SMZ': 'America/Paramaribo',
    'SNA': 'America/Los_Angeles',
    'SNC': 'America/Guayaquil',
    'SNE': 'Atlantic/Cape_Verde',
    'SNF': 'America/Caracas',
    'SNN': 'Europe/Dublin',
    'SNO': 'Asia/Bangkok',
    'SNP': 'America/Anchorage',
    'SNR': 'Europe/Paris',
    'SNU': 'America/Havana',
    'SNV': 'America/Caracas',
    'SNW': 'Asia/Rangoon',
    'SNY': 'America/Denver',
    'SNZ': 'America/Sao_Paulo',
    'SOB': 'Europe/Budapest',
    'SOC': 'Asia/Jakarta',
    'SOD': 'America/Sao_Paulo',
    'SOF': 'Europe/Sofia',
    'SOG': 'Europe/Oslo',
    'SOJ': 'Europe/Oslo',
    'SOM': 'America/Caracas',
    'SON': 'Pacific/Efate',
    'SOO': 'Europe/Stockholm',
    'SOP': 'America/New_York',
    'SOQ': 'Asia/Jayapura',
    'SOT': 'Europe/Helsinki',
    'SOU': 'Europe/London',
    'SOW': 'America/Phoenix',
    'SOY': 'Europe/London',
    'SOZ': 'Europe/Paris',
    'SPB': 'America/St_Thomas',
    'SPC': 'Atlantic/Canary',
    'SPD': 'Asia/Dhaka',
    'SPF': 'America/Denver',
    'SPG': 'America/New_York',
    'SPI': 'America/Chicago',
    'SPJ': 'Europe/Athens',
    'SPM': 'Europe/Berlin',
    'SPN': 'Pacific/Saipan',
    'SPP': 'Africa/Luanda',
    'SPR': 'America/Belize',
    'SPS': 'America/Chicago',
    'SPU': 'Europe/Zagreb',
    'SPW': 'America/Chicago',
    'SPY': 'Africa/Abidjan',
    'SQG': 'Asia/Jakarta',
    'SQH': 'Asia/Saigon',
    'SQL': 'America/Los_Angeles',
    'SQO': 'Europe/Stockholm',
    'SQQ': 'Europe/Vilnius',
    'SQR': 'Asia/Makassar',
    'SQW': 'Europe/Copenhagen',
    'SQZ': 'Europe/London',
    'SRA': 'America/Sao_Paulo',
    'SRE': 'America/La_Paz',
    'SRG': 'Asia/Jakarta',
    'SRH': 'Africa/Ndjamena',
    'SRI': 'Asia/Makassar',
    'SRJ': 'America/La_Paz',
    'SRN': 'Australia/Melbourne',
    'SRP': 'Europe/Oslo',
    'SRQ': 'America/New_York',
    'SRT': 'Africa/Kampala',
    'SRX': 'Africa/Tripoli',
    'SRY': 'Asia/Tehran',
    'SRZ': 'America/La_Paz',
    'SSA': 'America/Fortaleza',
    'SSC': 'America/New_York',
    'SSE': 'Asia/Calcutta',
    'SSG': 'Africa/Malabo',
    'SSH': 'Africa/Cairo',
    'SSI': 'America/New_York',
    'SSJ': 'Europe/Oslo',
    'SSN': 'Asia/Seoul',
    'SSR': 'Pacific/Efate',
    'SST': 'America/Buenos_Aires',
    'SSY': 'Africa/Luanda',
    'SSZ': 'America/Sao_Paulo',
    'STA': 'Europe/Copenhagen',
    'STB': 'America/Caracas',
    'STC': 'America/Chicago',
    'STD': 'America/Caracas',
    'STE': 'America/Chicago',
    'STG': 'America/Anchorage',
    'STI': 'America/Santo_Domingo',
    'STJ': 'America/Chicago',
    'STK': 'America/Denver',
    'STL': 'America/Chicago',
    'STM': 'America/Belem',
    'STN': 'Europe/London',
    'STP': 'America/Chicago',
    'STR': 'Europe/Berlin',
    'STS': 'America/Los_Angeles',
    'STT': 'America/St_Thomas',
    'STV': 'Asia/Calcutta',
    'STW': 'Europe/Moscow',
    'STX': 'America/St_Thomas',
    'STY': 'America/Montevideo',
    'STZ': 'America/Campo_Grande',
    'SUA': 'America/New_York',
    'SUB': 'Asia/Jakarta',
    'SUF': 'Europe/Rome',
    'SUG': 'Asia/Manila',
    'SUI': 'Asia/Tbilisi',
    'SUJ': 'Europe/Bucharest',
    'SUL': 'Asia/Karachi',
    'SUN': 'America/Denver',
    'SUR': 'America/Toronto',
    'SUS': 'America/Chicago',
    'SUU': 'America/Los_Angeles',
    'SUV': 'Pacific/Fiji',
    'SUX': 'America/Chicago',
    'SUY': 'Asia/Yakutsk',
    'SVA': 'America/Anchorage',
    'SVB': 'Indian/Antananarivo',
    'SVD': 'America/St_Vincent',
    'SVG': 'Europe/Oslo',
    'SVH': 'America/New_York',
    'SVI': 'America/Bogota',
    'SVJ': 'Europe/Oslo',
    'SVL': 'Europe/Helsinki',
    'SVN': 'America/New_York',
    'SVO': 'Europe/Moscow',
    'SVP': 'Africa/Luanda',
    'SVQ': 'Europe/Madrid',
    'SVU': 'Pacific/Fiji',
    'SVW': 'America/Anchorage',
    'SVX': 'Asia/Yekaterinburg',
    'SVZ': 'America/Caracas',
    'SWA': 'Asia/Shanghai',
    'SWD': 'America/Anchorage',
    'SWF': 'America/New_York',
    'SWJ': 'Pacific/Efate',
    'SWO': 'America/Chicago',
    'SWP': 'Africa/Windhoek',
    'SWQ': 'Asia/Makassar',
    'SWS': 'Europe/London',
    'SWT': 'Asia/Krasnoyarsk',
    'SWU': 'Asia/Seoul',
    'SWX': 'Africa/Gaborone',
    'SXB': 'Europe/Paris',
    'SXF': 'Europe/Berlin',
    'SXI': 'Asia/Tehran',
    'SXL': 'Europe/Dublin',
    'SXM': 'America/Curacao',
    'SXO': 'America/Campo_Grande',
    'SXQ': 'America/Anchorage',
    'SXR': 'Asia/Calcutta',
    'SXV': 'Asia/Calcutta',
    'SXX': 'America/Belem',
    'SXZ': 'Europe/Istanbul',
    'SYA': 'America/Adak',
    'SYD': 'Australia/Sydney',
    'SYH': 'Asia/Katmandu',
    'SYJ': 'Asia/Tehran',
    'SYM': 'Asia/Shanghai',
    'SYO': 'Asia/Tokyo',
    'SYP': 'America/Panama',
    'SYQ': 'America/Costa_Rica',
    'SYR': 'America/New_York',
    'SYS': 'Asia/Yakutsk',
    'SYT': 'Europe/Paris',
    'SYU': 'Australia/Brisbane',
    'SYW': 'Asia/Karachi',
    'SYX': 'Asia/Shanghai',
    'SYY': 'Europe/London',
    'SYZ': 'Asia/Tehran',
    'SZA': 'Africa/Luanda',
    'SZB': 'Asia/Kuala_Lumpur',
    'SZF': 'Europe/Istanbul',
    'SZG': 'Europe/Vienna',
    'SZJ': 'America/Havana',
    'SZK': 'Africa/Johannesburg',
    'SZL': 'America/Chicago',
    'SZR': 'Europe/Sofia',
    'SZS': 'Pacific/Auckland',
    'SZT': 'America/Mexico_City',
    'SZV': 'Asia/Shanghai',
    'SZW': 'Europe/Berlin',
    'SZX': 'Asia/Shanghai',
    'SZZ': 'Europe/Warsaw',
    'TAB': 'America/Port_of_Spain',
    'TAC': 'Asia/Manila',
    'TAE': 'Asia/Seoul',
    'TAF': 'Africa/Algiers',
    'TAG': 'Asia/Manila',
    'TAH': 'Pacific/Efate',
    'TAI': 'Asia/Aden',
    'TAK': 'Asia/Tokyo',
    'TAM': 'America/Mexico_City',
    'TAO': 'Asia/Shanghai',
    'TAP': 'America/Mexico_City',
    'TAR': 'Europe/Rome',
    'TAS': 'Asia/Samarkand',
    'TAT': 'Europe/Bratislava',
    'TAY': 'Europe/Tallinn',
    'TAZ': 'Asia/Ashgabat',
    'TBB': 'Asia/Saigon',
    'TBG': 'Pacific/Port_Moresby',
    'TBH': 'Asia/Manila',
    'TBI': 'America/Nassau',
    'TBJ': 'Africa/Tunis',
    'TBN': 'America/Chicago',
    'TBO': 'Africa/Dar_es_Salaam',
    'TBP': 'America/Lima',
    'TBS': 'Asia/Tbilisi',
    'TBT': 'America/Boa_Vista',
    'TBU': 'Pacific/Tongatapu',
    'TBW': 'Europe/Moscow',
    'TBZ': 'Asia/Tehran',
    'TCA': 'Australia/Darwin',
    'TCB': 'America/Nassau',
    'TCC': 'America/Denver',
    'TCE': 'Europe/Bucharest',
    'TCG': 'Asia/Shanghai',
    'TCH': 'Africa/Libreville',
    'TCL': 'America/Chicago',
    'TCM': 'America/Los_Angeles',
    'TCN': 'America/Mexico_City',
    'TCO': 'America/Bogota',
    'TCP': 'Africa/Cairo',
    'TCQ': 'America/Lima',
    'TCS': 'America/Denver',
    'TCX': 'Asia/Tehran',
    'TCZ': 'Asia/Shanghai',
    'TDD': 'America/La_Paz',
    'TDG': 'Asia/Manila',
    'TDJ': 'Africa/Djibouti',
    'TDL': 'America/Buenos_Aires',
    'TDR': 'Australia/Brisbane',
    'TDX': 'Asia/Bangkok',
    'TEA': 'America/Tegucigalpa',
    'TEB': 'America/New_York',
    'TEC': 'America/Sao_Paulo',
    'TED': 'Europe/Copenhagen',
    'TEE': 'Africa/Algiers',
    'TEF': 'Australia/Perth',
    'TEM': 'Australia/Sydney',
    'TEN': 'Asia/Shanghai',
    'TEQ': 'Europe/Istanbul',
    'TER': 'Atlantic/Azores',
    'TET': 'Africa/Maputo',
    'TEU': 'Pacific/Auckland',
    'TEX': 'America/Denver',
    'TEZ': 'Asia/Calcutta',
    'TFF': 'America/Boa_Vista',
    'TFN': 'Atlantic/Canary',
    'TFS': 'Atlantic/Canary',
    'TGA': 'Asia/Singapore',
    'TGD': 'Europe/Podgorica',
    'TGG': 'Asia/Kuala_Lumpur',
    'TGH': 'Pacific/Efate',
    'TGI': 'America/Lima',
    'TGJ': 'Pacific/Noumea',
    'TGK': 'Europe/Moscow',
    'TGM': 'Europe/Bucharest',
    'TGO': 'Asia/Shanghai',
    'TGP': 'Asia/Krasnoyarsk',
    'TGR': 'Africa/Algiers',
    'TGT': 'Africa/Dar_es_Salaam',
    'TGU': 'America/Tegucigalpa',
    'TGZ': 'America/Mexico_City',
    'THE': 'America/Fortaleza',
    'THF': 'Europe/Berlin',
    'THG': 'Australia/Brisbane',
    'THL': 'Asia/Rangoon',
    'THN': 'Europe/Stockholm',
    'THO': 'Atlantic/Reykjavik',
    'THQ': 'Asia/Shanghai',
    'THR': 'Asia/Tehran',
    'THS': 'Asia/Bangkok',
    'THU': 'America/Thule',
    'THX': 'Asia/Krasnoyarsk',
    'THZ': 'Africa/Niamey',
    'TIA': 'Europe/Tirane',
    'TID': 'Africa/Algiers',
    'TIE': 'Africa/Addis_Ababa',
    'TIF': 'Asia/Riyadh',
    'TIH': 'Pacific/Tahiti',
    'TII': 'Asia/Kabul',
    'TIJ': 'America/Tijuana',
    'TIK': 'America/Chicago',
    'TIM': 'Asia/Jayapura',
    'TIN': 'Africa/Algiers',
    'TIP': 'Africa/Tripoli',
    'TIQ': 'Pacific/Saipan',
    'TIR': 'Asia/Calcutta',
    'TIU': 'Pacific/Auckland',
    'TIV': 'Europe/Podgorica',
    'TIW': 'America/Los_Angeles',
    'TIX': 'America/New_York',
    'TIY': 'Africa/Nouakchott',
    'TIZ': 'Pacific/Port_Moresby',
    'TJA': 'America/La_Paz',
    'TJG': 'Asia/Makassar',
    'TJH': 'Asia/Tokyo',
    'TJI': 'America/Tegucigalpa',
    'TJK': 'Europe/Istanbul',
    'TJL': 'America/Campo_Grande',
    'TJM': 'Asia/Yekaterinburg',
    'TJQ': 'Asia/Jakarta',
    'TJS': 'Asia/Makassar',
    'TJU': 'Asia/Dushanbe',
    'TJV': 'Asia/Calcutta',
    'TKA': 'America/Anchorage',
    'TKC': 'Africa/Douala',
    'TKD': 'Africa/Accra',
    'TKF': 'America/Los_Angeles',
    'TKG': 'Asia/Jakarta',
    'TKH': 'Asia/Bangkok',
    'TKJ': 'America/Anchorage',
    'TKK': 'Pacific/Truk',
    'TKN': 'Asia/Tokyo',
    'TKP': 'Pacific/Tahiti',
    'TKQ': 'Africa/Dar_es_Salaam',
    'TKS': 'Asia/Tokyo',
    'TKT': 'Asia/Bangkok',
    'TKU': 'Europe/Helsinki',
    'TKX': 'Pacific/Tahiti',
    'TLA': 'America/Anchorage',
    'TLC': 'America/Mexico_City',
    'TLD': 'Africa/Gaborone',
    'TLE': 'Indian/Antananarivo',
    'TLH': 'America/New_York',
    'TLJ': 'America/Anchorage',
    'TLL': 'Europe/Tallinn',
    'TLM': 'Africa/Algiers',
    'TLN': 'Europe/Paris',
    'TLQ': 'Asia/Shanghai',
    'TLS': 'Europe/Paris',
    'TLU': 'America/Bogota',
    'TLV': 'Asia/Jerusalem',
    'TMA': 'America/New_York',
    'TMB': 'America/New_York',
    'TMC': 'Asia/Makassar',
    'TME': 'America/Bogota',
    'TMG': 'Asia/Kuala_Lumpur',
    'TMI': 'Asia/Katmandu',
    'TMJ': 'Asia/Samarkand',
    'TML': 'Africa/Accra',
    'TMM': 'Indian/Antananarivo',
    'TMN': 'Pacific/Tarawa',
    'TMO': 'America/Caracas',
    'TMP': 'Europe/Helsinki',
    'TMR': 'Africa/Algiers',
    'TMS': 'Africa/Sao_Tome',
    'TMT': 'America/Belem',
    'TMU': 'America/Costa_Rica',
    'TMW': 'Australia/Sydney',
    'TMX': 'Africa/Algiers',
    'TNA': 'Asia/Shanghai',
    'TNC': 'America/Anchorage',
    'TND': 'America/Havana',
    'TNE': 'Asia/Tokyo',
    'TNF': 'Europe/Paris',
    'TNG': 'Africa/Casablanca',
    'TNH': 'Asia/Shanghai',
    'TNI': 'Asia/Calcutta',
    'TNJ': 'Asia/Jakarta',
    'TNM': 'Antarctica/South_Pole',
    'TNN': 'Asia/Taipei',
    'TNR': 'Indian/Antananarivo',
    'TNT': 'America/New_York',
    'TNX': 'Asia/Phnom_Penh',
    'TOA': 'America/Los_Angeles',
    'TOB': 'Africa/Tripoli',
    'TOC': 'America/New_York',
    'TOD': 'Asia/Kuala_Lumpur',
    'TOE': 'Africa/Tunis',
    'TOF': 'Asia/Krasnoyarsk',
    'TOG': 'America/Anchorage',
    'TOH': 'Pacific/Efate',
    'TOJ': 'Europe/Madrid',
    'TOL': 'America/New_York',
    'TOM': 'Africa/Bamako',
    'TOO': 'America/Costa_Rica',
    'TOP': 'America/Chicago',
    'TOS': 'Europe/Oslo',
    'TOT': 'America/Paramaribo',
    'TOU': 'Pacific/Noumea',
    'TOW': 'America/Sao_Paulo',
    'TOY': 'Asia/Tokyo',
    'TPA': 'America/New_York',
    'TPC': 'America/Guayaquil',
    'TPE': 'Asia/Taipei',
    'TPJ': 'Asia/Katmandu',
    'TPL': 'America/Chicago',
    'TPN': 'America/Guayaquil',
    'TPP': 'America/Lima',
    'TPQ': 'America/Mazatlan',
    'TPS': 'Europe/Rome',
    'TQD': 'Asia/Baghdad',
    'TQQ': 'Asia/Makassar',
    'TRA': 'Asia/Tokyo',
    'TRC': 'America/Mexico_City',
    'TRD': 'Europe/Oslo',
    'TRE': 'Europe/London',
    'TRF': 'Europe/Oslo',
    'TRG': 'Pacific/Auckland',
    'TRI': 'America/New_York',
    'TRK': 'Asia/Makassar',
    'TRM': 'America/Los_Angeles',
    'TRN': 'Europe/Rome',
    'TRO': 'Australia/Sydney',
    'TRQ': 'America/Rio_Branco',
    'TRR': 'Asia/Colombo',
    'TRS': 'Europe/Rome',
    'TRU': 'America/Lima',
    'TRV': 'Asia/Calcutta',
    'TRW': 'Pacific/Tarawa',
    'TRZ': 'Asia/Calcutta',
    'TSA': 'Asia/Taipei',
    'TSB': 'Africa/Windhoek',
    'TSE': 'Asia/Qyzylorda',
    'TSF': 'Europe/Rome',
    'TSH': 'Africa/Lubumbashi',
    'TSJ': 'Asia/Tokyo',
    'TSL': 'America/Mexico_City',
    'TSN': 'Asia/Shanghai',
    'TSR': 'Europe/Bucharest',
    'TST': 'Asia/Bangkok',
    'TSU': 'Pacific/Tarawa',
    'TSV': 'Australia/Brisbane',
    'TSX': 'Asia/Makassar',
    'TSY': 'Asia/Jakarta',
    'TTA': 'Africa/Casablanca',
    'TTB': 'Europe/Rome',
    'TTD': 'America/Los_Angeles',
    'TTE': 'Asia/Jayapura',
    'TTG': 'America/Argentina/Salta',
    'TTH': 'Asia/Muscat',
    'TTI': 'Pacific/Tahiti',
    'TTJ': 'Asia/Tokyo',
    'TTN': 'America/New_York',
    'TTQ': 'America/Costa_Rica',
    'TTR': 'Asia/Makassar',
    'TTT': 'Asia/Taipei',
    'TTU': 'Africa/Casablanca',
    'TUA': 'America/Guayaquil',
    'TUB': 'Pacific/Tahiti',
    'TUC': 'America/Argentina/Tucuman',
    'TUD': 'Africa/Dakar',
    'TUF': 'Europe/Paris',
    'TUG': 'Asia/Manila',
    'TUI': 'Asia/Riyadh',
    'TUK': 'Asia/Karachi',
    'TUL': 'America/Chicago',
    'TUN': 'Africa/Tunis',
    'TUO': 'Pacific/Auckland',
    'TUP': 'America/Chicago',
    'TUR': 'America/Belem',
    'TUS': 'America/Phoenix',
    'TUU': 'Asia/Riyadh',
    'TUV': 'America/Caracas',
    'TVA': 'Indian/Antananarivo',
    'TVC': 'America/New_York',
    'TVF': 'America/Chicago',
    'TVI': 'America/New_York',
    'TVL': 'America/Los_Angeles',
    'TVU': 'Pacific/Fiji',
    'TVY': 'Asia/Rangoon',
    'TWB': 'Australia/Brisbane',
    'TWF': 'America/Denver',
    'TWT': 'Asia/Manila',
    'TWU': 'Asia/Kuala_Lumpur',
    'TWZ': 'Pacific/Auckland',
    'TXG': 'Asia/Taipei',
    'TXK': 'America/Chicago',
    'TXL': 'Europe/Berlin',
    'TXN': 'Asia/Shanghai',
    'TYF': 'Europe/Stockholm',
    'TYL': 'America/Lima',
    'TYM': 'America/Nassau',
    'TYN': 'Asia/Shanghai',
    'TYR': 'America/Chicago',
    'TYS': 'America/New_York',
    'TZL': 'Europe/Sarajevo',
    'TZR': 'Europe/Budapest',
    'TZX': 'Europe/Istanbul',
    'UAB': 'Europe/Istanbul',
    'UAH': 'Pacific/Marquesas',
    'UAI': 'Asia/Dili',
    'UAK': 'America/Godthab',
    'UAM': 'Pacific/Guam',
    'UAP': 'Pacific/Marquesas',
    'UAQ': 'America/Argentina/San_Juan',
    'UAR': 'Africa/Casablanca',
    'UAS': 'Africa/Nairobi',
    'UBA': 'America/Sao_Paulo',
    'UBB': 'Australia/Brisbane',
    'UBJ': 'Asia/Tokyo',
    'UBP': 'Asia/Bangkok',
    'UCK': 'Europe/Kiev',
    'UCT': 'Europe/Moscow',
    'UDD': 'America/Los_Angeles',
    'UDI': 'America/Sao_Paulo',
    'UDJ': 'Europe/Kiev',
    'UDR': 'Asia/Calcutta',
    'UEL': 'Africa/Maputo',
    'UEO': 'Asia/Tokyo',
    'UET': 'Asia/Karachi',
    'UFA': 'Asia/Yekaterinburg',
    'UGA': 'Asia/Ulaanbaatar',
    'UGC': 'Asia/Samarkand',
    'UGN': 'America/Chicago',
    'UGO': 'Africa/Luanda',
    'UHE': 'Europe/Prague',
    'UIB': 'America/Bogota',
    'UIH': 'Asia/Saigon',
    'UII': 'America/Tegucigalpa',
    'UIK': 'Asia/Irkutsk',
    'UIN': 'America/Chicago',
    'UIO': 'America/Guayaquil',
    'UIP': 'Europe/Paris',
    'UJE': 'Pacific/Majuro',
    'UKA': 'Africa/Nairobi',
    'UKB': 'Asia/Tokyo',
    'UKK': 'Asia/Qyzylorda',
    'UKS': 'Europe/Simferopol',
    'UKX': 'Asia/Irkutsk',
    'ULA': 'America/Argentina/Rio_Gallegos',
    'ULB': 'Pacific/Efate',
    'ULD': 'Africa/Johannesburg',
    'ULG': 'Asia/Hovd',
    'ULH': 'Asia/Riyadh',
    'ULK': 'Asia/Yakutsk',
    'ULN': 'Asia/Ulaanbaatar',
    'ULO': 'Asia/Hovd',
    'ULP': 'Australia/Brisbane',
    'ULQ': 'America/Bogota',
    'ULU': 'Africa/Kampala',
    'ULV': 'Europe/Samara',
    'ULY': 'Europe/Samara',
    'ULZ': 'Asia/Ulaanbaatar',
    'UMD': 'America/Godthab',
    'UME': 'Europe/Stockholm',
    'UMR': 'Australia/Adelaide',
    'UMS': 'Asia/Yakutsk',
    'UMU': 'America/Sao_Paulo',
    'UNA': 'America/Fortaleza',
    'UND': 'Asia/Kabul',
    'UNG': 'Pacific/Port_Moresby',
    'UNI': 'America/St_Vincent',
    'UNK': 'America/Anchorage',
    'UNN': 'Asia/Bangkok',
    'UNT': 'Europe/London',
    'UOS': 'America/Chicago',
    'UPB': 'America/Havana',
    'UPG': 'Asia/Makassar',
    'UPN': 'America/Mexico_City',
    'UPP': 'Pacific/Honolulu',
    'URA': 'Asia/Oral',
    'URC': 'Asia/Shanghai',
    'URD': 'Europe/Berlin',
    'URE': 'Europe/Tallinn',
    'URG': 'America/Sao_Paulo',
    'URJ': 'Asia/Yekaterinburg',
    'URO': 'Europe/Paris',
    'URS': 'Europe/Moscow',
    'URT': 'Asia/Bangkok',
    'URY': 'Asia/Riyadh',
    'USA': 'America/New_York',
    'USH': 'America/Argentina/Ushuaia',
    'USI': 'America/Guyana',
    'USK': 'Europe/Moscow',
    'USM': 'Asia/Bangkok',
    'USN': 'Asia/Seoul',
    'USQ': 'Europe/Istanbul',
    'USR': 'Asia/Vladivostok',
    'USS': 'America/Havana',
    'UST': 'America/New_York',
    'USU': 'Asia/Manila',
    'UTA': 'Africa/Harare',
    'UTC': 'Europe/Amsterdam',
    'UTH': 'Asia/Bangkok',
    'UTI': 'Europe/Helsinki',
    'UTK': 'Pacific/Majuro',
    'UTM': 'America/Chicago',
    'UTN': 'Africa/Johannesburg',
    'UTO': 'America/Anchorage',
    'UTP': 'Asia/Bangkok',
    'UTS': 'Europe/Moscow',
    'UTT': 'Africa/Johannesburg',
    'UTW': 'Africa/Johannesburg',
    'UUA': 'Europe/Moscow',
    'UUD': 'Asia/Irkutsk',
    'UUK': 'America/Anchorage',
    'UUS': 'Asia/Srednekolymsk',
    'UVA': 'America/Chicago',
    'UVE': 'Pacific/Noumea',
    'UVF': 'America/St_Lucia',
    'UYL': 'Africa/Khartoum',
    'UYN': 'Asia/Shanghai',
    'UYU': 'America/La_Paz',
    'UZU': 'America/Cordoba',
    'VAA': 'Europe/Helsinki',
    'VAD': 'America/New_York',
    'VAF': 'Europe/Paris',
    'VAG': 'America/Sao_Paulo',
    'VAI': 'Pacific/Port_Moresby',
    'VAK': 'America/Anchorage',
    'VAL': 'America/Fortaleza',
    'VAM': 'Indian/Maldives',
    'VAN': 'Europe/Istanbul',
    'VAO': 'Pacific/Guadalcanal',
    'VAR': 'Europe/Sofia',
    'VAS': 'Europe/Istanbul',
    'VAV': 'Pacific/Tongatapu',
    'VAW': 'Europe/Oslo',
    'VBA': 'Asia/Rangoon',
    'VBG': 'America/Los_Angeles',
    'VBP': 'Asia/Rangoon',
    'VBS': 'Europe/Rome',
    'VBV': 'Pacific/Fiji',
    'VBY': 'Europe/Stockholm',
    'VCA': 'Asia/Saigon',
    'VCD': 'Australia/Darwin',
    'VCE': 'Europe/Rome',
    'VCL': 'Asia/Saigon',
    'VCP': 'America/Sao_Paulo',
    'VCR': 'America/Caracas',
    'VCS': 'Asia/Saigon',
    'VCT': 'America/Chicago',
    'VCV': 'America/Los_Angeles',
    'VDA': 'Asia/Jerusalem',
    'VDB': 'Europe/Oslo',
    'VDC': 'America/Fortaleza',
    'VDE': 'Atlantic/Canary',
    'VDH': 'Asia/Saigon',
    'VDM': 'America/Argentina/Salta',
    'VDP': 'America/Caracas',
    'VDR': 'America/Cordoba',
    'VDS': 'Europe/Oslo',
    'VDZ': 'America/Anchorage',
    'VEE': 'America/Anchorage',
    'VEL': 'America/Denver',
    'VER': 'America/Mexico_City',
    'VEY': 'Atlantic/Reykjavik',
    'VFA': 'Africa/Harare',
    'VGA': 'Asia/Calcutta',
    'VGD': 'Europe/Moscow',
    'VGO': 'Europe/Madrid',
    'VGT': 'America/Los_Angeles',
    'VGZ': 'America/Bogota',
    'VHC': 'Africa/Luanda',
    'VHM': 'Europe/Stockholm',
    'VHY': 'Europe/Paris',
    'VIC': 'Europe/Rome',
    'VIE': 'Europe/Vienna',
    'VIG': 'America/Caracas',
    'VII': 'Asia/Saigon',
    'VIJ': 'America/Tortola',
    'VIL': 'Africa/El_Aaiun',
    'VIN': 'Europe/Kiev',
    'VIR': 'Africa/Johannesburg',
    'VIS': 'America/Los_Angeles',
    'VIT': 'Europe/Madrid',
    'VIX': 'America/Sao_Paulo',
    'VIY': 'Europe/Paris',
    'VKG': 'Asia/Saigon',
    'VKO': 'Europe/Moscow',
    'VKT': 'Europe/Moscow',
    'VLC': 'Europe/Madrid',
    'VLD': 'America/New_York',
    'VLG': 'America/Buenos_Aires',
    'VLI': 'Pacific/Efate',
    'VLL': 'Europe/Madrid',
    'VLM': 'America/La_Paz',
    'VLN': 'America/Caracas',
    'VLR': 'America/Santiago',
    'VLS': 'Pacific/Efate',
    'VLU': 'Europe/Moscow',
    'VLV': 'America/Caracas',
    'VLY': 'Europe/London',
    'VME': 'America/Argentina/San_Luis',
    'VMU': 'Pacific/Port_Moresby',
    'VNA': 'Asia/Vientiane',
    'VNC': 'America/New_York',
    'VNE': 'Europe/Paris',
    'VNO': 'Europe/Vilnius',
    'VNS': 'Asia/Calcutta',
    'VNT': 'Europe/Riga',
    'VNX': 'Africa/Maputo',
    'VNY': 'America/Los_Angeles',
    'VOD': 'Europe/Prague',
    'VOG': 'Europe/Moscow',
    'VOH': 'Indian/Antananarivo',
    'VOK': 'America/Chicago',
    'VOL': 'Europe/Athens',
    'VOZ': 'Europe/Moscow',
    'VPE': 'Africa/Luanda',
    'VPN': 'Atlantic/Reykjavik',
    'VPS': 'America/Chicago',
    'VPY': 'Africa/Maputo',
    'VQQ': 'America/New_York',
    'VQS': 'America/Puerto_Rico',
    'VRA': 'America/Havana',
    'VRB': 'America/New_York',
    'VRC': 'Asia/Manila',
    'VRE': 'Africa/Johannesburg',
    'VRK': 'Europe/Helsinki',
    'VRL': 'Europe/Lisbon',
    'VRN': 'Europe/Rome',
    'VRO': 'America/Havana',
    'VRU': 'Africa/Johannesburg',
    'VRY': 'Europe/Oslo',
    'VSA': 'America/Mexico_City',
    'VSE': 'Europe/Lisbon',
    'VSG': 'Europe/Kiev',
    'VST': 'Europe/Stockholm',
    'VTB': 'Europe/Minsk',
    'VTE': 'Asia/Vientiane',
    'VTM': 'Asia/Jerusalem',
    'VTU': 'America/Havana',
    'VTZ': 'Asia/Calcutta',
    'VUP': 'America/Bogota',
    'VUS': 'Europe/Moscow',
    'VVC': 'America/Bogota',
    'VVI': 'America/La_Paz',
    'VVO': 'Asia/Vladivostok',
    'VVZ': 'Africa/Algiers',
    'VXC': 'Africa/Maputo',
    'VXE': 'Atlantic/Cape_Verde',
    'VXO': 'Europe/Stockholm',
    'VYS': 'America/Chicago',
    'WAA': 'America/Anchorage',
    'WAE': 'Asia/Riyadh',
    'WAF': 'Asia/Karachi',
    'WAG': 'Pacific/Auckland',
    'WAI': 'Indian/Antananarivo',
    'WAL': 'America/New_York',
    'WAM': 'Indian/Antananarivo',
    'WAQ': 'Indian/Antananarivo',
    'WAR': 'Asia/Jayapura',
    'WAT': 'Europe/Dublin',
    'WAW': 'Europe/Warsaw',
    'WBG': 'Europe/Berlin',
    'WBM': 'Pacific/Port_Moresby',
    'WBQ': 'America/Anchorage',
    'WBU': 'America/Denver',
    'WBW': 'America/New_York',
    'WCH': 'America/Santiago',
    'WDH': 'Africa/Windhoek',
    'WDR': 'America/New_York',
    'WEF': 'Asia/Shanghai',
    'WEH': 'Asia/Shanghai',
    'WEI': 'Australia/Brisbane',
    'WFI': 'Indian/Antananarivo',
    'WFK': 'America/New_York',
    'WGA': 'Australia/Sydney',
    'WGE': 'Australia/Sydney',
    'WGP': 'Asia/Makassar',
    'WHF': 'Africa/Khartoum',
    'WHK': 'Pacific/Auckland',
    'WHP': 'America/Los_Angeles',
    'WIC': 'Europe/London',
    'WIE': 'Europe/Berlin',
    'WIL': 'Africa/Nairobi',
    'WIN': 'Australia/Brisbane',
    'WIO': 'Australia/Sydney',
    'WIR': 'Pacific/Auckland',
    'WJR': 'Africa/Nairobi',
    'WJU': 'Asia/Seoul',
    'WKA': 'Pacific/Auckland',
    'WKF': 'Africa/Johannesburg',
    'WKJ': 'Asia/Tokyo',
    'WKK': 'America/Anchorage',
    'WKL': 'Pacific/Honolulu',
    'WLD': 'America/Chicago',
    'WLG': 'Pacific/Auckland',
    'WLH': 'Pacific/Efate',
    'WLK': 'America/Anchorage',
    'WLS': 'Pacific/Wallis',
    'WMA': 'Indian/Antananarivo',
    'WME': 'Australia/Perth',
    'WMI': 'Europe/Warsaw',
    'WMN': 'Indian/Antananarivo',
    'WMO': 'America/Anchorage',
    'WMP': 'Indian/Antananarivo',
    'WMR': 'Indian/Antananarivo',
    'WMX': 'Asia/Jayapura',
    'WNA': 'America/Anchorage',
    'WNN': 'America/Toronto',
    'WNP': 'Asia/Manila',
    'WNR': 'Australia/Brisbane',
    'WNS': 'Asia/Karachi',
    'WNZ': 'Asia/Shanghai',
    'WOE': 'Europe/Amsterdam',
    'WOL': 'Australia/Sydney',
    'WOT': 'Asia/Taipei',
    'WPB': 'Indian/Antananarivo',
    'WPR': 'America/Santiago',
    'WPU': 'America/Santiago',
    'WRB': 'America/New_York',
    'WRE': 'Pacific/Auckland',
    'WRG': 'America/Anchorage',
    'WRI': 'America/New_York',
    'WRL': 'America/Denver',
    'WRO': 'Europe/Warsaw',
    'WRT': 'Europe/London',
    'WRY': 'Europe/London',
    'WRZ': 'Asia/Colombo',
    'WSD': 'America/Denver',
    'WSN': 'America/Anchorage',
    'WSO': 'America/Paramaribo',
    'WSP': 'America/Managua',
    'WSR': 'Asia/Jayapura',
    'WST': 'America/New_York',
    'WSY': 'Australia/Brisbane',
    'WSZ': 'Pacific/Auckland',
    'WTA': 'Indian/Antananarivo',
    'WTB': 'Australia/Brisbane',
    'WTK': 'America/Anchorage',
    'WTN': 'Europe/London',
    'WTS': 'Indian/Antananarivo',
    'WTZ': 'Pacific/Auckland',
    'WUA': 'Asia/Shanghai',
    'WUH': 'Asia/Shanghai',
    'WUN': 'Australia/Perth',
    'WUS': 'Asia/Shanghai',
    'WUU': 'Africa/Juba',
    'WUX': 'Asia/Shanghai',
    'WUZ': 'Asia/Shanghai',
    'WVB': 'Africa/Windhoek',
    'WVK': 'Indian/Antananarivo',
    'WVN': 'Europe/Berlin',
    'WWD': 'America/New_York',
    'WWK': 'Pacific/Port_Moresby',
    'WXN': 'Asia/Shanghai',
    'WYA': 'Australia/Adelaide',
    'WYE': 'Africa/Freetown',
    'WYN': 'Australia/Perth',
    'WYS': 'America/Denver',
    'XAB': 'Europe/Paris',
    'XAP': 'America/Sao_Paulo',
    'XAU': 'America/Cayenne',
    'XBE': 'America/Winnipeg',
    'XBJ': 'Asia/Tehran',
    'XCH': 'Indian/Christmas',
    'XCR': 'Europe/Paris',
    'XCZ': 'Europe/Paris',
    'XFN': 'Asia/Shanghai',
    'XFW': 'Europe/Berlin',
    'XGN': 'Africa/Luanda',
    'XGR': 'America/Toronto',
    'XIC': 'Asia/Shanghai',
    'XIL': 'Asia/Shanghai',
    'XIY': 'Asia/Shanghai',
    'XJD': 'Asia/Qatar',
    'XJM': 'Asia/Karachi',
    'XKH': 'Asia/Vientiane',
    'XKS': 'America/Toronto',
    'XLB': 'America/Winnipeg',
    'XLS': 'Africa/Dakar',
    'XMC': 'Australia/Hobart',
    'XME': 'Europe/Paris',
    'XMH': 'Pacific/Tahiti',
    'XMN': 'Asia/Shanghai',
    'XMS': 'America/Guayaquil',
    'XMW': 'Europe/Paris',
    'XMY': 'Australia/Brisbane',
    'XNA': 'America/Chicago',
    'XNN': 'Asia/Shanghai',
    'XOG': 'Europe/Paris',
    'XQC': 'Asia/Baghdad',
    'XQP': 'America/Costa_Rica',
    'XRH': 'Australia/Sydney',
    'XRY': 'Europe/Madrid',
    'XSB': 'Asia/Dubai',
    'XSC': 'America/Grand_Turk',
    'XSD': 'America/Los_Angeles',
    'XSI': 'America/Winnipeg',
    'XSP': 'Asia/Singapore',
    'XTG': 'Australia/Brisbane',
    'XTL': 'America/Winnipeg',
    'XUZ': 'Asia/Shanghai',
    'XVS': 'Europe/Paris',
    'XYA': 'Pacific/Guadalcanal',
    'XYE': 'Asia/Rangoon',
    'YAA': 'America/Vancouver',
    'YAB': 'America/Winnipeg',
    'YAC': 'America/Winnipeg',
    'YAG': 'America/Winnipeg',
    'YAI': 'America/Santiago',
    'YAK': 'America/Anchorage',
    'YAM': 'America/Toronto',
    'YAO': 'Africa/Douala',
    'YAP': 'Pacific/Truk',
    'YAT': 'America/Toronto',
    'YAX': 'America/Winnipeg',
    'YAY': 'America/St_Johns',
    'YAZ': 'America/Vancouver',
    'YBB': 'America/Edmonton',
    'YBC': 'America/Toronto',
    'YBE': 'America/Regina',
    'YBG': 'America/Toronto',
    'YBI': 'America/Halifax',
    'YBK': 'America/Winnipeg',
    'YBL': 'America/Vancouver',
    'YBO': 'America/Vancouver',
    'YBP': 'Asia/Shanghai',
    'YBR': 'America/Winnipeg',
    'YBT': 'America/Winnipeg',
    'YBV': 'America/Winnipeg',
    'YBW': 'America/Vancouver',
    'YBX': 'America/Blanc-Sablon',
    'YBY': 'America/Edmonton',
    'YCB': 'America/Edmonton',
    'YCC': 'America/Toronto',
    'YCD': 'America/Vancouver',
    'YCG': 'America/Vancouver',
    'YCH': 'America/Halifax',
    'YCK': 'America/Edmonton',
    'YCL': 'America/Halifax',
    'YCM': 'America/Toronto',
    'YCN': 'America/Toronto',
    'YCO': 'America/Edmonton',
    'YCR': 'America/Winnipeg',
    'YCS': 'America/Winnipeg',
    'YCT': 'America/Edmonton',
    'YCU': 'Asia/Shanghai',
    'YCW': 'America/Vancouver',
    'YCY': 'America/Toronto',
    'YDA': 'America/Vancouver',
    'YDB': 'America/Vancouver',
    'YDF': 'America/St_Johns',
    'YDL': 'America/Vancouver',
    'YDN': 'America/Winnipeg',
    'YDP': 'America/Halifax',
    'YDQ': 'America/Dawson_Creek',
    'YDT': 'America/Vancouver',
    'YEC': 'Asia/Seoul',
    'YEG': 'America/Edmonton',
    'YEI': 'Europe/Istanbul',
    'YEK': 'America/Winnipeg',
    'YEL': 'America/Toronto',
    'YEM': 'America/Toronto',
    'YEN': 'America/Regina',
    'YEO': 'Europe/London',
    'YER': 'America/Toronto',
    'YES': 'Asia/Tehran',
    'YET': 'America/Edmonton',
    'YEU': 'America/Winnipeg',
    'YEV': 'America/Edmonton',
    'YFA': 'America/Toronto',
    'YFB': 'America/Toronto',
    'YFC': 'America/Halifax',
    'YFE': 'America/Toronto',
    'YFH': 'America/Toronto',
    'YFJ': 'America/Edmonton',
    'YFO': 'America/Winnipeg',
    'YFR': 'America/Edmonton',
    'YFS': 'America/Edmonton',
    'YFX': 'America/St_Johns',
    'YGB': 'America/Vancouver',
    'YGG': 'America/Vancouver',
    'YGH': 'America/Edmonton',
    'YGJ': 'Asia/Tokyo',
    'YGK': 'America/Toronto',
    'YGL': 'America/Toronto',
    'YGM': 'America/Winnipeg',
    'YGO': 'America/Winnipeg',
    'YGP': 'America/Toronto',
    'YGQ': 'America/Toronto',
    'YGR': 'America/Toronto',
    'YGT': 'America/Toronto',
    'YGV': 'America/Toronto',
    'YGW': 'America/Toronto',
    'YGX': 'America/Winnipeg',
    'YGZ': 'America/Toronto',
    'YHA': 'America/St_Johns',
    'YHB': 'America/Regina',
    'YHD': 'America/Winnipeg',
    'YHF': 'America/Toronto',
    'YHI': 'America/Edmonton',
    'YHK': 'America/Edmonton',
    'YHM': 'America/Toronto',
    'YHN': 'America/Toronto',
    'YHO': 'America/Halifax',
    'YHP': 'America/Winnipeg',
    'YHR': 'America/Blanc-Sablon',
    'YHU': 'America/Toronto',
    'YHY': 'America/Edmonton',
    'YHZ': 'America/Halifax',
    'YIB': 'America/Coral_Harbour',
    'YIC': 'Asia/Shanghai',
    'YIF': 'America/Blanc-Sablon',
    'YIH': 'Asia/Shanghai',
    'YIK': 'America/Toronto',
    'YIN': 'Asia/Shanghai',
    'YIO': 'America/Toronto',
    'YIP': 'America/New_York',
    'YIV': 'America/Winnipeg',
    'YIW': 'Asia/Shanghai',
    'YJN': 'America/Toronto',
    'YJT': 'America/St_Johns',
    'YKA': 'America/Vancouver',
    'YKF': 'America/Toronto',
    'YKG': 'America/Toronto',
    'YKL': 'America/Toronto',
    'YKM': 'America/Los_Angeles',
    'YKN': 'America/Chicago',
    'YKQ': 'America/Toronto',
    'YKS': 'Asia/Yakutsk',
    'YKU': 'America/Toronto',
    'YKX': 'America/Toronto',
    'YKY': 'America/Regina',
    'YKZ': 'America/Toronto',
    'YLC': 'America/Toronto',
    'YLD': 'America/Toronto',
    'YLE': 'America/Edmonton',
    'YLH': 'America/Toronto',
    'YLI': 'Europe/Helsinki',
    'YLJ': 'America/Regina',
    'YLK': 'America/Toronto',
    'YLL': 'America/Edmonton',
    'YLT': 'America/Toronto',
    'YLW': 'America/Vancouver',
    'YLY': 'America/Vancouver',
    'YMA': 'America/Vancouver',
    'YMG': 'America/Toronto',
    'YMH': 'America/St_Johns',
    'YMJ': 'America/Regina',
    'YMM': 'America/Edmonton',
    'YMN': 'America/Halifax',
    'YMO': 'America/Toronto',
    'YMS': 'America/Lima',
    'YMT': 'America/Toronto',
    'YMW': 'America/Toronto',
    'YMX': 'America/Toronto',
    'YNA': 'America/Toronto',
    'YNB': 'Asia/Riyadh',
    'YNC': 'America/Toronto',
    'YND': 'America/Toronto',
    'YNE': 'America/Winnipeg',
    'YNG': 'America/New_York',
    'YNJ': 'Asia/Shanghai',
    'YNL': 'America/Regina',
    'YNM': 'America/Toronto',
    'YNO': 'America/Winnipeg',
    'YNP': 'America/Halifax',
    'YNS': 'America/Toronto',
    'YNT': 'Asia/Shanghai',
    'YNY': 'Asia/Seoul',
    'YNZ': 'Asia/Shanghai',
    'YOA': 'America/Edmonton',
    'YOC': 'America/Vancouver',
    'YOD': 'America/Edmonton',
    'YOG': 'America/Toronto',
    'YOH': 'America/Winnipeg',
    'YOJ': 'America/Edmonton',
    'YOL': 'Africa/Lagos',
    'YOO': 'America/Toronto',
    'YOP': 'America/Edmonton',
    'YOW': 'America/Toronto',
    'YPA': 'America/Regina',
    'YPC': 'America/Edmonton',
    'YPD': 'America/Toronto',
    'YPE': 'America/Edmonton',
    'YPG': 'America/Winnipeg',
    'YPH': 'America/Toronto',
    'YPJ': 'America/Toronto',
    'YPL': 'America/Coral_Harbour',
    'YPM': 'America/Winnipeg',
    'YPN': 'America/Toronto',
    'YPO': 'America/Toronto',
    'YPQ': 'America/Toronto',
    'YPR': 'America/Vancouver',
    'YPW': 'America/Vancouver',
    'YPX': 'America/Toronto',
    'YPY': 'America/Edmonton',
    'YQA': 'America/Toronto',
    'YQB': 'America/Toronto',
    'YQC': 'America/Toronto',
    'YQD': 'America/Winnipeg',
    'YQF': 'America/Edmonton',
    'YQG': 'America/Toronto',
    'YQH': 'America/Vancouver',
    'YQI': 'America/Halifax',
    'YQK': 'America/Winnipeg',
    'YQL': 'America/Edmonton',
    'YQM': 'America/Halifax',
    'YQN': 'America/Toronto',
    'YQQ': 'America/Vancouver',
    'YQR': 'America/Regina',
    'YQT': 'America/Toronto',
    'YQU': 'America/Edmonton',
    'YQV': 'America/Regina',
    'YQW': 'America/Regina',
    'YQX': 'America/St_Johns',
    'YQY': 'America/Halifax',
    'YQZ': 'America/Vancouver',
    'YRA': 'America/Edmonton',
    'YRB': 'America/Winnipeg',
    'YRF': 'America/Halifax',
    'YRG': 'America/Halifax',
    'YRI': 'America/Toronto',
    'YRJ': 'America/Toronto',
    'YRL': 'America/Winnipeg',
    'YRM': 'America/Edmonton',
    'YRQ': 'America/Toronto',
    'YRS': 'America/Winnipeg',
    'YRT': 'America/Winnipeg',
    'YRV': 'America/Vancouver',
    'YSB': 'America/Toronto',
    'YSC': 'America/Toronto',
    'YSD': 'America/Edmonton',
    'YSF': 'America/Regina',
    'YSJ': 'America/Halifax',
    'YSM': 'America/Edmonton',
    'YSO': 'America/Halifax',
    'YSP': 'America/Toronto',
    'YSR': 'America/Toronto',
    'YST': 'America/Winnipeg',
    'YSU': 'America/Halifax',
    'YSY': 'America/Edmonton',
    'YTA': 'America/Toronto',
    'YTE': 'America/Toronto',
    'YTF': 'America/Toronto',
    'YTH': 'America/Winnipeg',
    'YTL': 'America/Winnipeg',
    'YTM': 'America/Toronto',
    'YTQ': 'America/Toronto',
    'YTR': 'America/Toronto',
    'YTS': 'America/Toronto',
    'YTY': 'Asia/Shanghai',
    'YTZ': 'America/Toronto',
    'YUB': 'America/Edmonton',
    'YUD': 'America/Toronto',
    'YUE': 'Australia/Darwin',
    'YUL': 'America/Toronto',
    'YUM': 'America/Phoenix',
    'YUS': 'Asia/Shanghai',
    'YUT': 'America/Winnipeg',
    'YUX': 'America/Toronto',
    'YUY': 'America/Toronto',
    'YVA': 'Indian/Comoro',
    'YVB': 'America/Toronto',
    'YVC': 'America/Regina',
    'YVG': 'America/Edmonton',
    'YVM': 'America/Toronto',
    'YVO': 'America/Toronto',
    'YVP': 'America/Toronto',
    'YVQ': 'America/Edmonton',
    'YVR': 'America/Vancouver',
    'YVT': 'America/Regina',
    'YVV': 'America/Toronto',
    'YVZ': 'America/Winnipeg',
    'YWA': 'America/Toronto',
    'YWB': 'America/Toronto',
    'YWG': 'America/Winnipeg',
    'YWH': 'America/Vancouver',
    'YWJ': 'America/Edmonton',
    'YWK': 'America/Halifax',
    'YWL': 'America/Vancouver',
    'YWM': 'America/St_Johns',
    'YWP': 'America/Toronto',
    'YWS': 'America/Vancouver',
    'YWY': 'America/Edmonton',
    'YXC': 'America/Edmonton',
    'YXD': 'America/Edmonton',
    'YXE': 'America/Regina',
    'YXH': 'America/Edmonton',
    'YXJ': 'America/Dawson_Creek',
    'YXK': 'America/Toronto',
    'YXL': 'America/Winnipeg',
    'YXN': 'America/Winnipeg',
    'YXP': 'America/Toronto',
    'YXR': 'America/Toronto',
    'YXS': 'America/Vancouver',
    'YXT': 'America/Vancouver',
    'YXU': 'America/Toronto',
    'YXX': 'America/Vancouver',
    'YXY': 'America/Vancouver',
    'YXZ': 'America/Toronto',
    'YYB': 'America/Toronto',
    'YYC': 'America/Edmonton',
    'YYD': 'America/Vancouver',
    'YYE': 'America/Vancouver',
    'YYF': 'America/Vancouver',
    'YYG': 'America/Halifax',
    'YYH': 'America/Edmonton',
    'YYJ': 'America/Vancouver',
    'YYL': 'America/Winnipeg',
    'YYN': 'America/Regina',
    'YYQ': 'America/Winnipeg',
    'YYR': 'America/Halifax',
    'YYT': 'America/St_Johns',
    'YYU': 'America/Toronto',
    'YYW': 'America/Toronto',
    'YYY': 'America/Toronto',
    'YYZ': 'America/Toronto',
    'YZD': 'America/Toronto',
    'YZE': 'America/Toronto',
    'YZF': 'America/Edmonton',
    'YZG': 'America/Toronto',
    'YZH': 'America/Edmonton',
    'YZP': 'America/Vancouver',
    'YZR': 'America/Toronto',
    'YZS': 'America/Coral_Harbour',
    'YZT': 'America/Vancouver',
    'YZU': 'America/Edmonton',
    'YZV': 'America/Toronto',
    'YZW': 'America/Vancouver',
    'YZX': 'America/Halifax',
    'YZY': 'Asia/Shanghai',
    'YZZ': 'America/Vancouver',
    'ZAC': 'America/Winnipeg',
    'ZAD': 'Europe/Zagreb',
    'ZAG': 'Europe/Zagreb',
    'ZAH': 'Asia/Tehran',
    'ZAJ': 'Asia/Kabul',
    'ZAL': 'America/Santiago',
    'ZAM': 'Asia/Manila',
    'ZAO': 'Europe/Paris',
    'ZAR': 'Africa/Lagos',
    'ZAT': 'Asia/Shanghai',
    'ZAZ': 'Europe/Madrid',
    'ZBF': 'America/Halifax',
    'ZBM': 'America/Toronto',
    'ZBR': 'Asia/Tehran',
    'ZCL': 'America/Mexico_City',
    'ZCN': 'Europe/Berlin',
    'ZEC': 'Africa/Johannesburg',
    'ZEM': 'America/Toronto',
    'ZER': 'Asia/Calcutta',
    'ZFA': 'America/Vancouver',
    'ZFD': 'America/Regina',
    'ZFM': 'America/Edmonton',
    'ZFN': 'America/Edmonton',
    'ZGI': 'America/Winnipeg',
    'ZGR': 'America/Winnipeg',
    'ZGS': 'America/Blanc-Sablon',
    'ZGU': 'Pacific/Efate',
    'ZHA': 'Asia/Shanghai',
    'ZHI': 'Europe/Zurich',
    'ZHY': 'Asia/Shanghai',
    'ZIA': 'Europe/Moscow',
    'ZIG': 'Africa/Dakar',
    'ZIH': 'America/Mexico_City',
    'ZIN': 'Europe/Zurich',
    'ZJI': 'Europe/Zurich',
    'ZJN': 'America/Winnipeg',
    'ZKB': 'Africa/Lusaka',
    'ZKE': 'America/Toronto',
    'ZKG': 'America/Blanc-Sablon',
    'ZKP': 'Asia/Srednekolymsk',
    'ZLO': 'America/Mexico_City',
    'ZLT': 'America/Blanc-Sablon',
    'ZMG': 'Europe/Berlin',
    'ZMH': 'America/Vancouver',
    'ZMM': 'America/Mexico_City',
    'ZMT': 'America/Vancouver',
    'ZNA': 'America/Vancouver',
    'ZND': 'Africa/Niamey',
    'ZNE': 'Australia/Perth',
    'ZNF': 'Europe/Berlin',
    'ZNZ': 'Africa/Dar_es_Salaam',
    'ZOS': 'America/Santiago',
    'ZPB': 'America/Winnipeg',
    'ZPC': 'America/Santiago',
    'ZPH': 'America/New_York',
    'ZQL': 'Europe/Berlin',
    'ZQN': 'Pacific/Auckland',
    'ZQW': 'Europe/Berlin',
    'ZRH': 'Europe/Zurich',
    'ZRJ': 'America/Winnipeg',
    'ZSA': 'America/Nassau',
    'ZSE': 'Indian/Reunion',
    'ZSJ': 'America/Winnipeg',
    'ZSW': 'America/Vancouver',
    'ZTB': 'America/Blanc-Sablon',
    'ZTH': 'Europe/Athens',
    'ZTM': 'America/Winnipeg',
    'ZTR': 'Europe/Kiev',
    'ZTU': 'Asia/Baku',
    'ZUH': 'Asia/Shanghai',
    'ZUM': 'America/Halifax',
    'ZVA': 'Indian/Antananarivo',
    'ZVK': 'Asia/Vientiane',
    'ZWA': 'Indian/Antananarivo',
    'ZWL': 'America/Regina',
    'ZYI': 'Asia/Shanghai',
    'ZYL': 'Asia/Dhaka',
    'ZZU': 'Africa/Blantyre'
}
